Class: Aws::CloudFormation::Resource
- Inherits:
-
Object
- Object
- Aws::CloudFormation::Resource
- Defined in:
- sig/resource.rbs,
lib/aws-sdk-cloudformation/resource.rb
Overview
This class provides a resource oriented interface for CloudFormation. To create a resource object:
resource = Aws::CloudFormation::Resource.new(region: 'us-west-2')
You can supply a client object with custom configuration that will be used for all resource operations.
If you do not pass :client, a default client will be constructed.
client = Aws::CloudFormation::Client.new(region: 'us-west-2')
resource = Aws::CloudFormation::Resource.new(client: client)
Actions collapse
Associations collapse
Instance Method Summary collapse
- #client ⇒ Client
-
#initialize(options = {}) ⇒ Resource
constructor
A new instance of Resource.
Constructor Details
#initialize(options = {}) ⇒ Resource
Returns a new instance of Resource.
13 |
# File 'sig/resource.rbs', line 13
def initialize: (
|
Instance Method Details
#client ⇒ Client
32 |
# File 'lib/aws-sdk-cloudformation/resource.rb', line 32
def client: () -> Client
|