Class: Aws::CloudFormation::StackResource

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/stack_resource.rbs,
lib/aws-sdk-cloudformation/stack_resource.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(stack_name, logical_id, options = {}) ⇒ StackResource #initialize(options = {}) ⇒ StackResource

Returns a new instance of StackResource.

Overloads:

  • #initialize(stack_name, logical_id, options = {}) ⇒ StackResource

    Parameters:

    • stack_name (String)
    • logical_id (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ StackResource

    Options Hash (options):

    • :stack_name (required, String)
    • :logical_id (required, String)
    • :client (Client)


13
14
15
# File 'sig/stack_resource.rbs', line 13

def initialize: (String stack_name, String logical_id, Hash[Symbol, untyped] options) -> void
| (stack_name: String, logical_id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#clientClient

Returns:



132
# File 'lib/aws-sdk-cloudformation/stack_resource.rb', line 132

def client: () -> Client

#dataTypes::StackResourceDetail



61
# File 'sig/stack_resource.rbs', line 61

def data: () -> Types::StackResourceDetail

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



64
# File 'sig/stack_resource.rbs', line 64

def data_loaded?: () -> bool

#descriptionString

User defined description associated with the resource.

Returns:

  • (String)


43
# File 'sig/stack_resource.rbs', line 43

def description: () -> ::String

#drift_informationTypes::StackResourceDriftInformation

Information about whether the resource's actual configuration differs, or has drifted, from its expected configuration, as defined in the stack template and any values specified as template parameters. For more information, see Detect unmanaged configuration changes to stacks and resources with drift detection.



49
# File 'sig/stack_resource.rbs', line 49

def drift_information: () -> Types::StackResourceDriftInformation

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


280
281
282
283
284
285
# File 'lib/aws-sdk-cloudformation/stack_resource.rb', line 280

def identifiers
  {
    stack_name: @stack_name,
    logical_id: @logical_id
  }
end

#last_updated_timestampTime

Time the status was updated.

Returns:

  • (Time)


34
# File 'sig/stack_resource.rbs', line 34

def last_updated_timestamp: () -> ::Time

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::CloudFormation::StackResource. Returns self making it possible to chain methods.

stack_resource.reload.data

Returns:

  • (self)


57
# File 'sig/stack_resource.rbs', line 57

def load: () -> self

#logical_idString Also known as: logical_resource_id

Returns:

  • (String)


21
# File 'sig/stack_resource.rbs', line 21

def logical_id: () -> String

#metadataString

The content of the Metadata attribute declared for the resource. For more information, see Metadata attribute in the CloudFormation User Guide.

Returns:

  • (String)


46
# File 'sig/stack_resource.rbs', line 46

def metadata: () -> ::String

#module_infoTypes::ModuleInfo

Contains information about the module from which the resource was created, if the resource was created from a module included in the stack template.

Returns:



52
# File 'sig/stack_resource.rbs', line 52

def module_info: () -> Types::ModuleInfo

#physical_resource_idString

The name or unique identifier that corresponds to a physical instance ID of a resource supported by CloudFormation.

Returns:

  • (String)


28
# File 'sig/stack_resource.rbs', line 28

def physical_resource_id: () -> ::String

#resource_statusString

Current status of the resource.

Returns:

  • (String)


37
# File 'sig/stack_resource.rbs', line 37

def resource_status: () -> ("CREATE_IN_PROGRESS" | "CREATE_FAILED" | "CREATE_COMPLETE" | "DELETE_IN_PROGRESS" | "DELETE_FAILED" | "DELETE_COMPLETE" | "DELETE_SKIPPED" | "UPDATE_IN_PROGRESS" | "UPDATE_FAILED" | "UPDATE_COMPLETE" | "IMPORT_FAILED" | "IMPORT_COMPLETE" | "IMPORT_IN_PROGRESS" | "IMPORT_ROLLBACK_IN_PROGRESS" | "IMPORT_ROLLBACK_FAILED" | "IMPORT_ROLLBACK_COMPLETE" | "EXPORT_FAILED" | "EXPORT_COMPLETE" | "EXPORT_IN_PROGRESS" | "EXPORT_ROLLBACK_IN_PROGRESS" | "EXPORT_ROLLBACK_FAILED" | "EXPORT_ROLLBACK_COMPLETE" | "UPDATE_ROLLBACK_IN_PROGRESS" | "UPDATE_ROLLBACK_COMPLETE" | "UPDATE_ROLLBACK_FAILED" | "ROLLBACK_IN_PROGRESS" | "ROLLBACK_COMPLETE" | "ROLLBACK_FAILED")

#resource_status_reasonString

Success/failure message associated with the resource.

Returns:

  • (String)


40
# File 'sig/stack_resource.rbs', line 40

def resource_status_reason: () -> ::String

#resource_typeString

Type of resource. For more information, see Amazon Web Services resource and property types reference in the CloudFormation User Guide.

Returns:

  • (String)


31
# File 'sig/stack_resource.rbs', line 31

def resource_type: () -> ::String

#stackStack

Returns:



68
# File 'sig/stack_resource.rbs', line 68

def stack: () -> Stack

#stack_idString

Unique identifier of the stack.

Returns:

  • (String)


25
# File 'sig/stack_resource.rbs', line 25

def stack_id: () -> ::String

#stack_nameString

Returns:

  • (String)


18
# File 'sig/stack_resource.rbs', line 18

def stack_name: () -> String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::CloudFormation::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/aws-sdk-cloudformation/stack_resource.rb', line 249

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end