Class: Aws::CloudFormation::StackResourceSummary
- Inherits:
-
Object
- Object
- Aws::CloudFormation::StackResourceSummary
- Extended by:
- Deprecations
- Defined in:
- sig/stack_resource_summary.rbs,
lib/aws-sdk-cloudformation/stack_resource_summary.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#drift_information ⇒ Types::StackResourceDriftInformationSummary
Information about whether the resource's actual configuration differs, or has drifted, from its expected configuration, as defined in the stack template and any values specified as template parameters.
-
#last_updated_timestamp ⇒ Time
Time the status was updated.
- #logical_id ⇒ String (also: #logical_resource_id)
-
#module_info ⇒ Types::ModuleInfo
Contains information about the module from which the resource was created, if the resource was created from a module included in the stack template.
-
#physical_resource_id ⇒ String
The name or unique identifier that corresponds to a physical instance ID of the resource.
-
#resource_status ⇒ String
Current status of the resource.
-
#resource_status_reason ⇒ String
Success/failure message associated with the resource.
-
#resource_type ⇒ String
Type of resource.
- #stack_name ⇒ String
Associations collapse
- #identifiers ⇒ Object deprecated private Deprecated.
- #resource ⇒ StackResource
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::StackResourceSummary
Returns the data for this StackResourceSummary.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ StackResourceSummary
constructor
A new instance of StackResourceSummary.
- #load ⇒ Object (also: #reload) private
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::CloudFormation::Client] #wait_until instead
Constructor Details
#initialize(stack_name, logical_id, options = {}) ⇒ StackResourceSummary #initialize(options = {}) ⇒ StackResourceSummary
Returns a new instance of StackResourceSummary.
13 14 15 |
# File 'sig/stack_resource_summary.rbs', line 13
def initialize: (String stack_name, String logical_id, Hash[Symbol, untyped] options) -> void
| (stack_name: String, logical_id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#client ⇒ Client
108 |
# File 'lib/aws-sdk-cloudformation/stack_resource_summary.rb', line 108
def client: () -> Client
|
#data ⇒ Types::StackResourceSummary
Returns the data for this Aws::CloudFormation::StackResourceSummary.
49 |
# File 'sig/stack_resource_summary.rbs', line 49
def data: () -> Types::StackResourceSummary
|
#data_loaded? ⇒ Boolean
52 |
# File 'sig/stack_resource_summary.rbs', line 52
def data_loaded?: () -> bool
|
#drift_information ⇒ Types::StackResourceDriftInformationSummary
Information about whether the resource's actual configuration differs, or has drifted, from its expected configuration, as defined in the stack template and any values specified as template parameters. For more information, see Detect unmanaged configuration changes to stacks and resources with drift detection.
40 |
# File 'sig/stack_resource_summary.rbs', line 40
def drift_information: () -> Types::StackResourceDriftInformationSummary
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
247 248 249 250 251 252 |
# File 'lib/aws-sdk-cloudformation/stack_resource_summary.rb', line 247 def identifiers { stack_name: @stack_name, logical_id: @logical_id } end |
#last_updated_timestamp ⇒ Time
Time the status was updated.
31 |
# File 'sig/stack_resource_summary.rbs', line 31
def last_updated_timestamp: () -> ::Time
|
#load ⇒ Object Also known as: reload
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
114 115 116 117 |
# File 'lib/aws-sdk-cloudformation/stack_resource_summary.rb', line 114 def load msg = "#load is not implemented, data only available via enumeration" raise NotImplementedError, msg end |
#logical_id ⇒ String Also known as: logical_resource_id
21 |
# File 'sig/stack_resource_summary.rbs', line 21
def logical_id: () -> String
|
#module_info ⇒ Types::ModuleInfo
Contains information about the module from which the resource was created, if the resource was created from a module included in the stack template.
43 |
# File 'sig/stack_resource_summary.rbs', line 43
def module_info: () -> Types::ModuleInfo
|
#physical_resource_id ⇒ String
The name or unique identifier that corresponds to a physical instance ID of the resource.
25 |
# File 'sig/stack_resource_summary.rbs', line 25
def physical_resource_id: () -> ::String
|
#resource ⇒ StackResource
56 |
# File 'sig/stack_resource_summary.rbs', line 56
def resource: () -> StackResource
|
#resource_status ⇒ String
Current status of the resource.
34 |
# File 'sig/stack_resource_summary.rbs', line 34
def resource_status: () -> ("CREATE_IN_PROGRESS" | "CREATE_FAILED" | "CREATE_COMPLETE" | "DELETE_IN_PROGRESS" | "DELETE_FAILED" | "DELETE_COMPLETE" | "DELETE_SKIPPED" | "UPDATE_IN_PROGRESS" | "UPDATE_FAILED" | "UPDATE_COMPLETE" | "IMPORT_FAILED" | "IMPORT_COMPLETE" | "IMPORT_IN_PROGRESS" | "IMPORT_ROLLBACK_IN_PROGRESS" | "IMPORT_ROLLBACK_FAILED" | "IMPORT_ROLLBACK_COMPLETE" | "EXPORT_FAILED" | "EXPORT_COMPLETE" | "EXPORT_IN_PROGRESS" | "EXPORT_ROLLBACK_IN_PROGRESS" | "EXPORT_ROLLBACK_FAILED" | "EXPORT_ROLLBACK_COMPLETE" | "UPDATE_ROLLBACK_IN_PROGRESS" | "UPDATE_ROLLBACK_COMPLETE" | "UPDATE_ROLLBACK_FAILED" | "ROLLBACK_IN_PROGRESS" | "ROLLBACK_COMPLETE" | "ROLLBACK_FAILED")
|
#resource_status_reason ⇒ String
Success/failure message associated with the resource.
37 |
# File 'sig/stack_resource_summary.rbs', line 37
def resource_status_reason: () -> ::String
|
#resource_type ⇒ String
Type of resource. (For more information, see Amazon Web Services resource and property types reference in the CloudFormation User Guide.)
28 |
# File 'sig/stack_resource_summary.rbs', line 28
def resource_type: () -> ::String
|
#stack_name ⇒ String
18 |
# File 'sig/stack_resource_summary.rbs', line 18
def stack_name: () -> String
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::CloudFormation::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/aws-sdk-cloudformation/stack_resource_summary.rb', line 215 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |