Method: Aws::CloudFormation::Types::AccountGateResult#status
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
#status ⇒ String
The status of the account gate function.
-
SUCCEEDED: The account gate function has determined that the account and Region passes any requirements for a StackSet operation to occur. CloudFormation proceeds with the stack operation in that account and Region. -
FAILED: The account gate function has determined that the account and Region doesn’t meet the requirements for a StackSet operation to occur. CloudFormation cancels the StackSet operation in that account and Region, and sets the StackSet operation result status for that account and Region toFAILED. -
SKIPPED: CloudFormation has skipped calling the account gate function for this account and Region, for one of the following reasons:-
An account gate function hasn’t been specified for the account and Region. CloudFormation proceeds with the StackSet operation in this account and Region.
-
The
AWSCloudFormationStackSetExecutionRoleof the administration account lacks permissions to invoke the function. CloudFormation proceeds with the StackSet operation in this account and Region. -
Either no action is necessary, or no action is possible, on the stack. CloudFormation skips the StackSet operation in this account and Region.
-
72 73 74 75 76 77 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 72 class AccountGateResult < Struct.new( :status, :status_reason) SENSITIVE = [] include Aws::Structure end |