Class: Aws::CloudFormation::Types::CreateChangeSetInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::CreateChangeSetInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
The input for the CreateChangeSet action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capabilities ⇒ Array<String>
In some cases, you must explicitly acknowledge that your stack template contains certain capabilities in order for CloudFormation to create the stack.
-
#change_set_name ⇒ String
The name of the change set.
-
#change_set_type ⇒ String
The type of change set operation.
-
#client_token ⇒ String
A unique identifier for this
CreateChangeSetrequest. -
#deployment_config ⇒ Types::DeploymentConfig
The deployment configuration for this stack operation, including the deployment mode.
-
#deployment_mode ⇒ String
Determines how CloudFormation handles configuration drift during deployment.
-
#description ⇒ String
A description to help you identify this change set.
-
#disable_validation ⇒ Boolean
Set to
trueto disable pre-deployment validations in changeset or stack operations. -
#import_existing_resources ⇒ Boolean
Indicates if the change set auto-imports resources that already exist.
-
#include_nested_stacks ⇒ Boolean
Creates a change set for the all nested stacks specified in the template.
-
#notification_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of Amazon SNS topics that CloudFormation associates with the stack.
-
#on_stack_failure ⇒ String
Determines what action will be taken if stack creation fails.
-
#parameters ⇒ Array<Types::Parameter>
A list of
Parameterstructures that specify input parameters for the change set. -
#resource_types ⇒ Array<String>
Specifies which resource types you can work with, such as
AWS::EC2::InstanceorCustom::MyCustomInstance. -
#resources_to_import ⇒ Array<Types::ResourceToImport>
The resources to import into your stack.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that CloudFormation assumes when executing the change set.
-
#rollback_configuration ⇒ Types::RollbackConfiguration
The rollback triggers for CloudFormation to monitor during stack creation and updating operations, and for the specified monitoring period afterwards.
-
#stack_name ⇒ String
The name or the unique ID of the stack for which you are creating a change set.
-
#tags ⇒ Array<Types::Tag>
Key-value pairs to associate with this stack.
-
#template_body ⇒ String
A structure that contains the body of the revised template, with a minimum length of 1 byte and a maximum length of 51,200 bytes.
-
#template_url ⇒ String
The URL of the file that contains the revised template.
-
#use_previous_template ⇒ Boolean
Whether to reuse the template that's associated with the stack to create the change set.
Instance Attribute Details
#capabilities ⇒ Array<String>
In some cases, you must explicitly acknowledge that your stack template contains certain capabilities in order for CloudFormation to create the stack.
-
CAPABILITY_IAMandCAPABILITY_NAMED_IAMSome stack templates might include resources that can affect permissions in your Amazon Web Services account, for example, by creating new IAM users. For those stacks, you must explicitly acknowledge this by specifying one of these capabilities.
The following IAM resources require you to specify either the
CAPABILITY_IAMorCAPABILITY_NAMED_IAMcapability. -
If you have IAM resources, you can specify either capability.
-
If you have IAM resources with custom names, you must specify
CAPABILITY_NAMED_IAM. -
If you don't specify either of these capabilities, CloudFormation returns an
InsufficientCapabilitieserror. If your stack template contains these resources, we suggest that you review all permissions associated with them and edit their permissions if necessary. -
AWS::IAM::UserToGroupAddition For more information, see Acknowledging IAM resources in CloudFormation templates.
-
CAPABILITY_AUTO_EXPANDSome template contain macros. Macros perform custom processing on templates; this can include simple actions like find-and-replace operations, all the way to extensive transformations of entire templates. Because of this, users typically create a change set from the processed template, so that they can review the changes resulting from the macros before actually creating the stack. If your stack template contains one or more macros, and you choose to create a stack directly from the processed template, without first reviewing the resulting changes in a change set, you must acknowledge this capability. This includes the AWS::Include and AWS::Serverless transforms, which are macros hosted by CloudFormation.
This capacity doesn't apply to creating change sets, and specifying it when creating change sets has no effect. If you want to create a stack from a stack template that contains macros and nested stacks, you must create or update the stack directly from the template using the CreateStack or UpdateStack action, and specifying this capability.
For more information about macros, see Perform custom processing on CloudFormation templates with template macros.
Capabilities and ResourceType parameters can be
specified.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#change_set_name ⇒ String
The name of the change set. The name must be unique among all change sets that are associated with the specified stack.
A change set name can contain only alphanumeric, case sensitive characters, and hyphens. It must start with an alphabetical character and can't exceed 128 characters.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#change_set_type ⇒ String
The type of change set operation. To create a change set for a new
stack, specify CREATE. To create a change set for an existing
stack, specify UPDATE. To create a change set for an import
operation, specify IMPORT.
If you create a change set for a new stack, CloudFormation creates a
stack with a unique stack ID, but no template or resources. The
stack will be in the REVIEW_IN_PROGRESS state until you execute
the change set.
By default, CloudFormation specifies UPDATE. You can't use the
UPDATE type to create a change set for a new stack or the CREATE
type to create a change set for an existing stack.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique identifier for this CreateChangeSet request. Specify this
token if you plan to retry requests so that CloudFormation knows
that you're not attempting to create another change set with the
same name. You might retry CreateChangeSet requests to ensure that
CloudFormation successfully received them.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#deployment_config ⇒ Types::DeploymentConfig
The deployment configuration for this stack operation, including the deployment mode.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#deployment_mode ⇒ String
Determines how CloudFormation handles configuration drift during deployment.
REVERT_DRIFT– Creates a drift-aware change set that brings actual resource states in line with template definitions. Provides a three-way comparison between actual state, previous deployment state, and desired state.
^
For more information, see Using drift-aware change sets in the CloudFormation User Guide.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description to help you identify this change set.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#disable_validation ⇒ Boolean
Set to true to disable pre-deployment validations in changeset or
stack operations.
Default: false
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#import_existing_resources ⇒ Boolean
Indicates if the change set auto-imports resources that already exist. For more information, see Import Amazon Web Services resources into a CloudFormation stack automatically in the CloudFormation User Guide.
ResourcesToImport
parameter instead.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#include_nested_stacks ⇒ Boolean
Creates a change set for the all nested stacks specified in the
template. The default behavior of this action is set to False. To
include nested sets in a change set, specify True.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#notification_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of Amazon SNS topics that CloudFormation associates with the stack. To remove all associated notification topics, specify an empty list.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#on_stack_failure ⇒ String
Determines what action will be taken if stack creation fails. If
this parameter is specified, the DisableRollback parameter to the
ExecuteChangeSet API operation must not be specified. This must
be one of these values:
-
DELETE- Deletes the change set if the stack creation fails. This is only valid when theChangeSetTypeparameter is set toCREATE. If the deletion of the stack fails, the status of the stack isDELETE_FAILED. -
DO_NOTHING- if the stack creation fails, do nothing. This is equivalent to specifyingtruefor theDisableRollbackparameter to the ExecuteChangeSet API operation. -
ROLLBACK- if the stack creation fails, roll back the stack. This is equivalent to specifyingfalsefor theDisableRollbackparameter to the ExecuteChangeSet API operation.
For nested stacks, when the OnStackFailure parameter is set to
DELETE for the change set for the parent stack, any failure in a
child stack will cause the parent stack creation to fail and all
stacks to be deleted.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Array<Types::Parameter>
A list of Parameter structures that specify input parameters for
the change set. For more information, see the Parameter data type.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#resource_types ⇒ Array<String>
Specifies which resource types you can work with, such as
AWS::EC2::Instance or Custom::MyCustomInstance.
If the list of resource types doesn't include a resource type that you're updating, the stack update fails. By default, CloudFormation grants permissions to all resource types. IAM uses this parameter for condition keys in IAM policies for CloudFormation. For more information, see Control CloudFormation access with Identity and Access Management in the CloudFormation User Guide.
Capabilities and ResourceType parameters can be
specified.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#resources_to_import ⇒ Array<Types::ResourceToImport>
The resources to import into your stack.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that CloudFormation assumes when executing the change set. CloudFormation uses the role's credentials to make calls on your behalf. CloudFormation uses this role for all future operations on the stack. Provided that users have permission to operate on the stack, CloudFormation uses this role even if the users don't have permission to pass it. Ensure that the role grants least permission.
If you don't specify a value, CloudFormation uses the role that was previously associated with the stack. If no role is available, CloudFormation uses a temporary session that is generated from your user credentials.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#rollback_configuration ⇒ Types::RollbackConfiguration
The rollback triggers for CloudFormation to monitor during stack creation and updating operations, and for the specified monitoring period afterwards.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#stack_name ⇒ String
The name or the unique ID of the stack for which you are creating a change set. CloudFormation generates the change set by comparing this stack's information with the information that you submit, such as a modified template or different parameter input values.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Key-value pairs to associate with this stack. CloudFormation also propagates these tags to resources in the stack. You can specify a maximum of 50 tags.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#template_body ⇒ String
A structure that contains the body of the revised template, with a minimum length of 1 byte and a maximum length of 51,200 bytes. CloudFormation generates the change set by comparing this template with the template of the stack that you specified.
Conditional: You must specify only one of the following parameters:
TemplateBody, TemplateURL, or set the UsePreviousTemplate to
true.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#template_url ⇒ String
The URL of the file that contains the revised template. The URL must
point to a template (max size: 1 MB) that's located in an Amazon S3
bucket or a Systems Manager document. CloudFormation generates the
change set by comparing this template with the stack that you
specified. The location for an Amazon S3 bucket must start with
https://. URLs from S3 static websites are not supported.
Conditional: You must specify only one of the following parameters:
TemplateBody, TemplateURL, or set the UsePreviousTemplate to
true.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |
#use_previous_template ⇒ Boolean
Whether to reuse the template that's associated with the stack to create the change set.
When using templates with the AWS::LanguageExtensions transform,
provide the template instead of using UsePreviousTemplate to
ensure new parameter values and Systems Manager parameter updates
are applied correctly. For more information, see
AWS::LanguageExtensions transform.
Conditional: You must specify only one of the following parameters:
TemplateBody, TemplateURL, or set the UsePreviousTemplate to
true.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1115 class CreateChangeSetInput < Struct.new( :stack_name, :template_body, :template_url, :use_previous_template, :parameters, :capabilities, :resource_types, :role_arn, :rollback_configuration, :notification_arns, :tags, :change_set_name, :client_token, :description, :change_set_type, :resources_to_import, :include_nested_stacks, :on_stack_failure, :import_existing_resources, :deployment_mode, :deployment_config, :disable_validation) SENSITIVE = [] include Aws::Structure end |