Class: Aws::CloudFormation::Types::CreateGeneratedTemplateInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::CreateGeneratedTemplateInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#generated_template_name ⇒ String
The name assigned to the generated template.
-
#resources ⇒ Array<Types::ResourceDefinition>
An optional list of resources to be included in the generated template.
-
#stack_name ⇒ String
An optional name or ARN of a stack to use as the base stack for the generated template.
-
#template_configuration ⇒ Types::TemplateConfiguration
The configuration details of the generated template, including the
DeletionPolicyandUpdateReplacePolicy.
Instance Attribute Details
#generated_template_name ⇒ String
The name assigned to the generated template.
1186 1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1186 class CreateGeneratedTemplateInput < Struct.new( :resources, :generated_template_name, :stack_name, :template_configuration) SENSITIVE = [] include Aws::Structure end |
#resources ⇒ Array<Types::ResourceDefinition>
An optional list of resources to be included in the generated template.
If no resources are specified,the template will be created without
any resources. Resources can be added to the template using the
UpdateGeneratedTemplate API action.
1186 1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1186 class CreateGeneratedTemplateInput < Struct.new( :resources, :generated_template_name, :stack_name, :template_configuration) SENSITIVE = [] include Aws::Structure end |
#stack_name ⇒ String
An optional name or ARN of a stack to use as the base stack for the generated template.
1186 1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1186 class CreateGeneratedTemplateInput < Struct.new( :resources, :generated_template_name, :stack_name, :template_configuration) SENSITIVE = [] include Aws::Structure end |
#template_configuration ⇒ Types::TemplateConfiguration
The configuration details of the generated template, including the
DeletionPolicy and UpdateReplacePolicy.
1186 1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1186 class CreateGeneratedTemplateInput < Struct.new( :resources, :generated_template_name, :stack_name, :template_configuration) SENSITIVE = [] include Aws::Structure end |