Class: Aws::CloudFormation::Types::CreateStackRefactorInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description to help you identify the stack refactor.

Returns:

  • (String)


1682
1683
1684
1685
1686
1687
1688
1689
# File 'lib/aws-sdk-cloudformation/types.rb', line 1682

class CreateStackRefactorInput < Struct.new(
  :description,
  :enable_stack_creation,
  :resource_mappings,
  :stack_definitions)
  SENSITIVE = []
  include Aws::Structure
end

#enable_stack_creationBoolean

Determines if a new stack is created with the refactor.

Returns:

  • (Boolean)


1682
1683
1684
1685
1686
1687
1688
1689
# File 'lib/aws-sdk-cloudformation/types.rb', line 1682

class CreateStackRefactorInput < Struct.new(
  :description,
  :enable_stack_creation,
  :resource_mappings,
  :stack_definitions)
  SENSITIVE = []
  include Aws::Structure
end

#resource_mappingsArray<Types::ResourceMapping>

The mappings for the stack resource Source and stack resource Destination.

Returns:



1682
1683
1684
1685
1686
1687
1688
1689
# File 'lib/aws-sdk-cloudformation/types.rb', line 1682

class CreateStackRefactorInput < Struct.new(
  :description,
  :enable_stack_creation,
  :resource_mappings,
  :stack_definitions)
  SENSITIVE = []
  include Aws::Structure
end

#stack_definitionsArray<Types::StackDefinition>

The stacks being refactored.

Returns:



1682
1683
1684
1685
1686
1687
1688
1689
# File 'lib/aws-sdk-cloudformation/types.rb', line 1682

class CreateStackRefactorInput < Struct.new(
  :description,
  :enable_stack_creation,
  :resource_mappings,
  :stack_definitions)
  SENSITIVE = []
  include Aws::Structure
end