Class: Aws::CloudFormation::Types::CreateStackRefactorOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::CreateStackRefactorOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#stack_refactor_id ⇒ String
The ID associated with the stack refactor created from the CreateStackRefactor action.
Instance Attribute Details
#stack_refactor_id ⇒ String
The ID associated with the stack refactor created from the CreateStackRefactor action.
1698 1699 1700 1701 1702 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1698 class CreateStackRefactorOutput < Struct.new( :stack_refactor_id) SENSITIVE = [] include Aws::Structure end |