Class: Aws::CloudFormation::Types::CreateStackSetInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::CreateStackSetInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#administration_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role to use to create this StackSet.
-
#auto_deployment ⇒ Types::AutoDeployment
Describes whether StackSets automatically deploys to Organizations accounts that are added to the target organization or organizational unit (OU).
-
#call_as ⇒ String
Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.
-
#capabilities ⇒ Array<String>
In some cases, you must explicitly acknowledge that your StackSet template contains certain capabilities in order for CloudFormation to create the StackSet and related stack instances.
-
#client_request_token ⇒ String
A unique identifier for this
CreateStackSetrequest. -
#description ⇒ String
A description of the StackSet.
-
#execution_role_name ⇒ String
The name of the IAM execution role to use to create the StackSet.
-
#managed_execution ⇒ Types::ManagedExecution
Describes whether CloudFormation performs non-conflicting operations concurrently and queues conflicting operations.
-
#parameters ⇒ Array<Types::Parameter>
The input parameters for the StackSet template.
-
#permission_model ⇒ String
Describes how the IAM roles required for StackSet operations are created.
-
#stack_id ⇒ String
The stack ID you are importing into a new StackSet.
-
#stack_set_name ⇒ String
The name to associate with the StackSet.
-
#tags ⇒ Array<Types::Tag>
The key-value pairs to associate with this StackSet and the stacks created from it.
-
#template_body ⇒ String
The structure that contains the template body, with a minimum length of 1 byte and a maximum length of 51,200 bytes.
-
#template_url ⇒ String
The URL of a file that contains the template body.
Instance Attribute Details
#administration_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role to use to create this StackSet.
Specify an IAM role only if you are using customized administrator roles to control which users or groups can manage specific StackSets within the same administrator account. For more information, see Grant self-managed permissions in the CloudFormation User Guide.
Valid only if the permissions model is SELF_MANAGED.
1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1952 class CreateStackSetInput < Struct.new( :stack_set_name, :description, :template_body, :template_url, :stack_id, :parameters, :capabilities, :tags, :administration_role_arn, :execution_role_name, :permission_model, :auto_deployment, :call_as, :client_request_token, :managed_execution) SENSITIVE = [] include Aws::Structure end |
#auto_deployment ⇒ Types::AutoDeployment
Describes whether StackSets automatically deploys to Organizations accounts that are added to the target organization or organizational unit (OU). For more information, see Enable or disable automatic deployments for StackSets in Organizations in the CloudFormation User Guide.
Required if the permissions model is SERVICE_MANAGED. (Not used
with self-managed permissions.)
1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1952 class CreateStackSetInput < Struct.new( :stack_set_name, :description, :template_body, :template_url, :stack_id, :parameters, :capabilities, :tags, :administration_role_arn, :execution_role_name, :permission_model, :auto_deployment, :call_as, :client_request_token, :managed_execution) SENSITIVE = [] include Aws::Structure end |
#call_as ⇒ String
Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.
By default, SELF is specified. Use SELF for StackSets with
self-managed permissions.
-
To create a StackSet with service-managed permissions while signed in to the management account, specify
SELF. -
To create a StackSet with service-managed permissions while signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated admin in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.
StackSets with service-managed permissions are created in the management account, including StackSets that are created by delegated administrators.
Valid only if the permissions model is SERVICE_MANAGED.
1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1952 class CreateStackSetInput < Struct.new( :stack_set_name, :description, :template_body, :template_url, :stack_id, :parameters, :capabilities, :tags, :administration_role_arn, :execution_role_name, :permission_model, :auto_deployment, :call_as, :client_request_token, :managed_execution) SENSITIVE = [] include Aws::Structure end |
#capabilities ⇒ Array<String>
In some cases, you must explicitly acknowledge that your StackSet template contains certain capabilities in order for CloudFormation to create the StackSet and related stack instances.
-
CAPABILITY_IAMandCAPABILITY_NAMED_IAMSome stack templates might include resources that can affect permissions in your Amazon Web Services account; for example, by creating new IAM users. For those StackSets, you must explicitly acknowledge this by specifying one of these capabilities.
The following IAM resources require you to specify either the
CAPABILITY_IAMorCAPABILITY_NAMED_IAMcapability. -
If you have IAM resources, you can specify either capability.
-
If you have IAM resources with custom names, you must specify
CAPABILITY_NAMED_IAM. -
If you don't specify either of these capabilities, CloudFormation returns an
InsufficientCapabilitieserror. If your stack template contains these resources, we recommend that you review all permissions associated with them and edit their permissions if necessary. -
AWS::IAM::UserToGroupAddition For more information, see Acknowledging IAM resources in CloudFormation templates.
-
CAPABILITY_AUTO_EXPANDSome templates reference macros. If your StackSet template references one or more macros, you must create the StackSet directly from the processed template, without first reviewing the resulting changes in a change set. To create the StackSet directly, you must acknowledge this capability. For more information, see Perform custom processing on CloudFormation templates with template macros.
StackSets with service-managed permissions don't currently support the use of macros in templates. (This includes the AWS::Include and AWS::Serverless transforms, which are macros hosted by CloudFormation.) Even if you specify this capability for a StackSet with service-managed permissions, if you reference a macro in your template the StackSet operation will fail.
1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1952 class CreateStackSetInput < Struct.new( :stack_set_name, :description, :template_body, :template_url, :stack_id, :parameters, :capabilities, :tags, :administration_role_arn, :execution_role_name, :permission_model, :auto_deployment, :call_as, :client_request_token, :managed_execution) SENSITIVE = [] include Aws::Structure end |
#client_request_token ⇒ String
A unique identifier for this CreateStackSet request. Specify this
token if you plan to retry requests so that CloudFormation knows
that you're not attempting to create another StackSet with the same
name. You might retry CreateStackSet requests to ensure that
CloudFormation successfully received them.
If you don't specify an operation ID, the SDK generates one automatically.
A suitable default value is auto-generated. You should normally not need to pass this option.
1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1952 class CreateStackSetInput < Struct.new( :stack_set_name, :description, :template_body, :template_url, :stack_id, :parameters, :capabilities, :tags, :administration_role_arn, :execution_role_name, :permission_model, :auto_deployment, :call_as, :client_request_token, :managed_execution) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the StackSet. You can use the description to identify the StackSet's purpose or other important information.
1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1952 class CreateStackSetInput < Struct.new( :stack_set_name, :description, :template_body, :template_url, :stack_id, :parameters, :capabilities, :tags, :administration_role_arn, :execution_role_name, :permission_model, :auto_deployment, :call_as, :client_request_token, :managed_execution) SENSITIVE = [] include Aws::Structure end |
#execution_role_name ⇒ String
The name of the IAM execution role to use to create the StackSet. If
you do not specify an execution role, CloudFormation uses the
AWSCloudFormationStackSetExecutionRole role for the StackSet
operation.
Specify an IAM role only if you are using customized execution roles to control which stack resources users and groups can include in their StackSets.
Valid only if the permissions model is SELF_MANAGED.
1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1952 class CreateStackSetInput < Struct.new( :stack_set_name, :description, :template_body, :template_url, :stack_id, :parameters, :capabilities, :tags, :administration_role_arn, :execution_role_name, :permission_model, :auto_deployment, :call_as, :client_request_token, :managed_execution) SENSITIVE = [] include Aws::Structure end |
#managed_execution ⇒ Types::ManagedExecution
Describes whether CloudFormation performs non-conflicting operations concurrently and queues conflicting operations.
1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1952 class CreateStackSetInput < Struct.new( :stack_set_name, :description, :template_body, :template_url, :stack_id, :parameters, :capabilities, :tags, :administration_role_arn, :execution_role_name, :permission_model, :auto_deployment, :call_as, :client_request_token, :managed_execution) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Array<Types::Parameter>
The input parameters for the StackSet template.
1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1952 class CreateStackSetInput < Struct.new( :stack_set_name, :description, :template_body, :template_url, :stack_id, :parameters, :capabilities, :tags, :administration_role_arn, :execution_role_name, :permission_model, :auto_deployment, :call_as, :client_request_token, :managed_execution) SENSITIVE = [] include Aws::Structure end |
#permission_model ⇒ String
Describes how the IAM roles required for StackSet operations are
created. By default, SELF-MANAGED is specified.
-
With
self-managedpermissions, you must create the administrator and execution roles required to deploy to target accounts. For more information, see Grant self-managed permissions. -
With
service-managedpermissions, StackSets automatically creates the IAM roles required to deploy to accounts managed by Organizations. For more information, see Activate trusted access for StackSets with Organizations.
1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1952 class CreateStackSetInput < Struct.new( :stack_set_name, :description, :template_body, :template_url, :stack_id, :parameters, :capabilities, :tags, :administration_role_arn, :execution_role_name, :permission_model, :auto_deployment, :call_as, :client_request_token, :managed_execution) SENSITIVE = [] include Aws::Structure end |
#stack_id ⇒ String
The stack ID you are importing into a new StackSet. Specify the Amazon Resource Name (ARN) of the stack.
1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1952 class CreateStackSetInput < Struct.new( :stack_set_name, :description, :template_body, :template_url, :stack_id, :parameters, :capabilities, :tags, :administration_role_arn, :execution_role_name, :permission_model, :auto_deployment, :call_as, :client_request_token, :managed_execution) SENSITIVE = [] include Aws::Structure end |
#stack_set_name ⇒ String
The name to associate with the StackSet. The name must be unique in the Region where you create your StackSet.
1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1952 class CreateStackSetInput < Struct.new( :stack_set_name, :description, :template_body, :template_url, :stack_id, :parameters, :capabilities, :tags, :administration_role_arn, :execution_role_name, :permission_model, :auto_deployment, :call_as, :client_request_token, :managed_execution) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The key-value pairs to associate with this StackSet and the stacks created from it. CloudFormation also propagates these tags to supported resources that are created in the stacks. A maximum number of 50 tags can be specified.
If you specify tags as part of a CreateStackSet action,
CloudFormation checks to see if you have the required IAM permission
to tag resources. If you don't, the entire CreateStackSet action
fails with an access denied error, and the StackSet is not
created.
1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1952 class CreateStackSetInput < Struct.new( :stack_set_name, :description, :template_body, :template_url, :stack_id, :parameters, :capabilities, :tags, :administration_role_arn, :execution_role_name, :permission_model, :auto_deployment, :call_as, :client_request_token, :managed_execution) SENSITIVE = [] include Aws::Structure end |
#template_body ⇒ String
The structure that contains the template body, with a minimum length of 1 byte and a maximum length of 51,200 bytes.
Conditional: You must specify either the TemplateBody or the
TemplateURL parameter, but not both.
1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1952 class CreateStackSetInput < Struct.new( :stack_set_name, :description, :template_body, :template_url, :stack_id, :parameters, :capabilities, :tags, :administration_role_arn, :execution_role_name, :permission_model, :auto_deployment, :call_as, :client_request_token, :managed_execution) SENSITIVE = [] include Aws::Structure end |
#template_url ⇒ String
The URL of a file that contains the template body. The URL must
point to a template (maximum size: 1 MB) that's located in an
Amazon S3 bucket or a Systems Manager document. The location for an
Amazon S3 bucket must start with https://. S3 static website URLs
are not supported.
Conditional: You must specify either the TemplateBody or the
TemplateURL parameter, but not both.
1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1952 class CreateStackSetInput < Struct.new( :stack_set_name, :description, :template_body, :template_url, :stack_id, :parameters, :capabilities, :tags, :administration_role_arn, :execution_role_name, :permission_model, :auto_deployment, :call_as, :client_request_token, :managed_execution) SENSITIVE = [] include Aws::Structure end |