Class: Aws::CloudFormation::Types::DeactivateTypeInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::DeactivateTypeInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) for the extension in this account and Region.
-
#type ⇒ String
The extension type.
-
#type_name ⇒ String
The type name of the extension in this account and Region.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) for the extension in this account and Region.
Conditional: You must specify either Arn, or TypeName and
Type.
2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2054 class DeactivateTypeInput < Struct.new( :type_name, :type, :arn) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The extension type.
Conditional: You must specify either Arn, or TypeName and
Type.
2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2054 class DeactivateTypeInput < Struct.new( :type_name, :type, :arn) SENSITIVE = [] include Aws::Structure end |
#type_name ⇒ String
The type name of the extension in this account and Region. If you specified a type name alias when enabling the extension, use the type name alias.
Conditional: You must specify either Arn, or TypeName and
Type.
2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2054 class DeactivateTypeInput < Struct.new( :type_name, :type, :arn) SENSITIVE = [] include Aws::Structure end |