Class: Aws::CloudFormation::Types::DeleteStackInstancesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::DeleteStackInstancesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accounts ⇒ Array<String>
[Self-managed permissions] The account IDs of the Amazon Web Services accounts that you want to delete stack instances for.
-
#call_as ⇒ String
[Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.
-
#deployment_targets ⇒ Types::DeploymentTargets
[Service-managed permissions] The Organizations accounts from which to delete stack instances.
-
#operation_id ⇒ String
The unique identifier for this StackSet operation.
-
#operation_preferences ⇒ Types::StackSetOperationPreferences
Preferences for how CloudFormation performs this StackSet operation.
-
#regions ⇒ Array<String>
The Amazon Web Services Regions where you want to delete StackSet instances.
-
#retain_stacks ⇒ Boolean
Removes the stack instances from the specified StackSet, but doesn't delete the stacks.
-
#stack_set_name ⇒ String
The name or unique ID of the StackSet that you want to delete stack instances for.
Instance Attribute Details
#accounts ⇒ Array<String>
[Self-managed permissions] The account IDs of the Amazon Web Services accounts that you want to delete stack instances for.
You can specify Accounts or DeploymentTargets, but not both.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2266 class DeleteStackInstancesInput < Struct.new( :stack_set_name, :accounts, :deployment_targets, :regions, :operation_preferences, :retain_stacks, :operation_id, :call_as) SENSITIVE = [] include Aws::Structure end |
#call_as ⇒ String
[Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.
By default, SELF is specified. Use SELF for StackSets with
self-managed permissions.
-
If you are signed in to the management account, specify
SELF. -
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2266 class DeleteStackInstancesInput < Struct.new( :stack_set_name, :accounts, :deployment_targets, :regions, :operation_preferences, :retain_stacks, :operation_id, :call_as) SENSITIVE = [] include Aws::Structure end |
#deployment_targets ⇒ Types::DeploymentTargets
[Service-managed permissions] The Organizations accounts from which to delete stack instances.
You can specify Accounts or DeploymentTargets, but not both.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2266 class DeleteStackInstancesInput < Struct.new( :stack_set_name, :accounts, :deployment_targets, :regions, :operation_preferences, :retain_stacks, :operation_id, :call_as) SENSITIVE = [] include Aws::Structure end |
#operation_id ⇒ String
The unique identifier for this StackSet operation.
If you don't specify an operation ID, the SDK generates one automatically.
The operation ID also functions as an idempotency token, to ensure that CloudFormation performs the StackSet operation only once, even if you retry the request multiple times. You can retry StackSet operation requests to ensure that CloudFormation successfully received them.
Repeating this StackSet operation with a new operation ID retries
all stack instances whose status is OUTDATED.
A suitable default value is auto-generated. You should normally not need to pass this option.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2266 class DeleteStackInstancesInput < Struct.new( :stack_set_name, :accounts, :deployment_targets, :regions, :operation_preferences, :retain_stacks, :operation_id, :call_as) SENSITIVE = [] include Aws::Structure end |
#operation_preferences ⇒ Types::StackSetOperationPreferences
Preferences for how CloudFormation performs this StackSet operation.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2266 class DeleteStackInstancesInput < Struct.new( :stack_set_name, :accounts, :deployment_targets, :regions, :operation_preferences, :retain_stacks, :operation_id, :call_as) SENSITIVE = [] include Aws::Structure end |
#regions ⇒ Array<String>
The Amazon Web Services Regions where you want to delete StackSet instances.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2266 class DeleteStackInstancesInput < Struct.new( :stack_set_name, :accounts, :deployment_targets, :regions, :operation_preferences, :retain_stacks, :operation_id, :call_as) SENSITIVE = [] include Aws::Structure end |
#retain_stacks ⇒ Boolean
Removes the stack instances from the specified StackSet, but doesn't delete the stacks. You can't reassociate a retained stack or add an existing, saved stack to a new stack set.
For more information, see StackSet operation options.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2266 class DeleteStackInstancesInput < Struct.new( :stack_set_name, :accounts, :deployment_targets, :regions, :operation_preferences, :retain_stacks, :operation_id, :call_as) SENSITIVE = [] include Aws::Structure end |
#stack_set_name ⇒ String
The name or unique ID of the StackSet that you want to delete stack instances for.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2266 class DeleteStackInstancesInput < Struct.new( :stack_set_name, :accounts, :deployment_targets, :regions, :operation_preferences, :retain_stacks, :operation_id, :call_as) SENSITIVE = [] include Aws::Structure end |