Class: Aws::CloudFormation::Types::DeploymentConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

The deployment configuration for a stack operation, including the deployment mode.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#disable_rollbackBoolean

Specifies whether to disable rollback of the stack if the stack operation fails.

Default: false

Returns:



2359
2360
2361
2362
2363
2364
# File 'lib/aws-sdk-cloudformation/types.rb', line 2359

class DeploymentConfig < Struct.new(
  :mode,
  :disable_rollback)
  SENSITIVE = []
  include Aws::Structure
end

#modeString

Specifies the deployment mode for the stack operation. Possible values are:

  • STANDARD - Use the standard deployment behavior, ensuring resources are ready to serve traffic before completing the operation. This is the default. You do not need to specify this value explicitly.

  • EXPRESS - Complete the stack operation when resource configuration is applied, without waiting for resources to become ready to serve traffic. Resources continue becoming ready in the background.

Returns:



2359
2360
2361
2362
2363
2364
# File 'lib/aws-sdk-cloudformation/types.rb', line 2359

class DeploymentConfig < Struct.new(
  :mode,
  :disable_rollback)
  SENSITIVE = []
  include Aws::Structure
end