Class: Aws::CloudFormation::Types::DeregisterTypeInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::DeregisterTypeInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the extension.
-
#type ⇒ String
The kind of extension.
-
#type_name ⇒ String
The name of the extension.
-
#version_id ⇒ String
The ID of a specific version of the extension.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the extension.
Conditional: You must specify either TypeName and Type, or Arn.
2406 2407 2408 2409 2410 2411 2412 2413 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2406 class DeregisterTypeInput < Struct.new( :arn, :type, :type_name, :version_id) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The kind of extension.
Conditional: You must specify either TypeName and Type, or Arn.
2406 2407 2408 2409 2410 2411 2412 2413 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2406 class DeregisterTypeInput < Struct.new( :arn, :type, :type_name, :version_id) SENSITIVE = [] include Aws::Structure end |
#type_name ⇒ String
The name of the extension.
Conditional: You must specify either TypeName and Type, or Arn.
2406 2407 2408 2409 2410 2411 2412 2413 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2406 class DeregisterTypeInput < Struct.new( :arn, :type, :type_name, :version_id) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The ID of a specific version of the extension. The version ID is the value at the end of the Amazon Resource Name (ARN) assigned to the extension version when it is registered.
2406 2407 2408 2409 2410 2411 2412 2413 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2406 class DeregisterTypeInput < Struct.new( :arn, :type, :type_name, :version_id) SENSITIVE = [] include Aws::Structure end |