Class: Aws::CloudFormation::Types::DescribeChangeSetInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

The input for the DescribeChangeSet action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#change_set_nameString

The name or Amazon Resource Name (ARN) of the change set that you want to describe.



2621
2622
2623
2624
2625
2626
2627
2628
# File 'lib/aws-sdk-cloudformation/types.rb', line 2621

class DescribeChangeSetInput < Struct.new(
  :change_set_name,
  :stack_name,
  :next_token,
  :include_property_values)
  SENSITIVE = []
  include Aws::Structure
end

#include_property_valuesBoolean

If true, the returned changes include detailed changes in the property values.



2621
2622
2623
2624
2625
2626
2627
2628
# File 'lib/aws-sdk-cloudformation/types.rb', line 2621

class DescribeChangeSetInput < Struct.new(
  :change_set_name,
  :stack_name,
  :next_token,
  :include_property_values)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. (You received this token from a previous call.)



2621
2622
2623
2624
2625
2626
2627
2628
# File 'lib/aws-sdk-cloudformation/types.rb', line 2621

class DescribeChangeSetInput < Struct.new(
  :change_set_name,
  :stack_name,
  :next_token,
  :include_property_values)
  SENSITIVE = []
  include Aws::Structure
end

#stack_nameString

If you specified the name of a change set, specify the stack name or ID (ARN) of the change set you want to describe.



2621
2622
2623
2624
2625
2626
2627
2628
# File 'lib/aws-sdk-cloudformation/types.rb', line 2621

class DescribeChangeSetInput < Struct.new(
  :change_set_name,
  :stack_name,
  :next_token,
  :include_property_values)
  SENSITIVE = []
  include Aws::Structure
end