Class: Aws::CloudFormation::Types::DescribeChangeSetOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

The output for the DescribeChangeSet action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capabilitiesArray<String>

If you execute the change set, the list of capabilities that were explicitly acknowledged when the change set was created.

Returns:

  • (Array<String>)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#change_set_idString

The Amazon Resource Name (ARN) of the change set.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#change_set_nameString

The name of the change set.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#changesArray<Types::Change>

A list of Change structures that describes the resources CloudFormation changes if you execute the change set.

Returns:



2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The start time when the change set was created, in UTC.

Returns:

  • (Time)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_configTypes::DeploymentConfig

The deployment configuration specified when the change set was created.



2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_modeString

The deployment mode specified when the change set was created. Valid value is REVERT_DRIFT. Only present for drift-aware change sets.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Information about the change set.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#execution_statusString

If the change set execution status is AVAILABLE, you can execute the change set. If you can't execute the change set, the status indicates why. For example, a change set might be in an UNAVAILABLE state because CloudFormation is still creating it or in an OBSOLETE state because the stack was already updated.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#import_existing_resourcesBoolean

Indicates if the change set imports resources that already exist.

This parameter can only import resources that have custom names in templates. To import resources that do not accept custom names, such as EC2 instances, use the resource import feature instead.

Returns:

  • (Boolean)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#include_nested_stacksBoolean

Verifies if IncludeNestedStacks is set to True.

Returns:

  • (Boolean)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the output exceeds 1 MB, a string that identifies the next page of changes. If there is no additional page, this value is null.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#notification_arnsArray<String>

The ARNs of the Amazon SNS topics that will be associated with the stack if you execute the change set.

Returns:

  • (Array<String>)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#on_stack_failureString

Determines what action will be taken if stack creation fails. When this parameter is specified, the DisableRollback parameter to the ExecuteChangeSet API operation must not be specified. This must be one of these values:

  • DELETE - Deletes the change set if the stack creation fails. This is only valid when the ChangeSetType parameter is set to CREATE. If the deletion of the stack fails, the status of the stack is DELETE_FAILED.

  • DO_NOTHING - if the stack creation fails, do nothing. This is equivalent to specifying true for the DisableRollback parameter to the ExecuteChangeSet API operation.

  • ROLLBACK - if the stack creation fails, roll back the stack. This is equivalent to specifying false for the DisableRollback parameter to the ExecuteChangeSet API operation.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#parametersArray<Types::Parameter>

A list of Parameter structures that describes the input parameters and their values used to create the change set. For more information, see the Parameter data type.

Returns:



2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#parent_change_set_idString

Specifies the change set ID of the parent change set in the current nested change set hierarchy.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#rollback_configurationTypes::RollbackConfiguration

The rollback triggers for CloudFormation to monitor during stack creation and updating operations, and for the specified monitoring period afterwards.



2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#root_change_set_idString

Specifies the change set ID of the root change set in the current nested change set hierarchy.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#stack_drift_statusString

The drift status of the stack when the change set was created. Valid values:

  • DRIFTED – The stack has drifted from its last deployment.

  • IN_SYNC – The stack is in sync with its last deployment.

  • NOT_CHECKED – CloudFormation doesn’t currently return this value.

  • UNKNOWN – The drift status could not be determined.

Only present for drift-aware change sets.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#stack_idString

The Amazon Resource Name (ARN) of the stack that's associated with the change set.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#stack_nameString

The name of the stack that's associated with the change set.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the change set, such as CREATE_PENDING, CREATE_COMPLETE, or FAILED.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

A description of the change set's status. For example, if your attempt to create a change set failed, CloudFormation shows the error message.

Returns:

  • (String)


2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

If you execute the change set, the tags that will be associated with the stack.

Returns:



2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
# File 'lib/aws-sdk-cloudformation/types.rb', line 2798

class DescribeChangeSetOutput < Struct.new(
  :change_set_name,
  :change_set_id,
  :stack_id,
  :stack_name,
  :description,
  :parameters,
  :creation_time,
  :execution_status,
  :status,
  :status_reason,
  :stack_drift_status,
  :notification_arns,
  :rollback_configuration,
  :capabilities,
  :tags,
  :changes,
  :next_token,
  :include_nested_stacks,
  :parent_change_set_id,
  :root_change_set_id,
  :on_stack_failure,
  :import_existing_resources,
  :deployment_mode,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end