Class: Aws::CloudFormation::Types::DescribeEventsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::DescribeEventsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the request doesn't return all the remaining results,
NextTokenis set to a token. -
#operation_events ⇒ Array<Types::OperationEvent>
A list of operation events that match the specified criteria.
Instance Attribute Details
#next_token ⇒ String
If the request doesn't return all the remaining results,
NextToken is set to a token. To retrieve the next set of results,
call DescribeEvents again and assign that token to the request
object's NextToken parameter. If the request returns all results,
NextToken is set to null.
2878 2879 2880 2881 2882 2883 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2878 class DescribeEventsOutput < Struct.new( :operation_events, :next_token) SENSITIVE = [] include Aws::Structure end |
#operation_events ⇒ Array<Types::OperationEvent>
A list of operation events that match the specified criteria.
2878 2879 2880 2881 2882 2883 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2878 class DescribeEventsOutput < Struct.new( :operation_events, :next_token) SENSITIVE = [] include Aws::Structure end |