Class: Aws::CloudFormation::Types::DescribeOrganizationsAccessInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#call_asString

[Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.

By default, SELF is specified.

  • If you are signed in to the management account, specify SELF.

  • If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN.

    Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.

Returns:



3009
3010
3011
3012
3013
# File 'lib/aws-sdk-cloudformation/types.rb', line 3009

class DescribeOrganizationsAccessInput < Struct.new(
  :call_as)
  SENSITIVE = []
  include Aws::Structure
end