Class: Aws::CloudFormation::Types::DescribeStackDriftDetectionStatusInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::DescribeStackDriftDetectionStatusInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#stack_drift_detection_id ⇒ String
The ID of the drift detection results of this operation.
Instance Attribute Details
#stack_drift_detection_id ⇒ String
The ID of the drift detection results of this operation.
CloudFormation generates new results, with a new drift detection ID, each time this operation is run. However, the number of drift results CloudFormation retains for any given stack, and for how long, may vary.
3182 3183 3184 3185 3186 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 3182 class DescribeStackDriftDetectionStatusInput < Struct.new( :stack_drift_detection_id) SENSITIVE = [] include Aws::Structure end |