Class: Aws::CloudFormation::Types::DescribeStackRefactorInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::DescribeStackRefactorInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#stack_refactor_id ⇒ String
The ID associated with the stack refactor created from the CreateStackRefactor action.
Instance Attribute Details
#stack_refactor_id ⇒ String
The ID associated with the stack refactor created from the CreateStackRefactor action.
3309 3310 3311 3312 3313 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 3309 class DescribeStackRefactorInput < Struct.new( :stack_refactor_id) SENSITIVE = [] include Aws::Structure end |