Class: Aws::CloudFormation::Types::DescribeStackResourceDriftsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::DescribeStackResourceDriftsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the request doesn't return all the remaining results,
NextTokenis set to a token. -
#stack_resource_drifts ⇒ Array<Types::StackResourceDrift>
Drift information for the resources that have been checked for drift in the specified stack.
Instance Attribute Details
#next_token ⇒ String
If the request doesn't return all the remaining results,
NextToken is set to a token. To retrieve the next set of results,
call DescribeStackResourceDrifts again and assign that token to
the request object's NextToken parameter. If the request returns
all results, NextToken is set to null.
3511 3512 3513 3514 3515 3516 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 3511 class DescribeStackResourceDriftsOutput < Struct.new( :stack_resource_drifts, :next_token) SENSITIVE = [] include Aws::Structure end |
#stack_resource_drifts ⇒ Array<Types::StackResourceDrift>
Drift information for the resources that have been checked for drift in the specified stack. This includes actual and expected configuration values for resources where CloudFormation detects drift.
For a given stack, there will be one StackResourceDrift for each
stack resource that has been checked for drift. Resources that
haven't yet been checked for drift aren't included. Resources that
do not currently support drift detection aren't checked, and so not
included. For a list of resources that support drift detection, see
Resource type support for imports and drift detection.
3511 3512 3513 3514 3515 3516 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 3511 class DescribeStackResourceDriftsOutput < Struct.new( :stack_resource_drifts, :next_token) SENSITIVE = [] include Aws::Structure end |