Class: Aws::CloudFormation::Types::DescribeStackResourcesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::DescribeStackResourcesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
The input for DescribeStackResources action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#logical_resource_id ⇒ String
The logical name of the resource as specified in the template.
-
#physical_resource_id ⇒ String
The name or unique identifier that corresponds to a physical instance ID of a resource supported by CloudFormation.
-
#stack_name ⇒ String
The name or the unique stack ID that is associated with the stack, which aren't always interchangeable:.
Instance Attribute Details
#logical_resource_id ⇒ String
The logical name of the resource as specified in the template.
3593 3594 3595 3596 3597 3598 3599 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 3593 class DescribeStackResourcesInput < Struct.new( :stack_name, :logical_resource_id, :physical_resource_id) SENSITIVE = [] include Aws::Structure end |
#physical_resource_id ⇒ String
The name or unique identifier that corresponds to a physical instance ID of a resource supported by CloudFormation.
For example, for an Amazon Elastic Compute Cloud (EC2) instance,
PhysicalResourceId corresponds to the InstanceId. You can pass
the EC2 InstanceId to DescribeStackResources to find which stack
the instance belongs to and what other resources are part of the
stack.
Required: Conditional. If you don't specify PhysicalResourceId,
you must specify StackName.
3593 3594 3595 3596 3597 3598 3599 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 3593 class DescribeStackResourcesInput < Struct.new( :stack_name, :logical_resource_id, :physical_resource_id) SENSITIVE = [] include Aws::Structure end |
#stack_name ⇒ String
The name or the unique stack ID that is associated with the stack, which aren't always interchangeable:
-
Running stacks: You can specify either the stack's name or its unique stack ID.
-
Deleted stacks: You must specify the unique stack ID.
Required: Conditional. If you don't specify StackName, you must
specify PhysicalResourceId.
3593 3594 3595 3596 3597 3598 3599 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 3593 class DescribeStackResourcesInput < Struct.new( :stack_name, :logical_resource_id, :physical_resource_id) SENSITIVE = [] include Aws::Structure end |