Class: Aws::CloudFormation::Types::DescribeTypeInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the extension.

Conditional: You must specify either TypeName and Type, or Arn.

Returns:

  • (String)


3826
3827
3828
3829
3830
3831
3832
3833
3834
3835
# File 'lib/aws-sdk-cloudformation/types.rb', line 3826

class DescribeTypeInput < Struct.new(
  :type,
  :type_name,
  :arn,
  :version_id,
  :publisher_id,
  :public_version_number)
  SENSITIVE = []
  include Aws::Structure
end

#public_version_numberString

The version number of a public third-party extension.

Returns:

  • (String)


3826
3827
3828
3829
3830
3831
3832
3833
3834
3835
# File 'lib/aws-sdk-cloudformation/types.rb', line 3826

class DescribeTypeInput < Struct.new(
  :type,
  :type_name,
  :arn,
  :version_id,
  :publisher_id,
  :public_version_number)
  SENSITIVE = []
  include Aws::Structure
end

#publisher_idString

The publisher ID of the extension publisher.

Extensions provided by Amazon Web Services are not assigned a publisher ID.

Returns:

  • (String)


3826
3827
3828
3829
3830
3831
3832
3833
3834
3835
# File 'lib/aws-sdk-cloudformation/types.rb', line 3826

class DescribeTypeInput < Struct.new(
  :type,
  :type_name,
  :arn,
  :version_id,
  :publisher_id,
  :public_version_number)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The kind of extension.

Conditional: You must specify either TypeName and Type, or Arn.

Returns:

  • (String)


3826
3827
3828
3829
3830
3831
3832
3833
3834
3835
# File 'lib/aws-sdk-cloudformation/types.rb', line 3826

class DescribeTypeInput < Struct.new(
  :type,
  :type_name,
  :arn,
  :version_id,
  :publisher_id,
  :public_version_number)
  SENSITIVE = []
  include Aws::Structure
end

#type_nameString

The name of the extension.

Conditional: You must specify either TypeName and Type, or Arn.

Returns:

  • (String)


3826
3827
3828
3829
3830
3831
3832
3833
3834
3835
# File 'lib/aws-sdk-cloudformation/types.rb', line 3826

class DescribeTypeInput < Struct.new(
  :type,
  :type_name,
  :arn,
  :version_id,
  :publisher_id,
  :public_version_number)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

The ID of a specific version of the extension. The version ID is the value at the end of the Amazon Resource Name (ARN) assigned to the extension version when it is registered.

If you specify a VersionId, DescribeType returns information about that specific extension version. Otherwise, it returns information about the default extension version.

Returns:

  • (String)


3826
3827
3828
3829
3830
3831
3832
3833
3834
3835
# File 'lib/aws-sdk-cloudformation/types.rb', line 3826

class DescribeTypeInput < Struct.new(
  :type,
  :type_name,
  :arn,
  :version_id,
  :publisher_id,
  :public_version_number)
  SENSITIVE = []
  include Aws::Structure
end