Class: Aws::CloudFormation::Types::DetectStackDriftOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::DetectStackDriftOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#stack_drift_detection_id ⇒ String
The ID of the drift detection results of this operation.
Instance Attribute Details
#stack_drift_detection_id ⇒ String
The ID of the drift detection results of this operation.
CloudFormation generates new results, with a new drift detection ID, each time this operation is run. However, the number of drift results CloudFormation retains for any given stack, and for how long, may vary.
4250 4251 4252 4253 4254 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 4250 class DetectStackDriftOutput < Struct.new( :stack_drift_detection_id) SENSITIVE = [] include Aws::Structure end |