Class: Aws::CloudFormation::Types::ExecuteStackRefactorInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ExecuteStackRefactorInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#stack_refactor_id ⇒ String
The ID associated with the stack refactor created from the CreateStackRefactor action.
Instance Attribute Details
#stack_refactor_id ⇒ String
The ID associated with the stack refactor created from the CreateStackRefactor action.
4425 4426 4427 4428 4429 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 4425 class ExecuteStackRefactorInput < Struct.new( :stack_refactor_id) SENSITIVE = [] include Aws::Structure end |