Class: Aws::CloudFormation::Types::GetHookResultInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::GetHookResultInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hook_result_id ⇒ String
The unique identifier (ID) of the Hook invocation result that you want details about.
Instance Attribute Details
#hook_result_id ⇒ String
The unique identifier (ID) of the Hook invocation result that you want details about. You can get the ID from the ListHookResults operation.
4623 4624 4625 4626 4627 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 4623 class GetHookResultInput < Struct.new( :hook_result_id) SENSITIVE = [] include Aws::Structure end |