Class: Aws::CloudFormation::Types::GetTemplateInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::GetTemplateInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
The input for a GetTemplate action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#change_set_name ⇒ String
The name or Amazon Resource Name (ARN) of a change set for which CloudFormation returns the associated template.
-
#stack_name ⇒ String
The name or the unique stack ID that's associated with the stack, which aren't always interchangeable:.
-
#template_stage ⇒ String
For templates that include transforms, the stage of the template that CloudFormation returns.
Instance Attribute Details
#change_set_name ⇒ String
The name or Amazon Resource Name (ARN) of a change set for which
CloudFormation returns the associated template. If you specify a
name, you must also specify the StackName.
4785 4786 4787 4788 4789 4790 4791 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 4785 class GetTemplateInput < Struct.new( :stack_name, :change_set_name, :template_stage) SENSITIVE = [] include Aws::Structure end |
#stack_name ⇒ String
The name or the unique stack ID that's associated with the stack, which aren't always interchangeable:
-
Running stacks: You can specify either the stack's name or its unique stack ID.
-
Deleted stacks: You must specify the unique stack ID.
4785 4786 4787 4788 4789 4790 4791 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 4785 class GetTemplateInput < Struct.new( :stack_name, :change_set_name, :template_stage) SENSITIVE = [] include Aws::Structure end |
#template_stage ⇒ String
For templates that include transforms, the stage of the template
that CloudFormation returns. To get the user-submitted template,
specify Original. To get the template after CloudFormation has
processed all transforms, specify Processed.
If the template doesn't include transforms, Original and
Processed return the same template. By default, CloudFormation
specifies Processed.
4785 4786 4787 4788 4789 4790 4791 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 4785 class GetTemplateInput < Struct.new( :stack_name, :change_set_name, :template_stage) SENSITIVE = [] include Aws::Structure end |