Class: Aws::CloudFormation::Types::GetTemplateOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

The output for GetTemplate action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#stages_availableArray<String>

The stage of the template that you can retrieve. For stacks, the Original and Processed templates are always available. For change sets, the Original template is always available. After CloudFormation finishes creating the change set, the Processed template becomes available.



4812
4813
4814
4815
4816
4817
# File 'lib/aws-sdk-cloudformation/types.rb', line 4812

class GetTemplateOutput < Struct.new(
  :template_body,
  :stages_available)
  SENSITIVE = []
  include Aws::Structure
end

#template_bodyString

Structure that contains the template body.

CloudFormation returns the same template that was used when the stack was created.



4812
4813
4814
4815
4816
4817
# File 'lib/aws-sdk-cloudformation/types.rb', line 4812

class GetTemplateOutput < Struct.new(
  :template_body,
  :stages_available)
  SENSITIVE = []
  include Aws::Structure
end