Class: Aws::CloudFormation::Types::HookResultSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

A ListHookResults call returns a summary of a Hook invocation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failure_modeString

The failure mode of the invocation.

Returns:

  • (String)


5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
# File 'lib/aws-sdk-cloudformation/types.rb', line 5059

class HookResultSummary < Struct.new(
  :hook_result_id,
  :invocation_point,
  :failure_mode,
  :type_name,
  :type_version_id,
  :type_configuration_version_id,
  :status,
  :hook_status_reason,
  :invoked_at,
  :target_type,
  :target_id,
  :type_arn,
  :hook_execution_target)
  SENSITIVE = []
  include Aws::Structure
end

#hook_execution_targetString

The Amazon Resource Name (ARN) of the target stack or request token of the Cloud Control API operation.

Only shown in responses when the request does not specify TargetType and TargetId filters.

Returns:

  • (String)


5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
# File 'lib/aws-sdk-cloudformation/types.rb', line 5059

class HookResultSummary < Struct.new(
  :hook_result_id,
  :invocation_point,
  :failure_mode,
  :type_name,
  :type_version_id,
  :type_configuration_version_id,
  :status,
  :hook_status_reason,
  :invoked_at,
  :target_type,
  :target_id,
  :type_arn,
  :hook_execution_target)
  SENSITIVE = []
  include Aws::Structure
end

#hook_result_idString

The unique identifier for this Hook invocation result.

Returns:

  • (String)


5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
# File 'lib/aws-sdk-cloudformation/types.rb', line 5059

class HookResultSummary < Struct.new(
  :hook_result_id,
  :invocation_point,
  :failure_mode,
  :type_name,
  :type_version_id,
  :type_configuration_version_id,
  :status,
  :hook_status_reason,
  :invoked_at,
  :target_type,
  :target_id,
  :type_arn,
  :hook_execution_target)
  SENSITIVE = []
  include Aws::Structure
end

#hook_status_reasonString

A description of the Hook results status. For example, if the Hook result is in a failed state, this may contain additional information for the failed state.

Returns:

  • (String)


5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
# File 'lib/aws-sdk-cloudformation/types.rb', line 5059

class HookResultSummary < Struct.new(
  :hook_result_id,
  :invocation_point,
  :failure_mode,
  :type_name,
  :type_version_id,
  :type_configuration_version_id,
  :status,
  :hook_status_reason,
  :invoked_at,
  :target_type,
  :target_id,
  :type_arn,
  :hook_execution_target)
  SENSITIVE = []
  include Aws::Structure
end

#invocation_pointString

The specific point in the provisioning process where the Hook is invoked.

Returns:

  • (String)


5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
# File 'lib/aws-sdk-cloudformation/types.rb', line 5059

class HookResultSummary < Struct.new(
  :hook_result_id,
  :invocation_point,
  :failure_mode,
  :type_name,
  :type_version_id,
  :type_configuration_version_id,
  :status,
  :hook_status_reason,
  :invoked_at,
  :target_type,
  :target_id,
  :type_arn,
  :hook_execution_target)
  SENSITIVE = []
  include Aws::Structure
end

#invoked_atTime

The timestamp when the Hook was invoked.

Only shown in responses when the request does not specify TargetType and TargetId filters.

Returns:

  • (Time)


5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
# File 'lib/aws-sdk-cloudformation/types.rb', line 5059

class HookResultSummary < Struct.new(
  :hook_result_id,
  :invocation_point,
  :failure_mode,
  :type_name,
  :type_version_id,
  :type_configuration_version_id,
  :status,
  :hook_status_reason,
  :invoked_at,
  :target_type,
  :target_id,
  :type_arn,
  :hook_execution_target)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the Hook invocation. The following statuses are possible:

  • HOOK_IN_PROGRESS: The Hook is currently running.

  • HOOK_COMPLETE_SUCCEEDED: The Hook completed successfully.

  • HOOK_COMPLETE_FAILED: The Hook completed but failed validation.

  • HOOK_FAILED: The Hook encountered an error during execution.

Returns:

  • (String)


5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
# File 'lib/aws-sdk-cloudformation/types.rb', line 5059

class HookResultSummary < Struct.new(
  :hook_result_id,
  :invocation_point,
  :failure_mode,
  :type_name,
  :type_version_id,
  :type_configuration_version_id,
  :status,
  :hook_status_reason,
  :invoked_at,
  :target_type,
  :target_id,
  :type_arn,
  :hook_execution_target)
  SENSITIVE = []
  include Aws::Structure
end

#target_idString

The unique identifier of the Hook invocation target.

Returns:

  • (String)


5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
# File 'lib/aws-sdk-cloudformation/types.rb', line 5059

class HookResultSummary < Struct.new(
  :hook_result_id,
  :invocation_point,
  :failure_mode,
  :type_name,
  :type_version_id,
  :type_configuration_version_id,
  :status,
  :hook_status_reason,
  :invoked_at,
  :target_type,
  :target_id,
  :type_arn,
  :hook_execution_target)
  SENSITIVE = []
  include Aws::Structure
end

#target_typeString

The target type that the Hook was invoked against.

Returns:

  • (String)


5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
# File 'lib/aws-sdk-cloudformation/types.rb', line 5059

class HookResultSummary < Struct.new(
  :hook_result_id,
  :invocation_point,
  :failure_mode,
  :type_name,
  :type_version_id,
  :type_configuration_version_id,
  :status,
  :hook_status_reason,
  :invoked_at,
  :target_type,
  :target_id,
  :type_arn,
  :hook_execution_target)
  SENSITIVE = []
  include Aws::Structure
end

#type_arnString

The ARN of the Hook that was invoked.

Returns:

  • (String)


5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
# File 'lib/aws-sdk-cloudformation/types.rb', line 5059

class HookResultSummary < Struct.new(
  :hook_result_id,
  :invocation_point,
  :failure_mode,
  :type_name,
  :type_version_id,
  :type_configuration_version_id,
  :status,
  :hook_status_reason,
  :invoked_at,
  :target_type,
  :target_id,
  :type_arn,
  :hook_execution_target)
  SENSITIVE = []
  include Aws::Structure
end

#type_configuration_version_idString

The version of the Hook configuration.

Returns:

  • (String)


5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
# File 'lib/aws-sdk-cloudformation/types.rb', line 5059

class HookResultSummary < Struct.new(
  :hook_result_id,
  :invocation_point,
  :failure_mode,
  :type_name,
  :type_version_id,
  :type_configuration_version_id,
  :status,
  :hook_status_reason,
  :invoked_at,
  :target_type,
  :target_id,
  :type_arn,
  :hook_execution_target)
  SENSITIVE = []
  include Aws::Structure
end

#type_nameString

The name of the Hook that was invoked.

Returns:

  • (String)


5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
# File 'lib/aws-sdk-cloudformation/types.rb', line 5059

class HookResultSummary < Struct.new(
  :hook_result_id,
  :invocation_point,
  :failure_mode,
  :type_name,
  :type_version_id,
  :type_configuration_version_id,
  :status,
  :hook_status_reason,
  :invoked_at,
  :target_type,
  :target_id,
  :type_arn,
  :hook_execution_target)
  SENSITIVE = []
  include Aws::Structure
end

#type_version_idString

The version of the Hook that was invoked.

Returns:

  • (String)


5059
5060
5061
5062
5063
5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
# File 'lib/aws-sdk-cloudformation/types.rb', line 5059

class HookResultSummary < Struct.new(
  :hook_result_id,
  :invocation_point,
  :failure_mode,
  :type_name,
  :type_version_id,
  :type_configuration_version_id,
  :status,
  :hook_status_reason,
  :invoked_at,
  :target_type,
  :target_id,
  :type_arn,
  :hook_execution_target)
  SENSITIVE = []
  include Aws::Structure
end