Class: Aws::CloudFormation::Types::ImportStacksToStackSetInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#call_asString

By default, ‘SELF` is specified. Use `SELF` for StackSets with self-managed permissions.

  • If you are signed in to the management account, specify ‘SELF`.

  • For service managed StackSets, specify ‘DELEGATED_ADMIN`.

Returns:

  • (String)


5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
# File 'lib/aws-sdk-cloudformation/types.rb', line 5083

class ImportStacksToStackSetInput < Struct.new(
  :stack_set_name,
  :stack_ids,
  :stack_ids_url,
  :organizational_unit_ids,
  :operation_preferences,
  :operation_id,
  :call_as)
  SENSITIVE = []
  include Aws::Structure
end

#operation_idString

A unique, user defined, identifier for the StackSet operation.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
# File 'lib/aws-sdk-cloudformation/types.rb', line 5083

class ImportStacksToStackSetInput < Struct.new(
  :stack_set_name,
  :stack_ids,
  :stack_ids_url,
  :organizational_unit_ids,
  :operation_preferences,
  :operation_id,
  :call_as)
  SENSITIVE = []
  include Aws::Structure
end

#operation_preferencesTypes::StackSetOperationPreferences

The user-specified preferences for how CloudFormation performs a StackSet operation.

For more information about maximum concurrent accounts and failure tolerance, see [StackSet operation options].

[1]: docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-concepts.html#stackset-ops-options



5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
# File 'lib/aws-sdk-cloudformation/types.rb', line 5083

class ImportStacksToStackSetInput < Struct.new(
  :stack_set_name,
  :stack_ids,
  :stack_ids_url,
  :organizational_unit_ids,
  :operation_preferences,
  :operation_id,
  :call_as)
  SENSITIVE = []
  include Aws::Structure
end

#organizational_unit_idsArray<String>

The list of OU ID’s to which the imported stacks must be mapped as deployment targets.

Returns:

  • (Array<String>)


5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
# File 'lib/aws-sdk-cloudformation/types.rb', line 5083

class ImportStacksToStackSetInput < Struct.new(
  :stack_set_name,
  :stack_ids,
  :stack_ids_url,
  :organizational_unit_ids,
  :operation_preferences,
  :operation_id,
  :call_as)
  SENSITIVE = []
  include Aws::Structure
end

#stack_idsArray<String>

The IDs of the stacks you are importing into a StackSet. You import up to 10 stacks per StackSet at a time.

Specify either ‘StackIds` or `StackIdsUrl`.

Returns:

  • (Array<String>)


5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
# File 'lib/aws-sdk-cloudformation/types.rb', line 5083

class ImportStacksToStackSetInput < Struct.new(
  :stack_set_name,
  :stack_ids,
  :stack_ids_url,
  :organizational_unit_ids,
  :operation_preferences,
  :operation_id,
  :call_as)
  SENSITIVE = []
  include Aws::Structure
end

#stack_ids_urlString

The Amazon S3 URL which contains list of stack ids to be inputted.

Specify either ‘StackIds` or `StackIdsUrl`.

Returns:

  • (String)


5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
# File 'lib/aws-sdk-cloudformation/types.rb', line 5083

class ImportStacksToStackSetInput < Struct.new(
  :stack_set_name,
  :stack_ids,
  :stack_ids_url,
  :organizational_unit_ids,
  :operation_preferences,
  :operation_id,
  :call_as)
  SENSITIVE = []
  include Aws::Structure
end

#stack_set_nameString

The name of the StackSet. The name must be unique in the Region where you create your StackSet.

Returns:

  • (String)


5083
5084
5085
5086
5087
5088
5089
5090
5091
5092
5093
# File 'lib/aws-sdk-cloudformation/types.rb', line 5083

class ImportStacksToStackSetInput < Struct.new(
  :stack_set_name,
  :stack_ids,
  :stack_ids_url,
  :organizational_unit_ids,
  :operation_preferences,
  :operation_id,
  :call_as)
  SENSITIVE = []
  include Aws::Structure
end