Class: Aws::CloudFormation::Types::ListChangeSetsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ListChangeSetsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
The input for the ListChangeSets action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token for the next set of items to return.
-
#stack_name ⇒ String
The name or the Amazon Resource Name (ARN) of the stack for which you want to list change sets.
Instance Attribute Details
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5166 class ListChangeSetsInput < Struct.new( :stack_name, :next_token) SENSITIVE = [] include Aws::Structure end |
#stack_name ⇒ String
The name or the Amazon Resource Name (ARN) of the stack for which you want to list change sets.
5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5166 class ListChangeSetsInput < Struct.new( :stack_name, :next_token) SENSITIVE = [] include Aws::Structure end |