Class: Aws::CloudFormation::Types::ListGeneratedTemplatesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

If the number of available results exceeds this maximum, the response includes a NextToken value that you can use for the NextToken parameter to get the next set of results. By default the ListGeneratedTemplates API action will return at most 50 results in each response. The maximum value is 100.

Returns:

  • (Integer)


5242
5243
5244
5245
5246
5247
# File 'lib/aws-sdk-cloudformation/types.rb', line 5242

class ListGeneratedTemplatesInput < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. (You received this token from a previous call.)

Returns:

  • (String)


5242
5243
5244
5245
5246
5247
# File 'lib/aws-sdk-cloudformation/types.rb', line 5242

class ListGeneratedTemplatesInput < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end