Class: Aws::CloudFormation::Types::ListHookResultsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token for the next set of items to return. (You received this token from a previous call.)

Returns:

  • (String)


5319
5320
5321
5322
5323
5324
5325
5326
5327
# File 'lib/aws-sdk-cloudformation/types.rb', line 5319

class ListHookResultsInput < Struct.new(
  :target_type,
  :target_id,
  :type_arn,
  :status,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Filters results by the status of Hook invocations. Can only be used in combination with TypeArn. Valid values are:

  • HOOK_IN_PROGRESS: The Hook is currently running.

  • HOOK_COMPLETE_SUCCEEDED: The Hook completed successfully.

  • HOOK_COMPLETE_FAILED: The Hook completed but failed validation.

  • HOOK_FAILED: The Hook encountered an error during execution.

Returns:

  • (String)


5319
5320
5321
5322
5323
5324
5325
5326
5327
# File 'lib/aws-sdk-cloudformation/types.rb', line 5319

class ListHookResultsInput < Struct.new(
  :target_type,
  :target_id,
  :type_arn,
  :status,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#target_idString

Filters results by the unique identifier of the target the Hook was invoked against.

For change sets, this is the change set ARN. When the target is a Cloud Control API operation, this value must be the HookRequestToken returned by the Cloud Control API request. For more information on the HookRequestToken, see [ProgressEvent].

Required when TargetType is specified and cannot be used otherwise.

[1]: docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_ProgressEvent.html

Returns:

  • (String)


5319
5320
5321
5322
5323
5324
5325
5326
5327
# File 'lib/aws-sdk-cloudformation/types.rb', line 5319

class ListHookResultsInput < Struct.new(
  :target_type,
  :target_id,
  :type_arn,
  :status,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#target_typeString

Filters results by target type. Currently, only CHANGE_SET and CLOUD_CONTROL are supported filter options.

Required when TargetId is specified and cannot be used otherwise.

Returns:

  • (String)


5319
5320
5321
5322
5323
5324
5325
5326
5327
# File 'lib/aws-sdk-cloudformation/types.rb', line 5319

class ListHookResultsInput < Struct.new(
  :target_type,
  :target_id,
  :type_arn,
  :status,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#type_arnString

Filters results by the ARN of the Hook. Can be used alone or in combination with Status.

Returns:

  • (String)


5319
5320
5321
5322
5323
5324
5325
5326
5327
# File 'lib/aws-sdk-cloudformation/types.rb', line 5319

class ListHookResultsInput < Struct.new(
  :target_type,
  :target_id,
  :type_arn,
  :status,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end