Class: Aws::CloudFormation::Types::ListImportsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#export_nameString

The name of the exported output value. CloudFormation returns the stack names that are importing this value.



5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-cloudformation/types.rb', line 5370

class ListImportsInput < Struct.new(
  :export_name,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. (You received this token from a previous call.)



5370
5371
5372
5373
5374
5375
# File 'lib/aws-sdk-cloudformation/types.rb', line 5370

class ListImportsInput < Struct.new(
  :export_name,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end