Class: Aws::CloudFormation::Types::ListResourceScanRelatedResourcesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

If the number of available results exceeds this maximum, the response includes a NextToken value that you can use for the NextToken parameter to get the next set of results. By default the ListResourceScanRelatedResources API action will return up to 100 results in each response. The maximum value is 100.

Returns:

  • (Integer)


5420
5421
5422
5423
5424
5425
5426
5427
# File 'lib/aws-sdk-cloudformation/types.rb', line 5420

class ListResourceScanRelatedResourcesInput < Struct.new(
  :resource_scan_id,
  :resources,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. (You received this token from a previous call.)

Returns:

  • (String)


5420
5421
5422
5423
5424
5425
5426
5427
# File 'lib/aws-sdk-cloudformation/types.rb', line 5420

class ListResourceScanRelatedResourcesInput < Struct.new(
  :resource_scan_id,
  :resources,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#resource_scan_idString

The Amazon Resource Name (ARN) of the resource scan.

Returns:

  • (String)


5420
5421
5422
5423
5424
5425
5426
5427
# File 'lib/aws-sdk-cloudformation/types.rb', line 5420

class ListResourceScanRelatedResourcesInput < Struct.new(
  :resource_scan_id,
  :resources,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#resourcesArray<Types::ScannedResourceIdentifier>

The list of resources for which you want to get the related resources. Up to 100 resources can be provided.



5420
5421
5422
5423
5424
5425
5426
5427
# File 'lib/aws-sdk-cloudformation/types.rb', line 5420

class ListResourceScanRelatedResourcesInput < Struct.new(
  :resource_scan_id,
  :resources,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end