Class: Aws::CloudFormation::Types::ListResourceScanResourcesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

If the number of available results exceeds this maximum, the response includes a NextToken value that you can use for the NextToken parameter to get the next set of results. By default the ListResourceScanResources API action will return at most 100 results in each response. The maximum value is 100.

Returns:

  • (Integer)


5489
5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
# File 'lib/aws-sdk-cloudformation/types.rb', line 5489

class ListResourceScanResourcesInput < Struct.new(
  :resource_scan_id,
  :resource_identifier,
  :resource_type_prefix,
  :tag_key,
  :tag_value,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. (You received this token from a previous call.)

Returns:

  • (String)


5489
5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
# File 'lib/aws-sdk-cloudformation/types.rb', line 5489

class ListResourceScanResourcesInput < Struct.new(
  :resource_scan_id,
  :resource_identifier,
  :resource_type_prefix,
  :tag_key,
  :tag_value,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#resource_identifierString

If specified, the returned resources will have the specified resource identifier (or one of them in the case where the resource has multiple identifiers).

Returns:

  • (String)


5489
5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
# File 'lib/aws-sdk-cloudformation/types.rb', line 5489

class ListResourceScanResourcesInput < Struct.new(
  :resource_scan_id,
  :resource_identifier,
  :resource_type_prefix,
  :tag_key,
  :tag_value,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#resource_scan_idString

The Amazon Resource Name (ARN) of the resource scan.

Returns:

  • (String)


5489
5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
# File 'lib/aws-sdk-cloudformation/types.rb', line 5489

class ListResourceScanResourcesInput < Struct.new(
  :resource_scan_id,
  :resource_identifier,
  :resource_type_prefix,
  :tag_key,
  :tag_value,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#resource_type_prefixString

If specified, the returned resources will be of any of the resource types with the specified prefix.

Returns:

  • (String)


5489
5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
# File 'lib/aws-sdk-cloudformation/types.rb', line 5489

class ListResourceScanResourcesInput < Struct.new(
  :resource_scan_id,
  :resource_identifier,
  :resource_type_prefix,
  :tag_key,
  :tag_value,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#tag_keyString

If specified, the returned resources will have a matching tag key.

Returns:

  • (String)


5489
5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
# File 'lib/aws-sdk-cloudformation/types.rb', line 5489

class ListResourceScanResourcesInput < Struct.new(
  :resource_scan_id,
  :resource_identifier,
  :resource_type_prefix,
  :tag_key,
  :tag_value,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#tag_valueString

If specified, the returned resources will have a matching tag value.

Returns:

  • (String)


5489
5490
5491
5492
5493
5494
5495
5496
5497
5498
5499
# File 'lib/aws-sdk-cloudformation/types.rb', line 5489

class ListResourceScanResourcesInput < Struct.new(
  :resource_scan_id,
  :resource_identifier,
  :resource_type_prefix,
  :tag_key,
  :tag_value,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end