Class: Aws::CloudFormation::Types::ListResourceScansInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

If the number of available results exceeds this maximum, the response includes a NextToken value that you can use for the NextToken parameter to get the next set of results. The default value is 10. The maximum value is 100.

Returns:

  • (Integer)


5542
5543
5544
5545
5546
5547
5548
# File 'lib/aws-sdk-cloudformation/types.rb', line 5542

class ListResourceScansInput < Struct.new(
  :next_token,
  :max_results,
  :scan_type_filter)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. (You received this token from a previous call.)

Returns:

  • (String)


5542
5543
5544
5545
5546
5547
5548
# File 'lib/aws-sdk-cloudformation/types.rb', line 5542

class ListResourceScansInput < Struct.new(
  :next_token,
  :max_results,
  :scan_type_filter)
  SENSITIVE = []
  include Aws::Structure
end

#scan_type_filterString

The scan type that you want to get summary information about. The default is FULL.

Returns:

  • (String)


5542
5543
5544
5545
5546
5547
5548
# File 'lib/aws-sdk-cloudformation/types.rb', line 5542

class ListResourceScansInput < Struct.new(
  :next_token,
  :max_results,
  :scan_type_filter)
  SENSITIVE = []
  include Aws::Structure
end