Class: Aws::CloudFormation::Types::ListStackInstancesOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If the request doesn’t return all the remaining results, NextToken is set to a token. To retrieve the next set of results, call ListStackInstances again and assign that token to the request object’s NextToken parameter. If the request returns all results, NextToken is set to null.

Returns:

  • (String)


5760
5761
5762
5763
5764
5765
# File 'lib/aws-sdk-cloudformation/types.rb', line 5760

class ListStackInstancesOutput < Struct.new(
  :summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#summariesArray<Types::StackInstanceSummary>

A list of StackInstanceSummary structures that contain information about the specified stack instances.

Returns:



5760
5761
5762
5763
5764
5765
# File 'lib/aws-sdk-cloudformation/types.rb', line 5760

class ListStackInstancesOutput < Struct.new(
  :summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end