Class: Aws::CloudFormation::Types::ListStackRefactorActionsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If the request doesn’t return all the remaining results, NextToken is set to a token. To retrieve the next set of results, call this action again and assign that token to the request object’s NextToken parameter. If the request returns all results, NextToken is set to null.

Returns:

  • (String)


5808
5809
5810
5811
5812
5813
# File 'lib/aws-sdk-cloudformation/types.rb', line 5808

class ListStackRefactorActionsOutput < Struct.new(
  :stack_refactor_actions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#stack_refactor_actionsArray<Types::StackRefactorAction>

The stack refactor actions.

Returns:



5808
5809
5810
5811
5812
5813
# File 'lib/aws-sdk-cloudformation/types.rb', line 5808

class ListStackRefactorActionsOutput < Struct.new(
  :stack_refactor_actions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end