Class: Aws::CloudFormation::Types::ListStackRefactorsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#execution_status_filterArray<String>

Execution status to use as a filter. Specify one or more execution status codes to list only stack refactors with the specified execution status codes.

Returns:

  • (Array<String>)


5835
5836
5837
5838
5839
5840
5841
# File 'lib/aws-sdk-cloudformation/types.rb', line 5835

class ListStackRefactorsInput < Struct.new(
  :execution_status_filter,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to be returned with a single call. If the number of available results exceeds this maximum, the response includes a NextToken value that you can assign to the NextToken request parameter to get the next set of results.

Returns:

  • (Integer)


5835
5836
5837
5838
5839
5840
5841
# File 'lib/aws-sdk-cloudformation/types.rb', line 5835

class ListStackRefactorsInput < Struct.new(
  :execution_status_filter,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. (You received this token from a previous call.)

Returns:

  • (String)


5835
5836
5837
5838
5839
5840
5841
# File 'lib/aws-sdk-cloudformation/types.rb', line 5835

class ListStackRefactorsInput < Struct.new(
  :execution_status_filter,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end