Class: Aws::CloudFormation::Types::ListStackResourcesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

The input for the ListStackResource action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The token for the next set of items to return. (You received this token from a previous call.)

Returns:

  • (String)


5895
5896
5897
5898
5899
5900
# File 'lib/aws-sdk-cloudformation/types.rb', line 5895

class ListStackResourcesInput < Struct.new(
  :stack_name,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#stack_nameString

The name or the unique stack ID that is associated with the stack, which aren’t always interchangeable:

  • Running stacks: You can specify either the stack’s name or its unique stack ID.

  • Deleted stacks: You must specify the unique stack ID.

Returns:

  • (String)


5895
5896
5897
5898
5899
5900
# File 'lib/aws-sdk-cloudformation/types.rb', line 5895

class ListStackResourcesInput < Struct.new(
  :stack_name,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end