Class: Aws::CloudFormation::Types::ListStackSetOperationResultsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ListStackSetOperationResultsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#call_as ⇒ String
[Service-managed permissions] Specifies whether you are acting as an account administrator in the organization’s management account or as a delegated administrator in a member account.
-
#filters ⇒ Array<Types::OperationResultFilter>
The filter to apply to operation results.
-
#max_results ⇒ Integer
The maximum number of results to be returned with a single call.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#operation_id ⇒ String
The ID of the StackSet operation.
-
#stack_set_name ⇒ String
The name or unique ID of the StackSet that you want to get operation results for.
Instance Attribute Details
#call_as ⇒ String
[Service-managed permissions] Specifies whether you are acting as an account administrator in the organization’s management account or as a delegated administrator in a member account.
By default, SELF is specified. Use SELF for StackSets with self-managed permissions.
-
If you are signed in to the management account, specify
SELF. -
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see
- Register a delegated administrator][1
-
in the *CloudFormation
User Guide*.
[1]: docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-orgs-delegated-admin.html
6049 6050 6051 6052 6053 6054 6055 6056 6057 6058 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6049 class ListStackSetOperationResultsInput < Struct.new( :stack_set_name, :operation_id, :next_token, :max_results, :call_as, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::OperationResultFilter>
The filter to apply to operation results.
6049 6050 6051 6052 6053 6054 6055 6056 6057 6058 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6049 class ListStackSetOperationResultsInput < Struct.new( :stack_set_name, :operation_id, :next_token, :max_results, :call_as, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to be returned with a single call. If the number of available results exceeds this maximum, the response includes a NextToken value that you can assign to the NextToken request parameter to get the next set of results.
6049 6050 6051 6052 6053 6054 6055 6056 6057 6058 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6049 class ListStackSetOperationResultsInput < Struct.new( :stack_set_name, :operation_id, :next_token, :max_results, :call_as, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
6049 6050 6051 6052 6053 6054 6055 6056 6057 6058 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6049 class ListStackSetOperationResultsInput < Struct.new( :stack_set_name, :operation_id, :next_token, :max_results, :call_as, :filters) SENSITIVE = [] include Aws::Structure end |
#operation_id ⇒ String
The ID of the StackSet operation.
6049 6050 6051 6052 6053 6054 6055 6056 6057 6058 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6049 class ListStackSetOperationResultsInput < Struct.new( :stack_set_name, :operation_id, :next_token, :max_results, :call_as, :filters) SENSITIVE = [] include Aws::Structure end |
#stack_set_name ⇒ String
The name or unique ID of the StackSet that you want to get operation results for.
6049 6050 6051 6052 6053 6054 6055 6056 6057 6058 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6049 class ListStackSetOperationResultsInput < Struct.new( :stack_set_name, :operation_id, :next_token, :max_results, :call_as, :filters) SENSITIVE = [] include Aws::Structure end |