Class: Aws::CloudFormation::Types::ListTypeRegistrationsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If the request doesn’t return all the remaining results, NextToken is set to a token. To retrieve the next set of results, call this action again and assign that token to the request object’s NextToken parameter. If the request returns all results, NextToken is set to null.

Returns:

  • (String)


6343
6344
6345
6346
6347
6348
# File 'lib/aws-sdk-cloudformation/types.rb', line 6343

class ListTypeRegistrationsOutput < Struct.new(
  :registration_token_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#registration_token_listArray<String>

A list of extension registration tokens.

Use DescribeTypeRegistration to return detailed information about a type registration request.

Returns:

  • (Array<String>)


6343
6344
6345
6346
6347
6348
# File 'lib/aws-sdk-cloudformation/types.rb', line 6343

class ListTypeRegistrationsOutput < Struct.new(
  :registration_token_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end