Class: Aws::CloudFormation::Types::LoggingConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Contains logging configuration information for an extension.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#log_group_nameString

The Amazon CloudWatch Logs group to which CloudFormation sends error logging information when invoking the extension's handlers.



6675
6676
6677
6678
6679
6680
# File 'lib/aws-sdk-cloudformation/types.rb', line 6675

class LoggingConfig < Struct.new(
  :log_role_arn,
  :log_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#log_role_arnString

The Amazon Resource Name (ARN) of the role that CloudFormation should assume when sending log entries to CloudWatch Logs.



6675
6676
6677
6678
6679
6680
# File 'lib/aws-sdk-cloudformation/types.rb', line 6675

class LoggingConfig < Struct.new(
  :log_role_arn,
  :log_group_name)
  SENSITIVE = []
  include Aws::Structure
end