Class: Aws::CloudFormation::Types::ManagedExecution

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Describes whether StackSets performs non-conflicting operations concurrently and queues conflicting operations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#activeBoolean

When true, CloudFormation performs non-conflicting operations concurrently and queues conflicting operations. After conflicting operations finish, CloudFormation starts queued operations in request order.

If there are already running or queued operations, CloudFormation queues all incoming operations even if they are non-conflicting.

You can't modify your StackSet's execution configuration while there are running or queued operations for that StackSet.

When false (default), StackSets performs one operation at a time in request order.



6705
6706
6707
6708
6709
# File 'lib/aws-sdk-cloudformation/types.rb', line 6705

class ManagedExecution < Struct.new(
  :active)
  SENSITIVE = []
  include Aws::Structure
end