Class: Aws::CloudFormation::Types::OperationEvent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Contains detailed information about an event that occurred during a CloudFormation operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_tokenString

A unique identifier for the request that initiated this operation.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#detailed_statusString

Additional status information about the operation.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The time when the event ended.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#event_idString

A unique identifier for this event.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#event_typeString

The type of event.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#hook_failure_modeString

Specifies how Hook failures are handled.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#hook_invocation_pointString

The point in the operation lifecycle when the Hook was invoked.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#hook_statusString

The status of the Hook invocation.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#hook_status_reasonString

Additional information about the Hook status.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#hook_typeString

The type name of the Hook that was invoked.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#logical_resource_idString

The logical name of the resource as specified in the template.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#operation_idString

The unique identifier of the operation this event belongs to.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#operation_statusString

The current status of the operation.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#operation_typeString

The type of operation.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#physical_resource_idString

The name or unique identifier that corresponds to a physical instance ID of a resource.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#resource_propertiesString

The properties used to create the resource.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#resource_statusString

Current status of the resource.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#resource_status_reasonString

Success or failure message associated with the resource.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

Type of resource.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#stack_idString

The unique ID name of the instance of the stack.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The time when the event started.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

Time the status was updated.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#validation_failure_modeString

Specifies how validation failures are handled.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#validation_nameString

The name of the validation that was performed.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#validation_pathString

The path within the resource where the validation was applied.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#validation_statusString

The status of the validation.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end

#validation_status_reasonString

Additional information about the validation status.



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
6930
6931
# File 'lib/aws-sdk-cloudformation/types.rb', line 6901

class OperationEvent < Struct.new(
  :event_id,
  :stack_id,
  :operation_id,
  :operation_type,
  :operation_status,
  :event_type,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :timestamp,
  :start_time,
  :end_time,
  :resource_status,
  :resource_status_reason,
  :resource_properties,
  :client_request_token,
  :hook_type,
  :hook_status,
  :hook_status_reason,
  :hook_invocation_point,
  :hook_failure_mode,
  :detailed_status,
  :validation_failure_mode,
  :validation_name,
  :validation_status,
  :validation_status_reason,
  :validation_path)
  SENSITIVE = []
  include Aws::Structure
end