Class: Aws::CloudFormation::Types::ParameterConstraints

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

A set of criteria that CloudFormation uses to validate parameter values. Although other constraints might be defined in the stack template, CloudFormation returns only the AllowedValues property.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_valuesArray<String>

A list of values that are permitted for a parameter.

Returns:



7062
7063
7064
7065
7066
# File 'lib/aws-sdk-cloudformation/types.rb', line 7062

class ParameterConstraints < Struct.new(
  :allowed_values)
  SENSITIVE = []
  include Aws::Structure
end