Class: Aws::CloudFormation::Types::ParameterDeclaration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ParameterDeclaration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
The ParameterDeclaration data type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_value ⇒ String
The default value of the parameter.
-
#description ⇒ String
The description that's associate with the parameter.
-
#no_echo ⇒ Boolean
Flag that indicates whether the parameter value is shown as plain text in logs and in the Amazon Web Services Management Console.
-
#parameter_constraints ⇒ Types::ParameterConstraints
The criteria that CloudFormation uses to validate parameter values.
-
#parameter_key ⇒ String
The name that's associated with the parameter.
-
#parameter_type ⇒ String
The type of parameter.
Instance Attribute Details
#default_value ⇒ String
The default value of the parameter.
7097 7098 7099 7100 7101 7102 7103 7104 7105 7106 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7097 class ParameterDeclaration < Struct.new( :parameter_key, :default_value, :parameter_type, :no_echo, :description, :parameter_constraints) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description that's associate with the parameter.
7097 7098 7099 7100 7101 7102 7103 7104 7105 7106 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7097 class ParameterDeclaration < Struct.new( :parameter_key, :default_value, :parameter_type, :no_echo, :description, :parameter_constraints) SENSITIVE = [] include Aws::Structure end |
#no_echo ⇒ Boolean
Flag that indicates whether the parameter value is shown as plain text in logs and in the Amazon Web Services Management Console.
7097 7098 7099 7100 7101 7102 7103 7104 7105 7106 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7097 class ParameterDeclaration < Struct.new( :parameter_key, :default_value, :parameter_type, :no_echo, :description, :parameter_constraints) SENSITIVE = [] include Aws::Structure end |
#parameter_constraints ⇒ Types::ParameterConstraints
The criteria that CloudFormation uses to validate parameter values.
7097 7098 7099 7100 7101 7102 7103 7104 7105 7106 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7097 class ParameterDeclaration < Struct.new( :parameter_key, :default_value, :parameter_type, :no_echo, :description, :parameter_constraints) SENSITIVE = [] include Aws::Structure end |
#parameter_key ⇒ String
The name that's associated with the parameter.
7097 7098 7099 7100 7101 7102 7103 7104 7105 7106 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7097 class ParameterDeclaration < Struct.new( :parameter_key, :default_value, :parameter_type, :no_echo, :description, :parameter_constraints) SENSITIVE = [] include Aws::Structure end |
#parameter_type ⇒ String
The type of parameter.
7097 7098 7099 7100 7101 7102 7103 7104 7105 7106 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7097 class ParameterDeclaration < Struct.new( :parameter_key, :default_value, :parameter_type, :no_echo, :description, :parameter_constraints) SENSITIVE = [] include Aws::Structure end |