Class: Aws::CloudFormation::Types::PropertyDifference

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Information about a resource property whose actual value differs from its expected value, as defined in the stack template and any values specified as template parameters. These will be present only for resources whose StackResourceDriftStatus is MODIFIED. For more information, see Detect unmanaged configuration changes to stacks and resources with drift detection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actual_valueString

The actual property value of the resource property.

Returns:



7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-cloudformation/types.rb', line 7171

class PropertyDifference < Struct.new(
  :property_path,
  :expected_value,
  :actual_value,
  :difference_type)
  SENSITIVE = []
  include Aws::Structure
end

#difference_typeString

The type of property difference.

  • ADD: A value has been added to a resource property that's an array or list data type.

  • REMOVE: The property has been removed from the current resource configuration.

  • NOT_EQUAL: The current property value differs from its expected value (as defined in the stack template and any values specified as template parameters).

Returns:



7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-cloudformation/types.rb', line 7171

class PropertyDifference < Struct.new(
  :property_path,
  :expected_value,
  :actual_value,
  :difference_type)
  SENSITIVE = []
  include Aws::Structure
end

#expected_valueString

The expected property value of the resource property, as defined in the stack template and any values specified as template parameters.

Returns:



7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-cloudformation/types.rb', line 7171

class PropertyDifference < Struct.new(
  :property_path,
  :expected_value,
  :actual_value,
  :difference_type)
  SENSITIVE = []
  include Aws::Structure
end

#property_pathString

The fully-qualified path to the resource property.

Returns:



7171
7172
7173
7174
7175
7176
7177
7178
# File 'lib/aws-sdk-cloudformation/types.rb', line 7171

class PropertyDifference < Struct.new(
  :property_path,
  :expected_value,
  :actual_value,
  :difference_type)
  SENSITIVE = []
  include Aws::Structure
end