Class: Aws::CloudFormation::Types::ResourceChange

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

The ResourceChange structure describes the resource and the action that CloudFormation will perform on it if you execute this change set.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action that CloudFormation takes on the resource, such as Add (adds a new resource), Modify (changes a resource), Remove (deletes a resource), Import (imports a resource), Dynamic (exact action for the resource can't be determined), or SyncWithActual (resource will not be changed, only CloudFormation metadata will change).

Returns:



7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669

class ResourceChange < Struct.new(
  :policy_action,
  :action,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :replacement,
  :scope,
  :resource_drift_status,
  :resource_drift_ignored_attributes,
  :details,
  :change_set_id,
  :module_info,
  :before_context,
  :after_context,
  :previous_deployment_context)
  SENSITIVE = []
  include Aws::Structure
end

#after_contextString

An encoded JSON string that contains the context of the resource after the change is executed.

Returns:



7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669

class ResourceChange < Struct.new(
  :policy_action,
  :action,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :replacement,
  :scope,
  :resource_drift_status,
  :resource_drift_ignored_attributes,
  :details,
  :change_set_id,
  :module_info,
  :before_context,
  :after_context,
  :previous_deployment_context)
  SENSITIVE = []
  include Aws::Structure
end

#before_contextString

An encoded JSON string that contains the context of the resource before the change is executed.

Returns:



7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669

class ResourceChange < Struct.new(
  :policy_action,
  :action,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :replacement,
  :scope,
  :resource_drift_status,
  :resource_drift_ignored_attributes,
  :details,
  :change_set_id,
  :module_info,
  :before_context,
  :after_context,
  :previous_deployment_context)
  SENSITIVE = []
  include Aws::Structure
end

#change_set_idString

The change set ID of the nested change set.

Returns:



7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669

class ResourceChange < Struct.new(
  :policy_action,
  :action,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :replacement,
  :scope,
  :resource_drift_status,
  :resource_drift_ignored_attributes,
  :details,
  :change_set_id,
  :module_info,
  :before_context,
  :after_context,
  :previous_deployment_context)
  SENSITIVE = []
  include Aws::Structure
end

#detailsArray<Types::ResourceChangeDetail>

For the Modify action, a list of ResourceChangeDetail structures that describes the changes that CloudFormation will make to the resource.

Returns:



7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669

class ResourceChange < Struct.new(
  :policy_action,
  :action,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :replacement,
  :scope,
  :resource_drift_status,
  :resource_drift_ignored_attributes,
  :details,
  :change_set_id,
  :module_info,
  :before_context,
  :after_context,
  :previous_deployment_context)
  SENSITIVE = []
  include Aws::Structure
end

#logical_resource_idString

The resource's logical ID, which is defined in the stack's template.

Returns:



7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669

class ResourceChange < Struct.new(
  :policy_action,
  :action,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :replacement,
  :scope,
  :resource_drift_status,
  :resource_drift_ignored_attributes,
  :details,
  :change_set_id,
  :module_info,
  :before_context,
  :after_context,
  :previous_deployment_context)
  SENSITIVE = []
  include Aws::Structure
end

#module_infoTypes::ModuleInfo

Contains information about the module from which the resource was created, if the resource was created from a module included in the stack template.

Returns:



7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669

class ResourceChange < Struct.new(
  :policy_action,
  :action,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :replacement,
  :scope,
  :resource_drift_status,
  :resource_drift_ignored_attributes,
  :details,
  :change_set_id,
  :module_info,
  :before_context,
  :after_context,
  :previous_deployment_context)
  SENSITIVE = []
  include Aws::Structure
end

#physical_resource_idString

The resource's physical ID (resource name). Resources that you are adding don't have physical IDs because they haven't been created.

Returns:



7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669

class ResourceChange < Struct.new(
  :policy_action,
  :action,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :replacement,
  :scope,
  :resource_drift_status,
  :resource_drift_ignored_attributes,
  :details,
  :change_set_id,
  :module_info,
  :before_context,
  :after_context,
  :previous_deployment_context)
  SENSITIVE = []
  include Aws::Structure
end

#policy_actionString

The action that will be taken on the physical resource when the change set is executed.

  • Delete The resource will be deleted.

  • Retain The resource will be retained.

  • Snapshot The resource will have a snapshot taken.

  • ReplaceAndDelete The resource will be replaced and then deleted.

  • ReplaceAndRetain The resource will be replaced and then retained.

  • ReplaceAndSnapshot The resource will be replaced and then have a snapshot taken.

Returns:



7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669

class ResourceChange < Struct.new(
  :policy_action,
  :action,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :replacement,
  :scope,
  :resource_drift_status,
  :resource_drift_ignored_attributes,
  :details,
  :change_set_id,
  :module_info,
  :before_context,
  :after_context,
  :previous_deployment_context)
  SENSITIVE = []
  include Aws::Structure
end

#previous_deployment_contextString

Information about the resource's state from the previous CloudFormation deployment.

Returns:



7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669

class ResourceChange < Struct.new(
  :policy_action,
  :action,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :replacement,
  :scope,
  :resource_drift_status,
  :resource_drift_ignored_attributes,
  :details,
  :change_set_id,
  :module_info,
  :before_context,
  :after_context,
  :previous_deployment_context)
  SENSITIVE = []
  include Aws::Structure
end

#replacementString

For the Modify action, indicates whether CloudFormation will replace the resource by creating a new one and deleting the old one. This value depends on the value of the RequiresRecreation property in the ResourceTargetDefinition structure. For example, if the RequiresRecreation field is Always and the Evaluation field is Static, Replacement is True. If the RequiresRecreation field is Always and the Evaluation field is Dynamic, Replacement is Conditional.

If you have multiple changes with different RequiresRecreation values, the Replacement value depends on the change with the most impact. A RequiresRecreation value of Always has the most impact, followed by Conditional, and then Never.

Returns:



7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669

class ResourceChange < Struct.new(
  :policy_action,
  :action,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :replacement,
  :scope,
  :resource_drift_status,
  :resource_drift_ignored_attributes,
  :details,
  :change_set_id,
  :module_info,
  :before_context,
  :after_context,
  :previous_deployment_context)
  SENSITIVE = []
  include Aws::Structure
end

#resource_drift_ignored_attributesArray<Types::ResourceDriftIgnoredAttribute>

List of resource attributes for which drift was ignored.

Returns:



7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669

class ResourceChange < Struct.new(
  :policy_action,
  :action,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :replacement,
  :scope,
  :resource_drift_status,
  :resource_drift_ignored_attributes,
  :details,
  :change_set_id,
  :module_info,
  :before_context,
  :after_context,
  :previous_deployment_context)
  SENSITIVE = []
  include Aws::Structure
end

#resource_drift_statusString

The drift status of the resource. Valid values:

  • IN_SYNC – The resource matches its template definition.

  • MODIFIED – Resource properties were modified outside CloudFormation.

  • DELETED – The resource was deleted outside CloudFormation.

  • NOT_CHECKED – CloudFormation doesn’t currently return this value.

  • UNKNOWN – Drift status could not be determined.

  • UNSUPPORTED – Resource type does not support actual state comparison.

Only present for drift-aware change sets.

Returns:



7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669

class ResourceChange < Struct.new(
  :policy_action,
  :action,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :replacement,
  :scope,
  :resource_drift_status,
  :resource_drift_ignored_attributes,
  :details,
  :change_set_id,
  :module_info,
  :before_context,
  :after_context,
  :previous_deployment_context)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of CloudFormation resource, such as AWS::S3::Bucket.

Returns:



7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669

class ResourceChange < Struct.new(
  :policy_action,
  :action,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :replacement,
  :scope,
  :resource_drift_status,
  :resource_drift_ignored_attributes,
  :details,
  :change_set_id,
  :module_info,
  :before_context,
  :after_context,
  :previous_deployment_context)
  SENSITIVE = []
  include Aws::Structure
end

#scopeArray<String>

For the Modify action, indicates which resource attribute is triggering this update, such as a change in the resource attribute's Metadata, Properties, or Tags.

Returns:



7669
7670
7671
7672
7673
7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669

class ResourceChange < Struct.new(
  :policy_action,
  :action,
  :logical_resource_id,
  :physical_resource_id,
  :resource_type,
  :replacement,
  :scope,
  :resource_drift_status,
  :resource_drift_ignored_attributes,
  :details,
  :change_set_id,
  :module_info,
  :before_context,
  :after_context,
  :previous_deployment_context)
  SENSITIVE = []
  include Aws::Structure
end