Class: Aws::CloudFormation::Types::ResourceIdentifierSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Describes the target resources of a specific type in your import template (for example, all AWS::S3::Bucket resources) and the properties you can provide during the import to identify resources of that type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#logical_resource_idsArray<String>

The logical IDs of the target resources of the specified ResourceType, as defined in the import template.



7943
7944
7945
7946
7947
7948
7949
# File 'lib/aws-sdk-cloudformation/types.rb', line 7943

class ResourceIdentifierSummary < Struct.new(
  :resource_type,
  :logical_resource_ids,
  :resource_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#resource_identifiersArray<String>

The resource properties you can provide during the import to identify your target resources. For example, BucketName is a possible identifier property for AWS::S3::Bucket resources.



7943
7944
7945
7946
7947
7948
7949
# File 'lib/aws-sdk-cloudformation/types.rb', line 7943

class ResourceIdentifierSummary < Struct.new(
  :resource_type,
  :logical_resource_ids,
  :resource_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The template resource type of the target resources, such as AWS::S3::Bucket.



7943
7944
7945
7946
7947
7948
7949
# File 'lib/aws-sdk-cloudformation/types.rb', line 7943

class ResourceIdentifierSummary < Struct.new(
  :resource_type,
  :logical_resource_ids,
  :resource_identifiers)
  SENSITIVE = []
  include Aws::Structure
end