Class: Aws::CloudFormation::Types::ResourceMapping
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ResourceMapping
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Specifies the current source of the resource and the destination of where it will be moved to.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination ⇒ Types::ResourceLocation
The destination stack
StackNameandLogicalResourceIdfor the resource being refactored. -
#source ⇒ Types::ResourceLocation
The source stack
StackNameandLogicalResourceIdfor the resource being refactored.
Instance Attribute Details
#destination ⇒ Types::ResourceLocation
The destination stack StackName and LogicalResourceId for the
resource being refactored.
7985 7986 7987 7988 7989 7990 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7985 class ResourceMapping < Struct.new( :source, :destination) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::ResourceLocation
The source stack StackName and LogicalResourceId for the
resource being refactored.
7985 7986 7987 7988 7989 7990 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7985 class ResourceMapping < Struct.new( :source, :destination) SENSITIVE = [] include Aws::Structure end |