Class: Aws::CloudFormation::Types::ResourceTargetDefinition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

The field that CloudFormation will change, such as the name of a resource's property, and whether the resource will be recreated.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#after_valueString

The value of the property after the change is executed. Large values can be truncated.

Returns:



8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
# File 'lib/aws-sdk-cloudformation/types.rb', line 8166

class ResourceTargetDefinition < Struct.new(
  :attribute,
  :name,
  :requires_recreation,
  :path,
  :before_value,
  :after_value,
  :before_value_from,
  :after_value_from,
  :drift,
  :attribute_change_type)
  SENSITIVE = []
  include Aws::Structure
end

#after_value_fromString

Indicates the source of the after value. Valid value:

  • TEMPLATE – The after value comes from the new template.

^

Only present for drift-aware change sets.

Returns:



8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
# File 'lib/aws-sdk-cloudformation/types.rb', line 8166

class ResourceTargetDefinition < Struct.new(
  :attribute,
  :name,
  :requires_recreation,
  :path,
  :before_value,
  :after_value,
  :before_value_from,
  :after_value_from,
  :drift,
  :attribute_change_type)
  SENSITIVE = []
  include Aws::Structure
end

#attributeString

Indicates which resource attribute is triggering this update, such as a change in the resource attribute's Metadata, Properties, or Tags.

Returns:



8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
# File 'lib/aws-sdk-cloudformation/types.rb', line 8166

class ResourceTargetDefinition < Struct.new(
  :attribute,
  :name,
  :requires_recreation,
  :path,
  :before_value,
  :after_value,
  :before_value_from,
  :after_value_from,
  :drift,
  :attribute_change_type)
  SENSITIVE = []
  include Aws::Structure
end

#attribute_change_typeString

The type of change to be made to the property if the change is executed.

  • Add The item will be added.

  • Remove The item will be removed.

  • Modify The item will be modified.

  • SyncWithActual The drift status of this item will be reset but the item will not be modified.

Returns:



8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
# File 'lib/aws-sdk-cloudformation/types.rb', line 8166

class ResourceTargetDefinition < Struct.new(
  :attribute,
  :name,
  :requires_recreation,
  :path,
  :before_value,
  :after_value,
  :before_value_from,
  :after_value_from,
  :drift,
  :attribute_change_type)
  SENSITIVE = []
  include Aws::Structure
end

#before_valueString

The value of the property before the change is executed. Large values can be truncated.

Returns:



8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
# File 'lib/aws-sdk-cloudformation/types.rb', line 8166

class ResourceTargetDefinition < Struct.new(
  :attribute,
  :name,
  :requires_recreation,
  :path,
  :before_value,
  :after_value,
  :before_value_from,
  :after_value_from,
  :drift,
  :attribute_change_type)
  SENSITIVE = []
  include Aws::Structure
end

#before_value_fromString

Indicates the source of the before value. Valid values:

  • ACTUAL_STATE – The before value represents current actual state.

  • PREVIOUS_DEPLOYMENT_STATE – The before value represents the previous CloudFormation deployment state.

Only present for drift-aware change sets.

Returns:



8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
# File 'lib/aws-sdk-cloudformation/types.rb', line 8166

class ResourceTargetDefinition < Struct.new(
  :attribute,
  :name,
  :requires_recreation,
  :path,
  :before_value,
  :after_value,
  :before_value_from,
  :after_value_from,
  :drift,
  :attribute_change_type)
  SENSITIVE = []
  include Aws::Structure
end

#driftTypes::LiveResourceDrift

Detailed drift information for the resource property, including actual values, previous deployment values, and drift detection timestamps.

Returns:



8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
# File 'lib/aws-sdk-cloudformation/types.rb', line 8166

class ResourceTargetDefinition < Struct.new(
  :attribute,
  :name,
  :requires_recreation,
  :path,
  :before_value,
  :after_value,
  :before_value_from,
  :after_value_from,
  :drift,
  :attribute_change_type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

If the Attribute value is Properties, the name of the property. For all other attributes, the value is null.

Returns:



8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
# File 'lib/aws-sdk-cloudformation/types.rb', line 8166

class ResourceTargetDefinition < Struct.new(
  :attribute,
  :name,
  :requires_recreation,
  :path,
  :before_value,
  :after_value,
  :before_value_from,
  :after_value_from,
  :drift,
  :attribute_change_type)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

The property path of the property.

Returns:



8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
# File 'lib/aws-sdk-cloudformation/types.rb', line 8166

class ResourceTargetDefinition < Struct.new(
  :attribute,
  :name,
  :requires_recreation,
  :path,
  :before_value,
  :after_value,
  :before_value_from,
  :after_value_from,
  :drift,
  :attribute_change_type)
  SENSITIVE = []
  include Aws::Structure
end

#requires_recreationString

If the Attribute value is Properties, indicates whether a change to this property causes the resource to be recreated. The value can be Never, Always, or Conditionally. To determine the conditions for a Conditionally recreation, see the update behavior for that property in the Amazon Web Services resource and property types reference in the CloudFormation User Guide.

Returns:



8166
8167
8168
8169
8170
8171
8172
8173
8174
8175
8176
8177
8178
8179
# File 'lib/aws-sdk-cloudformation/types.rb', line 8166

class ResourceTargetDefinition < Struct.new(
  :attribute,
  :name,
  :requires_recreation,
  :path,
  :before_value,
  :after_value,
  :before_value_from,
  :after_value_from,
  :drift,
  :attribute_change_type)
  SENSITIVE = []
  include Aws::Structure
end