Class: Aws::CloudFormation::Types::RollbackStackInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_request_tokenString

A unique identifier for this RollbackStack request.

Returns:



8316
8317
8318
8319
8320
8321
8322
8323
8324
# File 'lib/aws-sdk-cloudformation/types.rb', line 8316

class RollbackStackInput < Struct.new(
  :stack_name,
  :role_arn,
  :client_request_token,
  :retain_except_on_create,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_configTypes::DeploymentConfig

The deployment configuration for this stack operation, including the deployment mode.

Returns:



8316
8317
8318
8319
8320
8321
8322
8323
8324
# File 'lib/aws-sdk-cloudformation/types.rb', line 8316

class RollbackStackInput < Struct.new(
  :stack_name,
  :role_arn,
  :client_request_token,
  :retain_except_on_create,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#retain_except_on_createBoolean

When set to true, newly created resources are deleted when the operation rolls back. This includes newly created resources marked with a deletion policy of Retain.

Default: false

Returns:



8316
8317
8318
8319
8320
8321
8322
8323
8324
# File 'lib/aws-sdk-cloudformation/types.rb', line 8316

class RollbackStackInput < Struct.new(
  :stack_name,
  :role_arn,
  :client_request_token,
  :retain_except_on_create,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of an IAM role that CloudFormation assumes to rollback the stack.

Returns:



8316
8317
8318
8319
8320
8321
8322
8323
8324
# File 'lib/aws-sdk-cloudformation/types.rb', line 8316

class RollbackStackInput < Struct.new(
  :stack_name,
  :role_arn,
  :client_request_token,
  :retain_except_on_create,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end

#stack_nameString

The name that's associated with the stack.

Returns:



8316
8317
8318
8319
8320
8321
8322
8323
8324
# File 'lib/aws-sdk-cloudformation/types.rb', line 8316

class RollbackStackInput < Struct.new(
  :stack_name,
  :role_arn,
  :client_request_token,
  :retain_except_on_create,
  :deployment_config)
  SENSITIVE = []
  include Aws::Structure
end