Class: Aws::CloudFormation::Types::ScanFilter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

A filter that is used to specify which resource types to scan.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#typesArray<String>

An array of strings where each string represents an Amazon Web Services resource type you want to scan. Each string defines the resource type using the format AWS::ServiceName::ResourceType, for example, AWS::DynamoDB::Table. For the full list of supported resource types, see the [Resource type support] table in the *CloudFormation User Guide*.

To scan all resource types within a service, you can use a wildcard, represented by an asterisk (‘*`). You can place an asterisk at only the end of the string, for example, AWS::S3::*.

[1]: docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/resource-import-supported-resources.html



8313
8314
8315
8316
8317
# File 'lib/aws-sdk-cloudformation/types.rb', line 8313

class ScanFilter < Struct.new(
  :types)
  SENSITIVE = []
  include Aws::Structure
end