Class: Aws::CloudFormation::Types::ScannedResource
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ScannedResource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
A scanned resource returned by ListResourceScanResources or
ListResourceScanRelatedResources.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#managed_by_stack ⇒ Boolean
If
true, the resource is managed by a CloudFormation stack. -
#resource_identifier ⇒ Hash<String,String>
A list of up to 256 key-value pairs that identifies for the scanned resource.
-
#resource_type ⇒ String
The type of the resource, such as
AWS::DynamoDB::Table.
Instance Attribute Details
#managed_by_stack ⇒ Boolean
If true, the resource is managed by a CloudFormation stack.
8439 8440 8441 8442 8443 8444 8445 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 8439 class ScannedResource < Struct.new( :resource_type, :resource_identifier, :managed_by_stack) SENSITIVE = [] include Aws::Structure end |
#resource_identifier ⇒ Hash<String,String>
A list of up to 256 key-value pairs that identifies for the scanned
resource. The key is the name of one of the primary identifiers for
the resource. (Primary identifiers are specified in the
primaryIdentifier list in the resource schema.) The value is the
value of that primary identifier. For example, for a
AWS::DynamoDB::Table resource, the primary identifiers is
TableName so the key-value pair could be "TableName": "MyDDBTable". For more information, see primaryIdentifier in
the CloudFormation Command Line Interface (CLI) User Guide.
8439 8440 8441 8442 8443 8444 8445 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 8439 class ScannedResource < Struct.new( :resource_type, :resource_identifier, :managed_by_stack) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of the resource, such as AWS::DynamoDB::Table. For the
list of supported resources, see Resource type support for imports
and drift detection In the CloudFormation User Guide
8439 8440 8441 8442 8443 8444 8445 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 8439 class ScannedResource < Struct.new( :resource_type, :resource_identifier, :managed_by_stack) SENSITIVE = [] include Aws::Structure end |