Class: Aws::CloudFormation::Types::SetTypeConfigurationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::SetTypeConfigurationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ String
The configuration data for the extension in this account and Region.
-
#configuration_alias ⇒ String
An alias by which to refer to this extension configuration data.
-
#type ⇒ String
The type of extension.
-
#type_arn ⇒ String
The Amazon Resource Name (ARN) for the extension in this account and Region.
-
#type_name ⇒ String
The name of the extension.
Instance Attribute Details
#configuration ⇒ String
The configuration data for the extension in this account and Region.
The configuration data must be formatted as JSON and validate
against the extension's schema returned in the Schema response
element of DescribeType.
8578 8579 8580 8581 8582 8583 8584 8585 8586 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 8578 class SetTypeConfigurationInput < Struct.new( :type_arn, :configuration, :configuration_alias, :type_name, :type) SENSITIVE = [] include Aws::Structure end |
#configuration_alias ⇒ String
An alias by which to refer to this extension configuration data.
Conditional: Specifying a configuration alias is required when setting a configuration for a resource type extension.
8578 8579 8580 8581 8582 8583 8584 8585 8586 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 8578 class SetTypeConfigurationInput < Struct.new( :type_arn, :configuration, :configuration_alias, :type_name, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of extension.
Conditional: You must specify ConfigurationArn, or Type and
TypeName.
8578 8579 8580 8581 8582 8583 8584 8585 8586 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 8578 class SetTypeConfigurationInput < Struct.new( :type_arn, :configuration, :configuration_alias, :type_name, :type) SENSITIVE = [] include Aws::Structure end |
#type_arn ⇒ String
The Amazon Resource Name (ARN) for the extension in this account and Region.
For public extensions, this will be the ARN assigned when you call the ActivateType API operation in this account and Region. For private extensions, this will be the ARN assigned when you call the RegisterType API operation in this account and Region.
Do not include the extension versions suffix at the end of the ARN. You can set the configuration for an extension, but not for a specific extension version.
8578 8579 8580 8581 8582 8583 8584 8585 8586 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 8578 class SetTypeConfigurationInput < Struct.new( :type_arn, :configuration, :configuration_alias, :type_name, :type) SENSITIVE = [] include Aws::Structure end |
#type_name ⇒ String
The name of the extension.
Conditional: You must specify ConfigurationArn, or Type and
TypeName.
8578 8579 8580 8581 8582 8583 8584 8585 8586 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 8578 class SetTypeConfigurationInput < Struct.new( :type_arn, :configuration, :configuration_alias, :type_name, :type) SENSITIVE = [] include Aws::Structure end |