Class: Aws::CloudFormation::Types::SetTypeDefaultVersionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the extension for which you want version summary information.

Conditional: You must specify either TypeName and Type, or Arn.



8634
8635
8636
8637
8638
8639
8640
8641
# File 'lib/aws-sdk-cloudformation/types.rb', line 8634

class SetTypeDefaultVersionInput < Struct.new(
  :arn,
  :type,
  :type_name,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The kind of extension.

Conditional: You must specify either TypeName and Type, or Arn.



8634
8635
8636
8637
8638
8639
8640
8641
# File 'lib/aws-sdk-cloudformation/types.rb', line 8634

class SetTypeDefaultVersionInput < Struct.new(
  :arn,
  :type,
  :type_name,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#type_nameString

The name of the extension.

Conditional: You must specify either TypeName and Type, or Arn.



8634
8635
8636
8637
8638
8639
8640
8641
# File 'lib/aws-sdk-cloudformation/types.rb', line 8634

class SetTypeDefaultVersionInput < Struct.new(
  :arn,
  :type,
  :type_name,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

The ID of a specific version of the extension. The version ID is the value at the end of the Amazon Resource Name (ARN) assigned to the extension version when it is registered.



8634
8635
8636
8637
8638
8639
8640
8641
# File 'lib/aws-sdk-cloudformation/types.rb', line 8634

class SetTypeDefaultVersionInput < Struct.new(
  :arn,
  :type,
  :type_name,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end