Class: Aws::CloudFormation::Types::StackInstanceResourceDriftsSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::StackInstanceResourceDriftsSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
The structure containing summary information about resource drifts for a stack instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#logical_resource_id ⇒ String
The logical name of the resource specified in the template.
-
#physical_resource_id ⇒ String
The name or unique identifier that corresponds to a physical instance ID of a resource supported by CloudFormation.
-
#physical_resource_id_context ⇒ Array<Types::PhysicalResourceIdContextKeyValuePair>
Context information that enables CloudFormation to uniquely identify a resource.
-
#property_differences ⇒ Array<Types::PropertyDifference>
Status of the actual configuration of the resource compared to its expected configuration.
-
#resource_type ⇒ String
Type of resource.
-
#stack_id ⇒ String
The ID of the stack instance.
-
#stack_resource_drift_status ⇒ String
The drift status of the resource in a stack instance.
-
#timestamp ⇒ Time
Time at which the stack instance drift detection operation was initiated.
Instance Attribute Details
#logical_resource_id ⇒ String
The logical name of the resource specified in the template.
9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 9414 class StackInstanceResourceDriftsSummary < Struct.new( :stack_id, :logical_resource_id, :physical_resource_id, :physical_resource_id_context, :resource_type, :property_differences, :stack_resource_drift_status, :timestamp) SENSITIVE = [] include Aws::Structure end |
#physical_resource_id ⇒ String
The name or unique identifier that corresponds to a physical instance ID of a resource supported by CloudFormation.
9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 9414 class StackInstanceResourceDriftsSummary < Struct.new( :stack_id, :logical_resource_id, :physical_resource_id, :physical_resource_id_context, :resource_type, :property_differences, :stack_resource_drift_status, :timestamp) SENSITIVE = [] include Aws::Structure end |
#physical_resource_id_context ⇒ Array<Types::PhysicalResourceIdContextKeyValuePair>
Context information that enables CloudFormation to uniquely identify a resource. CloudFormation uses context key-value pairs in cases where a resource's logical and physical IDs aren't enough to uniquely identify that resource. Each context key-value pair specifies a unique resource that contains the targeted resource.
9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 9414 class StackInstanceResourceDriftsSummary < Struct.new( :stack_id, :logical_resource_id, :physical_resource_id, :physical_resource_id_context, :resource_type, :property_differences, :stack_resource_drift_status, :timestamp) SENSITIVE = [] include Aws::Structure end |
#property_differences ⇒ Array<Types::PropertyDifference>
Status of the actual configuration of the resource compared to its
expected configuration. These will be present only for resources
whose StackInstanceResourceDriftStatus is MODIFIED.
9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 9414 class StackInstanceResourceDriftsSummary < Struct.new( :stack_id, :logical_resource_id, :physical_resource_id, :physical_resource_id_context, :resource_type, :property_differences, :stack_resource_drift_status, :timestamp) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
Type of resource. For more information, see Amazon Web Services resource and property types reference in the CloudFormation User Guide.
9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 9414 class StackInstanceResourceDriftsSummary < Struct.new( :stack_id, :logical_resource_id, :physical_resource_id, :physical_resource_id_context, :resource_type, :property_differences, :stack_resource_drift_status, :timestamp) SENSITIVE = [] include Aws::Structure end |
#stack_id ⇒ String
The ID of the stack instance.
9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 9414 class StackInstanceResourceDriftsSummary < Struct.new( :stack_id, :logical_resource_id, :physical_resource_id, :physical_resource_id_context, :resource_type, :property_differences, :stack_resource_drift_status, :timestamp) SENSITIVE = [] include Aws::Structure end |
#stack_resource_drift_status ⇒ String
The drift status of the resource in a stack instance.
-
DELETED: The resource differs from its expected template configuration in that the resource has been deleted. -
MODIFIED: One or more resource properties differ from their expected template values. -
IN_SYNC: The resource's actual configuration matches its expected template configuration. -
NOT_CHECKED: CloudFormation doesn't currently return this value.
9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 9414 class StackInstanceResourceDriftsSummary < Struct.new( :stack_id, :logical_resource_id, :physical_resource_id, :physical_resource_id_context, :resource_type, :property_differences, :stack_resource_drift_status, :timestamp) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Time
Time at which the stack instance drift detection operation was initiated.
9414 9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 9414 class StackInstanceResourceDriftsSummary < Struct.new( :stack_id, :logical_resource_id, :physical_resource_id, :physical_resource_id_context, :resource_type, :property_differences, :stack_resource_drift_status, :timestamp) SENSITIVE = [] include Aws::Structure end |