Method: Aws::CloudFormation::Types::StackSet#regions

Defined in:
lib/aws-sdk-cloudformation/types.rb

#regionsArray<String>

Returns a list of all Amazon Web Services Regions the given StackSet has stack instances deployed in. The Amazon Web Services Regions list output is in no particular order.

Returns:

  • (Array<String>)


10170
10171
10172
10173
10174
10175
10176
10177
10178
10179
10180
10181
10182
10183
10184
10185
10186
10187
10188
10189
10190
# File 'lib/aws-sdk-cloudformation/types.rb', line 10170

class StackSet < Struct.new(
  :stack_set_name,
  :stack_set_id,
  :description,
  :status,
  :template_body,
  :parameters,
  :capabilities,
  :tags,
  :stack_set_arn,
  :administration_role_arn,
  :execution_role_name,
  :stack_set_drift_detection_details,
  :auto_deployment,
  :permission_model,
  :organizational_unit_ids,
  :managed_execution,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end