Class: Aws::CloudFormation::Types::StackSetOperationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::StackSetOperationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
The structures that contain summary information about the specified operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The type of operation:
CREATE,UPDATE, orDELETE. -
#creation_timestamp ⇒ Time
The time at which the operation was initiated.
-
#end_timestamp ⇒ Time
The time at which the StackSet operation ended, across all accounts and Regions specified.
-
#operation_id ⇒ String
The unique ID of the StackSet operation.
-
#operation_preferences ⇒ Types::StackSetOperationPreferences
The user-specified preferences for how CloudFormation performs a StackSet operation.
-
#status ⇒ String
The overall status of the operation.
-
#status_details ⇒ Types::StackSetOperationStatusDetails
Detailed information about the StackSet operation.
-
#status_reason ⇒ String
The status of the operation in details.
Instance Attribute Details
#action ⇒ String
The type of operation: CREATE, UPDATE, or DELETE. Create and
delete operations affect only the specified stack instances that are
associated with the specified StackSet. Update operations affect
both the StackSet itself and all associated StackSet instances.
10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 10878 class StackSetOperationSummary < Struct.new( :operation_id, :action, :status, :creation_timestamp, :end_timestamp, :status_reason, :status_details, :operation_preferences) SENSITIVE = [] include Aws::Structure end |
#creation_timestamp ⇒ Time
The time at which the operation was initiated. Note that the creation times for the StackSet operation might differ from the creation time of the individual stacks themselves. This is because CloudFormation needs to perform preparatory work for the operation, such as dispatching the work to the requested Regions, before actually creating the first stacks.
10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 10878 class StackSetOperationSummary < Struct.new( :operation_id, :action, :status, :creation_timestamp, :end_timestamp, :status_reason, :status_details, :operation_preferences) SENSITIVE = [] include Aws::Structure end |
#end_timestamp ⇒ Time
The time at which the StackSet operation ended, across all accounts and Regions specified. Note that this doesn't necessarily mean that the StackSet operation was successful, or even attempted, in each account or Region.
10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 10878 class StackSetOperationSummary < Struct.new( :operation_id, :action, :status, :creation_timestamp, :end_timestamp, :status_reason, :status_details, :operation_preferences) SENSITIVE = [] include Aws::Structure end |
#operation_id ⇒ String
The unique ID of the StackSet operation.
10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 10878 class StackSetOperationSummary < Struct.new( :operation_id, :action, :status, :creation_timestamp, :end_timestamp, :status_reason, :status_details, :operation_preferences) SENSITIVE = [] include Aws::Structure end |
#operation_preferences ⇒ Types::StackSetOperationPreferences
The user-specified preferences for how CloudFormation performs a StackSet operation.
For more information about maximum concurrent accounts and failure tolerance, see StackSet operation options.
10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 10878 class StackSetOperationSummary < Struct.new( :operation_id, :action, :status, :creation_timestamp, :end_timestamp, :status_reason, :status_details, :operation_preferences) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The overall status of the operation.
-
FAILED: The operation exceeded the specified failure tolerance. The failure tolerance value that you've set for an operation is applied for each Region during stack create and update operations. If the number of failed stacks within a Region exceeds the failure tolerance, the status of the operation in the Region is set toFAILED. This in turn sets the status of the operation as a whole toFAILED, and CloudFormation cancels the operation in any remaining Regions. -
QUEUED: [Service-managed permissions] For automatic deployments that require a sequence of operations, the operation is queued to be performed. For more information, see the StackSet status codes in the CloudFormation User Guide. -
RUNNING: The operation is currently being performed. -
STOPPED: The user has canceled the operation. -
STOPPING: The operation is in the process of stopping, at user request. -
SUCCEEDED: The operation completed creating or updating all the specified stacks without exceeding the failure tolerance for the operation.
10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 10878 class StackSetOperationSummary < Struct.new( :operation_id, :action, :status, :creation_timestamp, :end_timestamp, :status_reason, :status_details, :operation_preferences) SENSITIVE = [] include Aws::Structure end |
#status_details ⇒ Types::StackSetOperationStatusDetails
Detailed information about the StackSet operation.
10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 10878 class StackSetOperationSummary < Struct.new( :operation_id, :action, :status, :creation_timestamp, :end_timestamp, :status_reason, :status_details, :operation_preferences) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
The status of the operation in details.
10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 10878 class StackSetOperationSummary < Struct.new( :operation_id, :action, :status, :creation_timestamp, :end_timestamp, :status_reason, :status_details, :operation_preferences) SENSITIVE = [] include Aws::Structure end |