Class: Aws::CloudFormation::Types::TemplateSummaryConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::TemplateSummaryConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Options for the GetTemplateSummary API action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#treat_unrecognized_resource_types_as_warnings ⇒ Boolean
If set to
True, any unrecognized resource types generate warnings and not an error.
Instance Attribute Details
#treat_unrecognized_resource_types_as_warnings ⇒ Boolean
If set to True, any unrecognized resource types generate warnings
and not an error. Any unrecognized resource types are returned in
the Warnings output parameter.
11373 11374 11375 11376 11377 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 11373 class TemplateSummaryConfig < Struct.new( :treat_unrecognized_resource_types_as_warnings) SENSITIVE = [] include Aws::Structure end |