Class: Aws::CloudFormation::Types::TestTypeInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the extension.

Conditional: You must specify Arn, or TypeName and Type.

Returns:

  • (String)


11434
11435
11436
11437
11438
11439
11440
11441
11442
# File 'lib/aws-sdk-cloudformation/types.rb', line 11434

class TestTypeInput < Struct.new(
  :arn,
  :type,
  :type_name,
  :version_id,
  :log_delivery_bucket)
  SENSITIVE = []
  include Aws::Structure
end

#log_delivery_bucketString

The S3 bucket to which CloudFormation delivers the contract test execution logs.

CloudFormation delivers the logs by the time contract testing has completed and the extension has been assigned a test type status of PASSED or FAILED.

The user calling TestType must be able to access items in the specified S3 bucket. Specifically, the user needs the following permissions:

  • GetObject

  • PutObject

For more information, see Actions, Resources, and Condition Keys for Amazon S3 in the Identity and Access Management User Guide.

Returns:

  • (String)


11434
11435
11436
11437
11438
11439
11440
11441
11442
# File 'lib/aws-sdk-cloudformation/types.rb', line 11434

class TestTypeInput < Struct.new(
  :arn,
  :type,
  :type_name,
  :version_id,
  :log_delivery_bucket)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the extension to test.

Conditional: You must specify Arn, or TypeName and Type.

Returns:

  • (String)


11434
11435
11436
11437
11438
11439
11440
11441
11442
# File 'lib/aws-sdk-cloudformation/types.rb', line 11434

class TestTypeInput < Struct.new(
  :arn,
  :type,
  :type_name,
  :version_id,
  :log_delivery_bucket)
  SENSITIVE = []
  include Aws::Structure
end

#type_nameString

The name of the extension to test.

Conditional: You must specify Arn, or TypeName and Type.

Returns:

  • (String)


11434
11435
11436
11437
11438
11439
11440
11441
11442
# File 'lib/aws-sdk-cloudformation/types.rb', line 11434

class TestTypeInput < Struct.new(
  :arn,
  :type,
  :type_name,
  :version_id,
  :log_delivery_bucket)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

The version of the extension to test.

You can specify the version id with either Arn, or with TypeName and Type.

If you don't specify a version, CloudFormation uses the default version of the extension in this account and Region for testing.

Returns:

  • (String)


11434
11435
11436
11437
11438
11439
11440
11441
11442
# File 'lib/aws-sdk-cloudformation/types.rb', line 11434

class TestTypeInput < Struct.new(
  :arn,
  :type,
  :type_name,
  :version_id,
  :log_delivery_bucket)
  SENSITIVE = []
  include Aws::Structure
end