Class: Aws::CloudFormation::Types::TypeConfigurationDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudformation/types.rb

Overview

Detailed information concerning the specification of a CloudFormation extension in a given account and Region.

For more information, see Edit configuration data for extensions in your account in the CloudFormation User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aliasString

The alias specified for this configuration, if one was specified when the configuration was set.

Returns:

  • (String)


11521
11522
11523
11524
11525
11526
11527
11528
11529
11530
11531
# File 'lib/aws-sdk-cloudformation/types.rb', line 11521

class TypeConfigurationDetails < Struct.new(
  :arn,
  :alias,
  :configuration,
  :last_updated,
  :type_arn,
  :type_name,
  :is_default_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The ARN for the configuration data, in this account and Region.

Returns:

  • (String)


11521
11522
11523
11524
11525
11526
11527
11528
11529
11530
11531
# File 'lib/aws-sdk-cloudformation/types.rb', line 11521

class TypeConfigurationDetails < Struct.new(
  :arn,
  :alias,
  :configuration,
  :last_updated,
  :type_arn,
  :type_name,
  :is_default_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#configurationString

A JSON string specifying the configuration data for the extension, in this account and Region.

If a configuration hasn't been set for a specified extension, CloudFormation returns {}.

Returns:

  • (String)


11521
11522
11523
11524
11525
11526
11527
11528
11529
11530
11531
# File 'lib/aws-sdk-cloudformation/types.rb', line 11521

class TypeConfigurationDetails < Struct.new(
  :arn,
  :alias,
  :configuration,
  :last_updated,
  :type_arn,
  :type_name,
  :is_default_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#is_default_configurationBoolean

Whether this configuration data is the default configuration for the extension.

Returns:

  • (Boolean)


11521
11522
11523
11524
11525
11526
11527
11528
11529
11530
11531
# File 'lib/aws-sdk-cloudformation/types.rb', line 11521

class TypeConfigurationDetails < Struct.new(
  :arn,
  :alias,
  :configuration,
  :last_updated,
  :type_arn,
  :type_name,
  :is_default_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#last_updatedTime

When the configuration data was last updated for this extension.

If a configuration hasn't been set for a specified extension, CloudFormation returns null.

Returns:

  • (Time)


11521
11522
11523
11524
11525
11526
11527
11528
11529
11530
11531
# File 'lib/aws-sdk-cloudformation/types.rb', line 11521

class TypeConfigurationDetails < Struct.new(
  :arn,
  :alias,
  :configuration,
  :last_updated,
  :type_arn,
  :type_name,
  :is_default_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#type_arnString

The ARN for the extension, in this account and Region.

For public extensions, this will be the ARN assigned when you call the ActivateType API operation in this account and Region. For private extensions, this will be the ARN assigned when you call the RegisterType API operation in this account and Region.

Returns:

  • (String)


11521
11522
11523
11524
11525
11526
11527
11528
11529
11530
11531
# File 'lib/aws-sdk-cloudformation/types.rb', line 11521

class TypeConfigurationDetails < Struct.new(
  :arn,
  :alias,
  :configuration,
  :last_updated,
  :type_arn,
  :type_name,
  :is_default_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#type_nameString

The name of the extension.

Returns:

  • (String)


11521
11522
11523
11524
11525
11526
11527
11528
11529
11530
11531
# File 'lib/aws-sdk-cloudformation/types.rb', line 11521

class TypeConfigurationDetails < Struct.new(
  :arn,
  :alias,
  :configuration,
  :last_updated,
  :type_arn,
  :type_name,
  :is_default_configuration)
  SENSITIVE = []
  include Aws::Structure
end