Class: Aws::CloudFormation::Types::UpdateStackInstancesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::UpdateStackInstancesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accounts ⇒ Array<String>
[Self-managed permissions] The account IDs of one or more Amazon Web Services accounts in which you want to update parameter values for stack instances.
-
#call_as ⇒ String
[Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.
-
#deployment_targets ⇒ Types::DeploymentTargets
[Service-managed permissions] The Organizations accounts in which you want to update parameter values for stack instances.
-
#operation_id ⇒ String
The unique identifier for this StackSet operation.
-
#operation_preferences ⇒ Types::StackSetOperationPreferences
Preferences for how CloudFormation performs this StackSet operation.
-
#parameter_overrides ⇒ Array<Types::Parameter>
A list of input parameters whose values you want to update for the specified stack instances.
-
#regions ⇒ Array<String>
The names of one or more Amazon Web Services Regions in which you want to update parameter values for stack instances.
-
#stack_set_name ⇒ String
The name or unique ID of the StackSet associated with the stack instances.
Instance Attribute Details
#accounts ⇒ Array<String>
[Self-managed permissions] The account IDs of one or more Amazon Web Services accounts in which you want to update parameter values for stack instances. The overridden parameter values will be applied to all stack instances in the specified accounts and Amazon Web Services Regions.
You can specify Accounts or DeploymentTargets, but not both.
12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 12278 class UpdateStackInstancesInput < Struct.new( :stack_set_name, :accounts, :deployment_targets, :regions, :parameter_overrides, :operation_preferences, :operation_id, :call_as) SENSITIVE = [] include Aws::Structure end |
#call_as ⇒ String
[Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.
By default, SELF is specified. Use SELF for StackSets with
self-managed permissions.
-
If you are signed in to the management account, specify
SELF. -
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.
12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 12278 class UpdateStackInstancesInput < Struct.new( :stack_set_name, :accounts, :deployment_targets, :regions, :parameter_overrides, :operation_preferences, :operation_id, :call_as) SENSITIVE = [] include Aws::Structure end |
#deployment_targets ⇒ Types::DeploymentTargets
[Service-managed permissions] The Organizations accounts in which you want to update parameter values for stack instances. If your update targets OUs, the overridden parameter values only apply to the accounts that are currently in the target OUs and their child OUs. Accounts added to the target OUs and their child OUs in the future won't use the overridden values.
You can specify Accounts or DeploymentTargets, but not both.
12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 12278 class UpdateStackInstancesInput < Struct.new( :stack_set_name, :accounts, :deployment_targets, :regions, :parameter_overrides, :operation_preferences, :operation_id, :call_as) SENSITIVE = [] include Aws::Structure end |
#operation_id ⇒ String
The unique identifier for this StackSet operation.
The operation ID also functions as an idempotency token, to ensure that CloudFormation performs the StackSet operation only once, even if you retry the request multiple times. You might retry StackSet operation requests to ensure that CloudFormation successfully received them.
If you don't specify an operation ID, the SDK generates one automatically.
A suitable default value is auto-generated. You should normally not need to pass this option.
12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 12278 class UpdateStackInstancesInput < Struct.new( :stack_set_name, :accounts, :deployment_targets, :regions, :parameter_overrides, :operation_preferences, :operation_id, :call_as) SENSITIVE = [] include Aws::Structure end |
#operation_preferences ⇒ Types::StackSetOperationPreferences
Preferences for how CloudFormation performs this StackSet operation.
12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 12278 class UpdateStackInstancesInput < Struct.new( :stack_set_name, :accounts, :deployment_targets, :regions, :parameter_overrides, :operation_preferences, :operation_id, :call_as) SENSITIVE = [] include Aws::Structure end |
#parameter_overrides ⇒ Array<Types::Parameter>
A list of input parameters whose values you want to update for the specified stack instances.
Any overridden parameter values will be applied to all stack instances in the specified accounts and Amazon Web Services Regions. When specifying parameters and their values, be aware of how CloudFormation sets parameter values during stack instance update operations:
-
To override the current value for a parameter, include the parameter and specify its value.
-
To leave an overridden parameter set to its present value, include the parameter and specify
UsePreviousValueastrue. (You can't specify both a value and setUsePreviousValuetotrue.) -
To set an overridden parameter back to the value specified in the StackSet, specify a parameter list but don't include the parameter in the list.
-
To leave all parameters set to their present values, don't specify this property at all.
During StackSet updates, any parameter values overridden for a stack instance aren't updated, but retain their overridden value.
You can only override the parameter values that are specified in
the StackSet. To add or delete a parameter itself, use
UpdateStackSet to update the StackSet template. If you add a
parameter to a template, before you can override the parameter value
specified in the StackSet you must first use UpdateStackSet to
update all stack instances with the updated template and parameter
value specified in the StackSet. Once a stack instance has been
updated with the new parameter, you can then override the parameter
value using UpdateStackInstances.
12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 12278 class UpdateStackInstancesInput < Struct.new( :stack_set_name, :accounts, :deployment_targets, :regions, :parameter_overrides, :operation_preferences, :operation_id, :call_as) SENSITIVE = [] include Aws::Structure end |
#regions ⇒ Array<String>
The names of one or more Amazon Web Services Regions in which you want to update parameter values for stack instances. The overridden parameter values will be applied to all stack instances in the specified accounts and Amazon Web Services Regions.
12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 12278 class UpdateStackInstancesInput < Struct.new( :stack_set_name, :accounts, :deployment_targets, :regions, :parameter_overrides, :operation_preferences, :operation_id, :call_as) SENSITIVE = [] include Aws::Structure end |
#stack_set_name ⇒ String
The name or unique ID of the StackSet associated with the stack instances.
12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 12278 class UpdateStackInstancesInput < Struct.new( :stack_set_name, :accounts, :deployment_targets, :regions, :parameter_overrides, :operation_preferences, :operation_id, :call_as) SENSITIVE = [] include Aws::Structure end |