Class: Aws::CloudFormation::Types::Warnings
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::Warnings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Contains any warnings returned by the GetTemplateSummary API action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unrecognized_resource_types ⇒ Array<String>
A list of all of the unrecognized resource types.
Instance Attribute Details
#unrecognized_resource_types ⇒ Array<String>
A list of all of the unrecognized resource types. This is only
returned if the TemplateSummaryConfig parameter has the
TreatUnrecognizedResourceTypesAsWarning configuration set to
True.
12989 12990 12991 12992 12993 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 12989 class Warnings < Struct.new( :unrecognized_resource_types) SENSITIVE = [] include Aws::Structure end |