Class: Aws::CloudFormation::Waiters::ChangeSetCreateComplete

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-cloudformation/waiters.rb,
sig/waiters.rbs

Overview

Wait until change set status is CREATE_COMPLETE.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ChangeSetCreateComplete

Returns a new instance of ChangeSetCreateComplete.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 120
  • :delay (Integer) — default: 30
  • :before_attempt (Proc)
  • :before_wait (Proc)


94
95
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 94

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



131
132
133
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 131

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeChangeSetOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :change_set_name (required, String)

    The name or Amazon Resource Name (ARN) of the change set that you want to describe.

  • :stack_name (String)

    If you specified the name of a change set, specify the stack name or ID (ARN) of the change set you want to describe.

  • :next_token (String)

    The token for the next set of items to return. (You received this token from a previous call.)

  • :include_property_values (Boolean)

    If true, the returned changes include detailed changes in the property values.

Returns:



126
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 126

def wait: (