Method: Aws::CloudFormation::Waiters::ChangeSetCreateComplete#wait

Defined in:
lib/aws-sdk-cloudformation/waiters.rb

#wait(params = {}) ⇒ Types::DescribeChangeSetOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :change_set_name (required, String)

    The name or Amazon Resource Name (ARN) of the change set that you want to describe.

  • :stack_name (String)

    If you specified the name of a change set, specify the stack name or ID (ARN) of the change set you want to describe.

  • :next_token (String)

    The token for the next set of items to return. (You received this token from a previous call.)

  • :include_property_values (Boolean)

    If true, the returned changes include detailed changes in the property values.

Returns:



126
127
128
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 126

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end