Class: Aws::CloudFormation::Waiters::StackCreateComplete
- Inherits:
-
Object
- Object
- Aws::CloudFormation::Waiters::StackCreateComplete
- Defined in:
- lib/aws-sdk-cloudformation/waiters.rb,
sig/waiters.rbs
Overview
Wait until stack status is CREATE_COMPLETE.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ StackCreateComplete
constructor
A new instance of StackCreateComplete.
-
#wait(params = {}) ⇒ Types::DescribeStacksOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ StackCreateComplete
Returns a new instance of StackCreateComplete.
144 145 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 144
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
253 254 255 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 253 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeStacksOutput
Returns a response object which responds to the following methods:
- #stacks => Array<Types::Stack>
- #next_token => String
248 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 248
def wait: (
|