Class: Aws::CloudFormation::Waiters::StackDeleteComplete
- Inherits:
-
Object
- Object
- Aws::CloudFormation::Waiters::StackDeleteComplete
- Defined in:
- lib/aws-sdk-cloudformation/waiters.rb,
sig/waiters.rbs
Overview
Wait until stack status is DELETE_COMPLETE.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ StackDeleteComplete
constructor
A new instance of StackDeleteComplete.
-
#wait(params = {}) ⇒ Types::DescribeStacksOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ StackDeleteComplete
Returns a new instance of StackDeleteComplete.
266 267 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 266
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
339 340 341 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 339 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeStacksOutput
Returns a response object which responds to the following methods:
- #stacks => Array<Types::Stack>
- #next_token => String
334 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 334
def wait: (
|