Class: Aws::CloudFormation::Waiters::StackImportComplete

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-cloudformation/waiters.rb,
sig/waiters.rbs

Overview

Wait until stack status is IMPORT_COMPLETE.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ StackImportComplete

Returns a new instance of StackImportComplete.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 120
  • :delay (Integer) — default: 30
  • :before_attempt (Proc)
  • :before_wait (Proc)


394
395
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 394

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



455
456
457
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 455

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeStacksOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :stack_name (String)

    If you don't pass a parameter to StackName, the API returns a response that describes all resources in the account, which can impact performance. This requires ListStacks and DescribeStacks permissions.

    Consider using the ListStacks API if you're not passing a parameter to StackName.

    The IAM policy below can be added to IAM policies when you want to limit resource-level permissions and avoid returning a response when no parameter is sent in the request:

    { "Version": "2012-10-17", "Statement": [{ "Effect": "Deny", "Action": "cloudformation:DescribeStacks", "NotResource": "arn:aws:cloudformation:::stack//" }] }

    The name or the unique stack ID that's associated with the stack, which aren't always interchangeable:

    • Running stacks: You can specify either the stack's name or its unique stack ID.

    • Deleted stacks: You must specify the unique stack ID.

  • :next_token (String)

    The token for the next set of items to return. (You received this token from a previous call.)

Returns:



450
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 450

def wait: (