Class: Aws::CloudFormation::Waiters::StackRefactorCreateComplete
- Inherits:
-
Object
- Object
- Aws::CloudFormation::Waiters::StackRefactorCreateComplete
- Defined in:
- lib/aws-sdk-cloudformation/waiters.rb,
sig/waiters.rbs
Overview
Wait until the stack refactor status is CREATE_COMPLETE.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ StackRefactorCreateComplete
constructor
A new instance of StackRefactorCreateComplete.
-
#wait(params = {}) ⇒ Types::DescribeStackRefactorOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ StackRefactorCreateComplete
Returns a new instance of StackRefactorCreateComplete.
468 469 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 468
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
505 506 507 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 505 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeStackRefactorOutput
Returns a response object which responds to the following methods:
- #description => String
- #stack_refactor_id => String
- #stack_ids => Array<String>
- #execution_status => String
- #execution_status_reason => String
- #status => String
- #status_reason => String
500 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 500
def wait: (
|