Class: Aws::CloudFormation::Waiters::StackRefactorExecuteComplete

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-cloudformation/waiters.rb,
sig/waiters.rbs

Overview

Wait until the stack refactor status is EXECUTE_COMPLETE.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ StackRefactorExecuteComplete

Returns a new instance of StackRefactorExecuteComplete.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 120
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


518
519
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 518

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



561
562
563
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 561

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeStackRefactorOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :stack_refactor_id (required, String)

    The ID associated with the stack refactor created from the CreateStackRefactor action.

Returns:



556
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 556

def wait: (