Class: Aws::CloudFormation::Waiters::StackRollbackComplete
- Inherits:
-
Object
- Object
- Aws::CloudFormation::Waiters::StackRollbackComplete
- Defined in:
- lib/aws-sdk-cloudformation/waiters.rb,
sig/waiters.rbs
Overview
Wait until stack status is UPDATE_ROLLBACK_COMPLETE.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ StackRollbackComplete
constructor
A new instance of StackRollbackComplete.
-
#wait(params = {}) ⇒ Types::DescribeStacksOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ StackRollbackComplete
Returns a new instance of StackRollbackComplete.
574 575 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 574
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
623 624 625 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 623 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeStacksOutput
Returns a response object which responds to the following methods:
- #stacks => Array<Types::Stack>
- #next_token => String
618 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 618
def wait: (
|