Class: Aws::CloudFormation::Waiters::TypeRegistrationComplete

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-cloudformation/waiters.rb,
sig/waiters.rbs

Overview

Wait until type registration is COMPLETE.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ TypeRegistrationComplete

Returns a new instance of TypeRegistrationComplete.

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 120
  • :delay (Integer) — default: 30
  • :before_attempt (Proc)
  • :before_wait (Proc)


698
699
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 698

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



730
731
732
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 730

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeTypeRegistrationOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :registration_token (required, String)

    The identifier for this registration request.

    This registration token is generated by CloudFormation when you initiate a registration request using RegisterType.



725
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 725

def wait: (