Class: Aws::CloudFormation::Stack
- Inherits:
-
Object
- Object
- Aws::CloudFormation::Stack
- Extended by:
- Deprecations
- Defined in:
- lib/aws-sdk-cloudformation/stack.rb
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#capabilities ⇒ Array<String>
The capabilities allowed in the stack.
-
#change_set_id ⇒ String
The unique ID of the change set.
-
#creation_time ⇒ Time
The time at which the stack was created.
-
#deletion_mode ⇒ String
Specifies the deletion mode for the stack.
-
#deletion_time ⇒ Time
The time the stack was deleted.
-
#description ⇒ String
A user-defined description associated with the stack.
-
#detailed_status ⇒ String
The detailed status of the resource or stack.
-
#disable_rollback ⇒ Boolean
Boolean to enable or disable rollback on stack creation failures:.
-
#drift_information ⇒ Types::StackDriftInformation
Information about whether a stack’s actual configuration differs, or has drifted, from its expected configuration, as defined in the stack template and any values specified as template parameters.
-
#enable_termination_protection ⇒ Boolean
Whether termination protection is enabled for the stack.
-
#last_updated_time ⇒ Time
The time the stack was last updated.
- #name ⇒ String (also: #stack_name)
-
#notification_arns ⇒ Array<String>
Amazon SNS topic Amazon Resource Names (ARNs) to which stack related events are published.
-
#outputs ⇒ Array<Types::Output>
A list of output structures.
-
#parameters ⇒ Array<Types::Parameter>
A list of
Parameterstructures. -
#parent_id ⇒ String
For nested stacks–stacks created as resources for another stack–the stack ID of the direct parent of this stack.
-
#retain_except_on_create ⇒ Boolean
When set to
true, newly created resources are deleted when the operation rolls back. -
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that’s associated with the stack.
-
#rollback_configuration ⇒ Types::RollbackConfiguration
The rollback triggers for CloudFormation to monitor during stack creation and updating operations, and for the specified monitoring period afterwards.
-
#root_id ⇒ String
For nested stacks–stacks created as resources for another stack–the stack ID of the top-level stack to which the nested stack ultimately belongs.
-
#stack_id ⇒ String
Unique identifier of the stack.
-
#stack_status ⇒ String
Current status of the stack.
-
#stack_status_reason ⇒ String
Success/failure message associated with the stack status.
-
#tags ⇒ Array<Types::Tag>
A list of ‘Tag`s that specify information about the stack.
-
#timeout_in_minutes ⇒ Integer
The amount of time within which stack creation should complete.
Actions collapse
- #cancel_update(options = {}) ⇒ EmptyStructure
- #create(options = {}) ⇒ Types::CreateStackOutput
- #delete(options = {}) ⇒ EmptyStructure
- #update(options = {}) ⇒ Types::UpdateStackOutput
Associations collapse
- #events(options = {}) ⇒ Event::Collection
- #identifiers ⇒ Object deprecated private Deprecated.
- #resource(logical_id) ⇒ StackResource
- #resource_summaries(options = {}) ⇒ StackResourceSummary::Collection
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::Stack
Returns the data for this Stack.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#exists?(options = {}) ⇒ Boolean
Returns
trueif the Stack exists. -
#initialize(*args) ⇒ Stack
constructor
A new instance of Stack.
- #load ⇒ self (also: #reload)
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::CloudFormation::Client] #wait_until instead
- #wait_until_exists(options = {}, &block) ⇒ Stack
Constructor Details
#initialize(name, options = {}) ⇒ Stack #initialize(options = {}) ⇒ Stack
Returns a new instance of Stack.
22 23 24 25 26 27 28 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 22 def initialize(*args) = Hash === args.last ? args.pop.dup : {} @name = extract_name(args, ) @data = .delete(:data) @client = .delete(:client) || Client.new() @waiter_block_warned = false end |
Instance Method Details
#cancel_update(options = {}) ⇒ EmptyStructure
432 433 434 435 436 437 438 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 432 def cancel_update( = {}) = .merge(stack_name: @name) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.cancel_update_stack() end resp.data end |
#capabilities ⇒ Array<String>
The capabilities allowed in the stack.
126 127 128 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 126 def capabilities data[:capabilities] end |
#change_set_id ⇒ String
The unique ID of the change set.
46 47 48 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 46 def change_set_id data[:change_set_id] end |
#client ⇒ Client
251 252 253 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 251 def client @client end |
#create(options = {}) ⇒ Types::CreateStackOutput
719 720 721 722 723 724 725 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 719 def create( = {}) = .merge(stack_name: @name) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.create_stack() end resp.data end |
#creation_time ⇒ Time
The time at which the stack was created.
64 65 66 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 64 def creation_time data[:creation_time] end |
#data ⇒ Types::Stack
Returns the data for this Aws::CloudFormation::Stack. Calls Client#describe_stacks if #data_loaded? is false.
273 274 275 276 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 273 def data load unless @data @data end |
#data_loaded? ⇒ Boolean
281 282 283 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 281 def data_loaded? !!@data end |
#delete(options = {}) ⇒ EmptyStructure
782 783 784 785 786 787 788 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 782 def delete( = {}) = .merge(stack_name: @name) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.delete_stack() end resp.data end |
#deletion_mode ⇒ String
Specifies the deletion mode for the stack. Possible values are:
-
STANDARD- Use the standard behavior. Specifying this value is the same as not specifying this parameter. -
FORCE_DELETE_STACK- Delete the stack if it’s stuck in aDELETE_FAILEDstate due to resource deletion failure.
228 229 230 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 228 def deletion_mode data[:deletion_mode] end |
#deletion_time ⇒ Time
The time the stack was deleted.
70 71 72 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 70 def deletion_time data[:deletion_time] end |
#description ⇒ String
A user-defined description associated with the stack.
52 53 54 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 52 def description data[:description] end |
#detailed_status ⇒ String
The detailed status of the resource or stack. If CONFIGURATION_COMPLETE is present, the resource or resource configuration phase has completed and the stabilization of the resources is in progress. The stack sets CONFIGURATION_COMPLETE when all of the resources in the stack have reached that event. For more information, see [Understand CloudFormation stack creation events] in the *CloudFormation User Guide*.
[1]: docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stack-resource-configuration-complete.html
244 245 246 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 244 def detailed_status data[:detailed_status] end |
#disable_rollback ⇒ Boolean
Boolean to enable or disable rollback on stack creation failures:
-
true: disable rollback. -
false: enable rollback.
107 108 109 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 107 def disable_rollback data[:disable_rollback] end |
#drift_information ⇒ Types::StackDriftInformation
Information about whether a stack’s actual configuration differs, or has drifted, from its expected configuration, as defined in the stack template and any values specified as template parameters. For more information, see [Detect unmanaged configuration changes to stacks and resources with drift detection].
[1]: docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-stack-drift.html
206 207 208 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 206 def drift_information data[:drift_information] end |
#enable_termination_protection ⇒ Boolean
Whether termination protection is enabled for the stack.
For [nested stacks], termination protection is set on the root stack and can’t be changed directly on the nested stack. For more information, see [Protect a CloudFormation stack from being deleted] in the *CloudFormation User Guide*.
[1]: docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-nested-stacks.html [2]: docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-protect-stacks.html
162 163 164 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 162 def enable_termination_protection data[:enable_termination_protection] end |
#events(options = {}) ⇒ Event::Collection
1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 1090 def events( = {}) batches = Enumerator.new do |y| = .merge(stack_name: @name) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_stack_events() end resp.each_page do |page| batch = [] page.data.stack_events.each do |s| batch << Event.new( id: s.event_id, data: s, client: @client ) end y.yield(batch) end end Event::Collection.new(batches) end |
#exists?(options = {}) ⇒ Boolean
Returns true if the Stack exists.
288 289 290 291 292 293 294 295 296 297 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 288 def exists?( = {}) begin wait_until_exists(.merge(max_attempts: 1)) true rescue Aws::Waiters::Errors::UnexpectedError => e raise e.error rescue Aws::Waiters::Errors::WaiterFailed false end end |
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1150 1151 1152 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 1150 def identifiers { name: @name } end |
#last_updated_time ⇒ Time
The time the stack was last updated. This field will only be returned if the stack has been updated at least once.
77 78 79 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 77 def last_updated_time data[:last_updated_time] end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::CloudFormation::Stack. Returns self making it possible to chain methods.
stack.reload.data
261 262 263 264 265 266 267 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 261 def load resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_stacks(stack_name: @name) end @data = resp.stacks[0] self end |
#name ⇒ String Also known as: stack_name
33 34 35 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 33 def name @name end |
#notification_arns ⇒ Array<String>
Amazon SNS topic Amazon Resource Names (ARNs) to which stack related events are published.
114 115 116 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 114 def notification_arns data[:notification_arns] end |
#outputs ⇒ Array<Types::Output>
A list of output structures.
132 133 134 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 132 def outputs data[:outputs] end |
#parameters ⇒ Array<Types::Parameter>
A list of Parameter structures.
58 59 60 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 58 def parameters data[:parameters] end |
#parent_id ⇒ String
For nested stacks–stacks created as resources for another stack–the stack ID of the direct parent of this stack. For the first level of nested stacks, the root stack is also the parent stack.
For more information, see [Embed stacks within other stacks using nested stacks] in the *CloudFormation User Guide*.
[1]: docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-nested-stacks.html
177 178 179 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 177 def parent_id data[:parent_id] end |
#resource(logical_id) ⇒ StackResource
1113 1114 1115 1116 1117 1118 1119 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 1113 def resource(logical_id) StackResource.new( stack_name: @name, logical_id: logical_id, client: @client ) end |
#resource_summaries(options = {}) ⇒ StackResourceSummary::Collection
1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 1126 def resource_summaries( = {}) batches = Enumerator.new do |y| = .merge(stack_name: @name) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.list_stack_resources() end resp.each_page do |page| batch = [] page.data.stack_resource_summaries.each do |s| batch << StackResourceSummary.new( logical_id: s.logical_resource_id, stack_name: [:stack_name], data: s, client: @client ) end y.yield(batch) end end StackResourceSummary::Collection.new(batches) end |
#retain_except_on_create ⇒ Boolean
When set to true, newly created resources are deleted when the operation rolls back. This includes newly created resources marked with a deletion policy of Retain.
Default: false
216 217 218 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 216 def retain_except_on_create data[:retain_except_on_create] end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that’s associated with the stack. During a stack operation, CloudFormation uses this role’s credentials to make calls on your behalf.
140 141 142 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 140 def role_arn data[:role_arn] end |
#rollback_configuration ⇒ Types::RollbackConfiguration
The rollback triggers for CloudFormation to monitor during stack creation and updating operations, and for the specified monitoring period afterwards.
85 86 87 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 85 def rollback_configuration data[:rollback_configuration] end |
#root_id ⇒ String
For nested stacks–stacks created as resources for another stack–the stack ID of the top-level stack to which the nested stack ultimately belongs.
For more information, see [Embed stacks within other stacks using nested stacks] in the *CloudFormation User Guide*.
[1]: docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-nested-stacks.html
192 193 194 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 192 def root_id data[:root_id] end |
#stack_id ⇒ String
Unique identifier of the stack.
40 41 42 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 40 def stack_id data[:stack_id] end |
#stack_status ⇒ String
Current status of the stack.
91 92 93 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 91 def stack_status data[:stack_status] end |
#stack_status_reason ⇒ String
Success/failure message associated with the stack status.
97 98 99 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 97 def stack_status_reason data[:stack_status_reason] end |
#tags ⇒ Array<Types::Tag>
A list of ‘Tag`s that specify information about the stack.
146 147 148 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 146 def data[:tags] end |
#timeout_in_minutes ⇒ Integer
The amount of time within which stack creation should complete.
120 121 122 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 120 def timeout_in_minutes data[:timeout_in_minutes] end |
#update(options = {}) ⇒ Types::UpdateStackOutput
1075 1076 1077 1078 1079 1080 1081 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 1075 def update( = {}) = .merge(stack_name: @name) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.update_stack() end resp.data end |
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::CloudFormation::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
## Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
## Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
## Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 398 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |
#wait_until_exists(options = {}, &block) ⇒ Stack
305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/aws-sdk-cloudformation/stack.rb', line 305 def wait_until_exists( = {}, &block) , params = () waiter = Waiters::StackExists.new() yield_waiter_and_warn(waiter, &block) if block_given? Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do waiter.wait(params.merge(stack_name: @name)) end Stack.new({ name: @name, client: @client }) end |