Class: Aws::CloudFormation::Types::CreateStackRefactorInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::CreateStackRefactorInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description to help you identify the stack refactor.
-
#enable_stack_creation ⇒ Boolean
Determines if a new stack is created with the refactor.
-
#resource_mappings ⇒ Array<Types::ResourceMapping>
The mappings for the stack resource
Sourceand stack resourceDestination. -
#stack_definitions ⇒ Array<Types::StackDefinition>
The stacks being refactored.
Instance Attribute Details
#description ⇒ String
A description to help you identify the stack refactor.
1682 1683 1684 1685 1686 1687 1688 1689 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1682 class CreateStackRefactorInput < Struct.new( :description, :enable_stack_creation, :resource_mappings, :stack_definitions) SENSITIVE = [] include Aws::Structure end |
#enable_stack_creation ⇒ Boolean
Determines if a new stack is created with the refactor.
1682 1683 1684 1685 1686 1687 1688 1689 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1682 class CreateStackRefactorInput < Struct.new( :description, :enable_stack_creation, :resource_mappings, :stack_definitions) SENSITIVE = [] include Aws::Structure end |
#resource_mappings ⇒ Array<Types::ResourceMapping>
The mappings for the stack resource Source and stack resource Destination.
1682 1683 1684 1685 1686 1687 1688 1689 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1682 class CreateStackRefactorInput < Struct.new( :description, :enable_stack_creation, :resource_mappings, :stack_definitions) SENSITIVE = [] include Aws::Structure end |
#stack_definitions ⇒ Array<Types::StackDefinition>
The stacks being refactored.
1682 1683 1684 1685 1686 1687 1688 1689 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 1682 class CreateStackRefactorInput < Struct.new( :description, :enable_stack_creation, :resource_mappings, :stack_definitions) SENSITIVE = [] include Aws::Structure end |