Class: Aws::CloudFormation::Types::DeploymentConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::DeploymentConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
The deployment configuration for a stack operation, including the deployment mode.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#disable_rollback ⇒ Boolean
Specifies whether to disable rollback of the stack if the stack operation fails.
-
#mode ⇒ String
Specifies the deployment mode for the stack operation.
Instance Attribute Details
#disable_rollback ⇒ Boolean
Specifies whether to disable rollback of the stack if the stack operation fails.
Default: false
2359 2360 2361 2362 2363 2364 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2359 class DeploymentConfig < Struct.new( :mode, :disable_rollback) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
Specifies the deployment mode for the stack operation. Possible values are:
-
STANDARD- Use the standard deployment behavior, ensuring resources are ready to serve traffic before completing the operation. This is the default. You do not need to specify this value explicitly. -
EXPRESS- Complete the stack operation when resource configuration is applied, without waiting for resources to become ready to serve traffic. Resources continue becoming ready in the background.
2359 2360 2361 2362 2363 2364 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 2359 class DeploymentConfig < Struct.new( :mode, :disable_rollback) SENSITIVE = [] include Aws::Structure end |