Class: Aws::CloudFormation::Types::DescribeTypeInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::DescribeTypeInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the extension.
-
#public_version_number ⇒ String
The version number of a public third-party extension.
-
#publisher_id ⇒ String
The publisher ID of the extension publisher.
-
#type ⇒ String
The kind of extension.
-
#type_name ⇒ String
The name of the extension.
-
#version_id ⇒ String
The ID of a specific version of the extension.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the extension.
Conditional: You must specify either TypeName and Type, or
Arn.
3826 3827 3828 3829 3830 3831 3832 3833 3834 3835 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 3826 class DescribeTypeInput < Struct.new( :type, :type_name, :arn, :version_id, :publisher_id, :public_version_number) SENSITIVE = [] include Aws::Structure end |
#public_version_number ⇒ String
The version number of a public third-party extension.
3826 3827 3828 3829 3830 3831 3832 3833 3834 3835 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 3826 class DescribeTypeInput < Struct.new( :type, :type_name, :arn, :version_id, :publisher_id, :public_version_number) SENSITIVE = [] include Aws::Structure end |
#publisher_id ⇒ String
The publisher ID of the extension publisher.
Extensions provided by Amazon Web Services are not assigned a publisher ID.
3826 3827 3828 3829 3830 3831 3832 3833 3834 3835 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 3826 class DescribeTypeInput < Struct.new( :type, :type_name, :arn, :version_id, :publisher_id, :public_version_number) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The kind of extension.
Conditional: You must specify either TypeName and Type, or
Arn.
3826 3827 3828 3829 3830 3831 3832 3833 3834 3835 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 3826 class DescribeTypeInput < Struct.new( :type, :type_name, :arn, :version_id, :publisher_id, :public_version_number) SENSITIVE = [] include Aws::Structure end |
#type_name ⇒ String
The name of the extension.
Conditional: You must specify either TypeName and Type, or
Arn.
3826 3827 3828 3829 3830 3831 3832 3833 3834 3835 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 3826 class DescribeTypeInput < Struct.new( :type, :type_name, :arn, :version_id, :publisher_id, :public_version_number) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The ID of a specific version of the extension. The version ID is the value at the end of the Amazon Resource Name (ARN) assigned to the extension version when it is registered.
If you specify a VersionId, DescribeType returns information
about that specific extension version. Otherwise, it returns
information about the default extension version.
3826 3827 3828 3829 3830 3831 3832 3833 3834 3835 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 3826 class DescribeTypeInput < Struct.new( :type, :type_name, :arn, :version_id, :publisher_id, :public_version_number) SENSITIVE = [] include Aws::Structure end |