Class: Aws::CloudFormation::Types::ListHookResultsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ListHookResultsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token for the next set of items to return.
-
#status ⇒ String
Filters results by the status of Hook invocations.
-
#target_id ⇒ String
Filters results by the unique identifier of the target the Hook was invoked against.
-
#target_type ⇒ String
Filters results by target type.
-
#type_arn ⇒ String
Filters results by the ARN of the Hook.
Instance Attribute Details
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
5319 5320 5321 5322 5323 5324 5325 5326 5327 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5319 class ListHookResultsInput < Struct.new( :target_type, :target_id, :type_arn, :status, :next_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Filters results by the status of Hook invocations. Can only be used in combination with TypeArn. Valid values are:
-
HOOK_IN_PROGRESS: The Hook is currently running. -
HOOK_COMPLETE_SUCCEEDED: The Hook completed successfully. -
HOOK_COMPLETE_FAILED: The Hook completed but failed validation. -
HOOK_FAILED: The Hook encountered an error during execution.
5319 5320 5321 5322 5323 5324 5325 5326 5327 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5319 class ListHookResultsInput < Struct.new( :target_type, :target_id, :type_arn, :status, :next_token) SENSITIVE = [] include Aws::Structure end |
#target_id ⇒ String
Filters results by the unique identifier of the target the Hook was invoked against.
For change sets, this is the change set ARN. When the target is a Cloud Control API operation, this value must be the HookRequestToken returned by the Cloud Control API request. For more information on the HookRequestToken, see [ProgressEvent].
Required when TargetType is specified and cannot be used otherwise.
[1]: docs.aws.amazon.com/cloudcontrolapi/latest/APIReference/API_ProgressEvent.html
5319 5320 5321 5322 5323 5324 5325 5326 5327 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5319 class ListHookResultsInput < Struct.new( :target_type, :target_id, :type_arn, :status, :next_token) SENSITIVE = [] include Aws::Structure end |
#target_type ⇒ String
Filters results by target type. Currently, only CHANGE_SET and CLOUD_CONTROL are supported filter options.
Required when TargetId is specified and cannot be used otherwise.
5319 5320 5321 5322 5323 5324 5325 5326 5327 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5319 class ListHookResultsInput < Struct.new( :target_type, :target_id, :type_arn, :status, :next_token) SENSITIVE = [] include Aws::Structure end |
#type_arn ⇒ String
Filters results by the ARN of the Hook. Can be used alone or in combination with Status.
5319 5320 5321 5322 5323 5324 5325 5326 5327 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5319 class ListHookResultsInput < Struct.new( :target_type, :target_id, :type_arn, :status, :next_token) SENSITIVE = [] include Aws::Structure end |