Class: Aws::CloudFormation::Types::ListResourceScanRelatedResourcesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ListResourceScanRelatedResourcesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
If the number of available results exceeds this maximum, the response includes a
NextTokenvalue that you can use for theNextTokenparameter to get the next set of results. -
#next_token ⇒ String
The token for the next set of items to return.
-
#resource_scan_id ⇒ String
The Amazon Resource Name (ARN) of the resource scan.
-
#resources ⇒ Array<Types::ScannedResourceIdentifier>
The list of resources for which you want to get the related resources.
Instance Attribute Details
#max_results ⇒ Integer
If the number of available results exceeds this maximum, the response includes a NextToken value that you can use for the NextToken parameter to get the next set of results. By default the ListResourceScanRelatedResources API action will return up to 100 results in each response. The maximum value is 100.
5420 5421 5422 5423 5424 5425 5426 5427 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5420 class < Struct.new( :resource_scan_id, :resources, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
5420 5421 5422 5423 5424 5425 5426 5427 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5420 class < Struct.new( :resource_scan_id, :resources, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_scan_id ⇒ String
The Amazon Resource Name (ARN) of the resource scan.
5420 5421 5422 5423 5424 5425 5426 5427 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5420 class < Struct.new( :resource_scan_id, :resources, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resources ⇒ Array<Types::ScannedResourceIdentifier>
The list of resources for which you want to get the related resources. Up to 100 resources can be provided.
5420 5421 5422 5423 5424 5425 5426 5427 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5420 class < Struct.new( :resource_scan_id, :resources, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |