Class: Aws::CloudFormation::Types::ListResourceScanResourcesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ListResourceScanResourcesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
If the number of available results exceeds this maximum, the response includes a
NextTokenvalue that you can use for theNextTokenparameter to get the next set of results. -
#next_token ⇒ String
The token for the next set of items to return.
-
#resource_identifier ⇒ String
If specified, the returned resources will have the specified resource identifier (or one of them in the case where the resource has multiple identifiers).
-
#resource_scan_id ⇒ String
The Amazon Resource Name (ARN) of the resource scan.
-
#resource_type_prefix ⇒ String
If specified, the returned resources will be of any of the resource types with the specified prefix.
-
#tag_key ⇒ String
If specified, the returned resources will have a matching tag key.
-
#tag_value ⇒ String
If specified, the returned resources will have a matching tag value.
Instance Attribute Details
#max_results ⇒ Integer
If the number of available results exceeds this maximum, the response includes a NextToken value that you can use for the NextToken parameter to get the next set of results. By default the ListResourceScanResources API action will return at most 100 results in each response. The maximum value is 100.
5489 5490 5491 5492 5493 5494 5495 5496 5497 5498 5499 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5489 class ListResourceScanResourcesInput < Struct.new( :resource_scan_id, :resource_identifier, :resource_type_prefix, :tag_key, :tag_value, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
5489 5490 5491 5492 5493 5494 5495 5496 5497 5498 5499 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5489 class ListResourceScanResourcesInput < Struct.new( :resource_scan_id, :resource_identifier, :resource_type_prefix, :tag_key, :tag_value, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_identifier ⇒ String
If specified, the returned resources will have the specified resource identifier (or one of them in the case where the resource has multiple identifiers).
5489 5490 5491 5492 5493 5494 5495 5496 5497 5498 5499 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5489 class ListResourceScanResourcesInput < Struct.new( :resource_scan_id, :resource_identifier, :resource_type_prefix, :tag_key, :tag_value, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_scan_id ⇒ String
The Amazon Resource Name (ARN) of the resource scan.
5489 5490 5491 5492 5493 5494 5495 5496 5497 5498 5499 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5489 class ListResourceScanResourcesInput < Struct.new( :resource_scan_id, :resource_identifier, :resource_type_prefix, :tag_key, :tag_value, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#resource_type_prefix ⇒ String
If specified, the returned resources will be of any of the resource types with the specified prefix.
5489 5490 5491 5492 5493 5494 5495 5496 5497 5498 5499 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5489 class ListResourceScanResourcesInput < Struct.new( :resource_scan_id, :resource_identifier, :resource_type_prefix, :tag_key, :tag_value, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#tag_key ⇒ String
If specified, the returned resources will have a matching tag key.
5489 5490 5491 5492 5493 5494 5495 5496 5497 5498 5499 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5489 class ListResourceScanResourcesInput < Struct.new( :resource_scan_id, :resource_identifier, :resource_type_prefix, :tag_key, :tag_value, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#tag_value ⇒ String
If specified, the returned resources will have a matching tag value.
5489 5490 5491 5492 5493 5494 5495 5496 5497 5498 5499 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5489 class ListResourceScanResourcesInput < Struct.new( :resource_scan_id, :resource_identifier, :resource_type_prefix, :tag_key, :tag_value, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |