Class: Aws::CloudFormation::Types::ListResourceScansInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ListResourceScansInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
If the number of available results exceeds this maximum, the response includes a
NextTokenvalue that you can use for theNextTokenparameter to get the next set of results. -
#next_token ⇒ String
The token for the next set of items to return.
-
#scan_type_filter ⇒ String
The scan type that you want to get summary information about.
Instance Attribute Details
#max_results ⇒ Integer
If the number of available results exceeds this maximum, the response includes a NextToken value that you can use for the NextToken parameter to get the next set of results. The default value is 10. The maximum value is 100.
5542 5543 5544 5545 5546 5547 5548 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5542 class ListResourceScansInput < Struct.new( :next_token, :max_results, :scan_type_filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
5542 5543 5544 5545 5546 5547 5548 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5542 class ListResourceScansInput < Struct.new( :next_token, :max_results, :scan_type_filter) SENSITIVE = [] include Aws::Structure end |
#scan_type_filter ⇒ String
The scan type that you want to get summary information about. The default is FULL.
5542 5543 5544 5545 5546 5547 5548 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5542 class ListResourceScansInput < Struct.new( :next_token, :max_results, :scan_type_filter) SENSITIVE = [] include Aws::Structure end |