Class: Aws::CloudFormation::Types::ListStackInstancesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ListStackInstancesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the request doesn’t return all the remaining results,
NextTokenis set to a token. -
#summaries ⇒ Array<Types::StackInstanceSummary>
A list of
StackInstanceSummarystructures that contain information about the specified stack instances.
Instance Attribute Details
#next_token ⇒ String
If the request doesn’t return all the remaining results, NextToken is set to a token. To retrieve the next set of results, call ListStackInstances again and assign that token to the request object’s NextToken parameter. If the request returns all results, NextToken is set to null.
5760 5761 5762 5763 5764 5765 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5760 class ListStackInstancesOutput < Struct.new( :summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#summaries ⇒ Array<Types::StackInstanceSummary>
A list of StackInstanceSummary structures that contain information about the specified stack instances.
5760 5761 5762 5763 5764 5765 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5760 class ListStackInstancesOutput < Struct.new( :summaries, :next_token) SENSITIVE = [] include Aws::Structure end |