Class: Aws::CloudFormation::Types::ListStackRefactorActionsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ListStackRefactorActionsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to be returned with a single call.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#stack_refactor_id ⇒ String
The ID associated with the stack refactor created from the CreateStackRefactor action.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to be returned with a single call. If the number of available results exceeds this maximum, the response includes a NextToken value that you can assign to the NextToken request parameter to get the next set of results.
5786 5787 5788 5789 5790 5791 5792 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5786 class ListStackRefactorActionsInput < Struct.new( :stack_refactor_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
5786 5787 5788 5789 5790 5791 5792 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5786 class ListStackRefactorActionsInput < Struct.new( :stack_refactor_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#stack_refactor_id ⇒ String
The ID associated with the stack refactor created from the CreateStackRefactor action.
5786 5787 5788 5789 5790 5791 5792 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5786 class ListStackRefactorActionsInput < Struct.new( :stack_refactor_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |