Class: Aws::CloudFormation::Types::ListStackRefactorsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ListStackRefactorsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_status_filter ⇒ Array<String>
Execution status to use as a filter.
-
#max_results ⇒ Integer
The maximum number of results to be returned with a single call.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#execution_status_filter ⇒ Array<String>
Execution status to use as a filter. Specify one or more execution status codes to list only stack refactors with the specified execution status codes.
5835 5836 5837 5838 5839 5840 5841 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5835 class ListStackRefactorsInput < Struct.new( :execution_status_filter, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to be returned with a single call. If the number of available results exceeds this maximum, the response includes a NextToken value that you can assign to the NextToken request parameter to get the next set of results.
5835 5836 5837 5838 5839 5840 5841 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5835 class ListStackRefactorsInput < Struct.new( :execution_status_filter, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
5835 5836 5837 5838 5839 5840 5841 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5835 class ListStackRefactorsInput < Struct.new( :execution_status_filter, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |