Class: Aws::CloudFormation::Types::ListStackSetAutoDeploymentTargetsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ListStackSetAutoDeploymentTargetsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the request doesn’t return all the remaining results,
NextTokenis set to a token. -
#summaries ⇒ Array<Types::StackSetAutoDeploymentTargetSummary>
An array of summaries of the deployment targets for the StackSet.
Instance Attribute Details
#next_token ⇒ String
If the request doesn’t return all the remaining results, NextToken is set to a token. To retrieve the next set of results, call [ListStackSetAutoDeploymentTargets] again and use that value for the NextToken parameter. If the request returns all results, NextToken is set to an empty string.
[1]: docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListStackSetAutoDeploymentTargets.html
5992 5993 5994 5995 5996 5997 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5992 class ListStackSetAutoDeploymentTargetsOutput < Struct.new( :summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#summaries ⇒ Array<Types::StackSetAutoDeploymentTargetSummary>
An array of summaries of the deployment targets for the StackSet.
5992 5993 5994 5995 5996 5997 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 5992 class ListStackSetAutoDeploymentTargetsOutput < Struct.new( :summaries, :next_token) SENSITIVE = [] include Aws::Structure end |