Class: Aws::CloudFormation::Types::ListStackSetsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ListStackSetsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#call_as ⇒ String
[Service-managed permissions] Specifies whether you are acting as an account administrator in the management account or as a delegated administrator in a member account.
-
#max_results ⇒ Integer
The maximum number of results to be returned with a single call.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#status ⇒ String
The status of the StackSets that you want to get summary information about.
Instance Attribute Details
#call_as ⇒ String
[Service-managed permissions] Specifies whether you are acting as an account administrator in the management account or as a delegated administrator in a member account.
By default, SELF is specified. Use SELF for StackSets with self-managed permissions.
-
If you are signed in to the management account, specify
SELF. -
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see
- Register a delegated administrator][1
-
in the *CloudFormation
User Guide*.
[1]: docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-orgs-delegated-admin.html
6198 6199 6200 6201 6202 6203 6204 6205 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6198 class ListStackSetsInput < Struct.new( :next_token, :max_results, :status, :call_as) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to be returned with a single call. If the number of available results exceeds this maximum, the response includes a NextToken value that you can assign to the NextToken request parameter to get the next set of results.
6198 6199 6200 6201 6202 6203 6204 6205 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6198 class ListStackSetsInput < Struct.new( :next_token, :max_results, :status, :call_as) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
6198 6199 6200 6201 6202 6203 6204 6205 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6198 class ListStackSetsInput < Struct.new( :next_token, :max_results, :status, :call_as) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the StackSets that you want to get summary information about.
6198 6199 6200 6201 6202 6203 6204 6205 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6198 class ListStackSetsInput < Struct.new( :next_token, :max_results, :status, :call_as) SENSITIVE = [] include Aws::Structure end |