Class: Aws::CloudFormation::Types::ListTypeRegistrationsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ListTypeRegistrationsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to be returned with a single call.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#registration_status_filter ⇒ String
The current status of the extension registration request.
-
#type ⇒ String
The kind of extension.
-
#type_arn ⇒ String
The Amazon Resource Name (ARN) of the extension.
-
#type_name ⇒ String
The name of the extension.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to be returned with a single call. If the number of available results exceeds this maximum, the response includes a NextToken value that you can assign to the NextToken request parameter to get the next set of results.
6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6315 class ListTypeRegistrationsInput < Struct.new( :type, :type_name, :type_arn, :registration_status_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6315 class ListTypeRegistrationsInput < Struct.new( :type, :type_name, :type_arn, :registration_status_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#registration_status_filter ⇒ String
The current status of the extension registration request.
The default is IN_PROGRESS.
6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6315 class ListTypeRegistrationsInput < Struct.new( :type, :type_name, :type_arn, :registration_status_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The kind of extension.
Conditional: You must specify either TypeName and Type, or Arn.
6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6315 class ListTypeRegistrationsInput < Struct.new( :type, :type_name, :type_arn, :registration_status_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#type_arn ⇒ String
The Amazon Resource Name (ARN) of the extension.
Conditional: You must specify either TypeName and Type, or Arn.
6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6315 class ListTypeRegistrationsInput < Struct.new( :type, :type_name, :type_arn, :registration_status_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#type_name ⇒ String
The name of the extension.
Conditional: You must specify either TypeName and Type, or Arn.
6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6315 class ListTypeRegistrationsInput < Struct.new( :type, :type_name, :type_arn, :registration_status_filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |