Class: Aws::CloudFormation::Types::ListTypesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ListTypesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the request doesn’t return all the remaining results,
NextTokenis set to a token. -
#type_summaries ⇒ Array<Types::TypeSummary>
A list of
TypeSummarystructures that contain information about the specified extensions.
Instance Attribute Details
#next_token ⇒ String
If the request doesn’t return all the remaining results, NextToken is set to a token. To retrieve the next set of results, call this action again and assign that token to the request object’s NextToken parameter. If the request returns all results, NextToken is set to null.
6553 6554 6555 6556 6557 6558 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6553 class ListTypesOutput < Struct.new( :type_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#type_summaries ⇒ Array<Types::TypeSummary>
A list of TypeSummary structures that contain information about the specified extensions.
6553 6554 6555 6556 6557 6558 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 6553 class ListTypesOutput < Struct.new( :type_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |