Class: Aws::CloudFormation::Types::ResourceChange
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::ResourceChange
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
The ResourceChange structure describes the resource and the action
that CloudFormation will perform on it if you execute this change set.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action that CloudFormation takes on the resource, such as
Add(adds a new resource),Modify(changes a resource),Remove(deletes a resource),Import(imports a resource),Dynamic(exact action for the resource can't be determined), orSyncWithActual(resource will not be changed, only CloudFormation metadata will change). -
#after_context ⇒ String
An encoded JSON string that contains the context of the resource after the change is executed.
-
#before_context ⇒ String
An encoded JSON string that contains the context of the resource before the change is executed.
-
#change_set_id ⇒ String
The change set ID of the nested change set.
-
#details ⇒ Array<Types::ResourceChangeDetail>
For the
Modifyaction, a list ofResourceChangeDetailstructures that describes the changes that CloudFormation will make to the resource. -
#logical_resource_id ⇒ String
The resource's logical ID, which is defined in the stack's template.
-
#module_info ⇒ Types::ModuleInfo
Contains information about the module from which the resource was created, if the resource was created from a module included in the stack template.
-
#physical_resource_id ⇒ String
The resource's physical ID (resource name).
-
#policy_action ⇒ String
The action that will be taken on the physical resource when the change set is executed.
-
#previous_deployment_context ⇒ String
Information about the resource's state from the previous CloudFormation deployment.
-
#replacement ⇒ String
For the
Modifyaction, indicates whether CloudFormation will replace the resource by creating a new one and deleting the old one. -
#resource_drift_ignored_attributes ⇒ Array<Types::ResourceDriftIgnoredAttribute>
List of resource attributes for which drift was ignored.
-
#resource_drift_status ⇒ String
The drift status of the resource.
-
#resource_type ⇒ String
The type of CloudFormation resource, such as
AWS::S3::Bucket. -
#scope ⇒ Array<String>
For the
Modifyaction, indicates which resource attribute is triggering this update, such as a change in the resource attribute'sMetadata,Properties, orTags.
Instance Attribute Details
#action ⇒ String
The action that CloudFormation takes on the resource, such as Add
(adds a new resource), Modify (changes a resource), Remove
(deletes a resource), Import (imports a resource), Dynamic
(exact action for the resource can't be determined), or
SyncWithActual (resource will not be changed, only CloudFormation
metadata will change).
7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669 class ResourceChange < Struct.new( :policy_action, :action, :logical_resource_id, :physical_resource_id, :resource_type, :replacement, :scope, :resource_drift_status, :resource_drift_ignored_attributes, :details, :change_set_id, :module_info, :before_context, :after_context, :previous_deployment_context) SENSITIVE = [] include Aws::Structure end |
#after_context ⇒ String
An encoded JSON string that contains the context of the resource after the change is executed.
7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669 class ResourceChange < Struct.new( :policy_action, :action, :logical_resource_id, :physical_resource_id, :resource_type, :replacement, :scope, :resource_drift_status, :resource_drift_ignored_attributes, :details, :change_set_id, :module_info, :before_context, :after_context, :previous_deployment_context) SENSITIVE = [] include Aws::Structure end |
#before_context ⇒ String
An encoded JSON string that contains the context of the resource before the change is executed.
7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669 class ResourceChange < Struct.new( :policy_action, :action, :logical_resource_id, :physical_resource_id, :resource_type, :replacement, :scope, :resource_drift_status, :resource_drift_ignored_attributes, :details, :change_set_id, :module_info, :before_context, :after_context, :previous_deployment_context) SENSITIVE = [] include Aws::Structure end |
#change_set_id ⇒ String
The change set ID of the nested change set.
7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669 class ResourceChange < Struct.new( :policy_action, :action, :logical_resource_id, :physical_resource_id, :resource_type, :replacement, :scope, :resource_drift_status, :resource_drift_ignored_attributes, :details, :change_set_id, :module_info, :before_context, :after_context, :previous_deployment_context) SENSITIVE = [] include Aws::Structure end |
#details ⇒ Array<Types::ResourceChangeDetail>
For the Modify action, a list of ResourceChangeDetail structures
that describes the changes that CloudFormation will make to the
resource.
7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669 class ResourceChange < Struct.new( :policy_action, :action, :logical_resource_id, :physical_resource_id, :resource_type, :replacement, :scope, :resource_drift_status, :resource_drift_ignored_attributes, :details, :change_set_id, :module_info, :before_context, :after_context, :previous_deployment_context) SENSITIVE = [] include Aws::Structure end |
#logical_resource_id ⇒ String
The resource's logical ID, which is defined in the stack's template.
7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669 class ResourceChange < Struct.new( :policy_action, :action, :logical_resource_id, :physical_resource_id, :resource_type, :replacement, :scope, :resource_drift_status, :resource_drift_ignored_attributes, :details, :change_set_id, :module_info, :before_context, :after_context, :previous_deployment_context) SENSITIVE = [] include Aws::Structure end |
#module_info ⇒ Types::ModuleInfo
Contains information about the module from which the resource was created, if the resource was created from a module included in the stack template.
7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669 class ResourceChange < Struct.new( :policy_action, :action, :logical_resource_id, :physical_resource_id, :resource_type, :replacement, :scope, :resource_drift_status, :resource_drift_ignored_attributes, :details, :change_set_id, :module_info, :before_context, :after_context, :previous_deployment_context) SENSITIVE = [] include Aws::Structure end |
#physical_resource_id ⇒ String
The resource's physical ID (resource name). Resources that you are adding don't have physical IDs because they haven't been created.
7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669 class ResourceChange < Struct.new( :policy_action, :action, :logical_resource_id, :physical_resource_id, :resource_type, :replacement, :scope, :resource_drift_status, :resource_drift_ignored_attributes, :details, :change_set_id, :module_info, :before_context, :after_context, :previous_deployment_context) SENSITIVE = [] include Aws::Structure end |
#policy_action ⇒ String
The action that will be taken on the physical resource when the change set is executed.
-
DeleteThe resource will be deleted. -
RetainThe resource will be retained. -
SnapshotThe resource will have a snapshot taken. -
ReplaceAndDeleteThe resource will be replaced and then deleted. -
ReplaceAndRetainThe resource will be replaced and then retained. -
ReplaceAndSnapshotThe resource will be replaced and then have a snapshot taken.
7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669 class ResourceChange < Struct.new( :policy_action, :action, :logical_resource_id, :physical_resource_id, :resource_type, :replacement, :scope, :resource_drift_status, :resource_drift_ignored_attributes, :details, :change_set_id, :module_info, :before_context, :after_context, :previous_deployment_context) SENSITIVE = [] include Aws::Structure end |
#previous_deployment_context ⇒ String
Information about the resource's state from the previous CloudFormation deployment.
7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669 class ResourceChange < Struct.new( :policy_action, :action, :logical_resource_id, :physical_resource_id, :resource_type, :replacement, :scope, :resource_drift_status, :resource_drift_ignored_attributes, :details, :change_set_id, :module_info, :before_context, :after_context, :previous_deployment_context) SENSITIVE = [] include Aws::Structure end |
#replacement ⇒ String
For the Modify action, indicates whether CloudFormation will
replace the resource by creating a new one and deleting the old one.
This value depends on the value of the RequiresRecreation property
in the ResourceTargetDefinition structure. For example, if the
RequiresRecreation field is Always and the Evaluation field is
Static, Replacement is True. If the RequiresRecreation field
is Always and the Evaluation field is Dynamic, Replacement
is Conditional.
If you have multiple changes with different RequiresRecreation
values, the Replacement value depends on the change with the most
impact. A RequiresRecreation value of Always has the most
impact, followed by Conditional, and then Never.
7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669 class ResourceChange < Struct.new( :policy_action, :action, :logical_resource_id, :physical_resource_id, :resource_type, :replacement, :scope, :resource_drift_status, :resource_drift_ignored_attributes, :details, :change_set_id, :module_info, :before_context, :after_context, :previous_deployment_context) SENSITIVE = [] include Aws::Structure end |
#resource_drift_ignored_attributes ⇒ Array<Types::ResourceDriftIgnoredAttribute>
List of resource attributes for which drift was ignored.
7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669 class ResourceChange < Struct.new( :policy_action, :action, :logical_resource_id, :physical_resource_id, :resource_type, :replacement, :scope, :resource_drift_status, :resource_drift_ignored_attributes, :details, :change_set_id, :module_info, :before_context, :after_context, :previous_deployment_context) SENSITIVE = [] include Aws::Structure end |
#resource_drift_status ⇒ String
The drift status of the resource. Valid values:
-
IN_SYNC– The resource matches its template definition. -
MODIFIED– Resource properties were modified outside CloudFormation. -
DELETED– The resource was deleted outside CloudFormation. -
NOT_CHECKED– CloudFormation doesn’t currently return this value. -
UNKNOWN– Drift status could not be determined. -
UNSUPPORTED– Resource type does not support actual state comparison.
Only present for drift-aware change sets.
7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669 class ResourceChange < Struct.new( :policy_action, :action, :logical_resource_id, :physical_resource_id, :resource_type, :replacement, :scope, :resource_drift_status, :resource_drift_ignored_attributes, :details, :change_set_id, :module_info, :before_context, :after_context, :previous_deployment_context) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of CloudFormation resource, such as AWS::S3::Bucket.
7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669 class ResourceChange < Struct.new( :policy_action, :action, :logical_resource_id, :physical_resource_id, :resource_type, :replacement, :scope, :resource_drift_status, :resource_drift_ignored_attributes, :details, :change_set_id, :module_info, :before_context, :after_context, :previous_deployment_context) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ Array<String>
For the Modify action, indicates which resource attribute is
triggering this update, such as a change in the resource
attribute's Metadata, Properties, or Tags.
7669 7670 7671 7672 7673 7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 7684 7685 7686 7687 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 7669 class ResourceChange < Struct.new( :policy_action, :action, :logical_resource_id, :physical_resource_id, :resource_type, :replacement, :scope, :resource_drift_status, :resource_drift_ignored_attributes, :details, :change_set_id, :module_info, :before_context, :after_context, :previous_deployment_context) SENSITIVE = [] include Aws::Structure end |