Class: Aws::CloudFormation::Types::SetStackPolicyInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::SetStackPolicyInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
The input for the SetStackPolicy action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#stack_name ⇒ String
The name or unique stack ID that you want to associate a policy with.
-
#stack_policy_body ⇒ String
Structure that contains the stack policy body.
-
#stack_policy_url ⇒ String
Location of a file that contains the stack policy.
Instance Attribute Details
#stack_name ⇒ String
The name or unique stack ID that you want to associate a policy with.
8431 8432 8433 8434 8435 8436 8437 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 8431 class SetStackPolicyInput < Struct.new( :stack_name, :stack_policy_body, :stack_policy_url) SENSITIVE = [] include Aws::Structure end |
#stack_policy_body ⇒ String
Structure that contains the stack policy body. For more information,
see Prevent updates to stack resources in the CloudFormation
User Guide. You can specify either the StackPolicyBody or the
StackPolicyURL parameter, but not both.
8431 8432 8433 8434 8435 8436 8437 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 8431 class SetStackPolicyInput < Struct.new( :stack_name, :stack_policy_body, :stack_policy_url) SENSITIVE = [] include Aws::Structure end |
#stack_policy_url ⇒ String
Location of a file that contains the stack policy. The URL must
point to a policy (maximum size: 16 KB) located in an Amazon S3
bucket in the same Amazon Web Services Region as the stack. The
location for an Amazon S3 bucket must start with https://. URLs
from S3 static websites are not supported.
You can specify either the StackPolicyBody or the StackPolicyURL
parameter, but not both.
8431 8432 8433 8434 8435 8436 8437 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 8431 class SetStackPolicyInput < Struct.new( :stack_name, :stack_policy_body, :stack_policy_url) SENSITIVE = [] include Aws::Structure end |