Method: Aws::CloudFormation::Types::SignalResourceInput#status
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
#status ⇒ String
The status of the signal, which is either success or failure. A failure signal causes CloudFormation to immediately fail the stack creation or update.
8590 8591 8592 8593 8594 8595 8596 8597 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 8590 class SignalResourceInput < Struct.new( :stack_name, :logical_resource_id, :unique_id, :status) SENSITIVE = [] include Aws::Structure end |