Method: Aws::CloudFormation::Types::StackSetOperationResultSummary#status
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
#status ⇒ String
The result status of the StackSet operation for the given account in the given Region.
-
CANCELLED: The operation in the specified account and Region has been canceled. This is either because a user has stopped the StackSet operation, or because the failure tolerance of the StackSet operation has been exceeded. -
FAILED: The operation in the specified account and Region failed.If the StackSet operation fails in enough accounts within a Region, the failure tolerance for the StackSet operation as a whole might be exceeded.
-
RUNNING: The operation in the specified account and Region is currently in progress. -
PENDING: The operation in the specified account and Region has yet to start. -
SUCCEEDED: The operation in the specified account and Region completed successfully.
10676 10677 10678 10679 10680 10681 10682 10683 10684 10685 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 10676 class StackSetOperationResultSummary < Struct.new( :account, :region, :status, :status_reason, :account_gate_result, :organizational_unit_id) SENSITIVE = [] include Aws::Structure end |