Class: Aws::CloudFormation::Types::TypeConfigurationIdentifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudFormation::Types::TypeConfigurationIdentifier
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudformation/types.rb
Overview
Identifying information for the configuration of a CloudFormation extension.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#type ⇒ String
The type of extension.
-
#type_arn ⇒ String
The ARN for the extension, in this account and Region.
-
#type_configuration_alias ⇒ String
The alias specified for this configuration, if one was specified when the configuration was set.
-
#type_configuration_arn ⇒ String
The ARN for the configuration, in this account and Region.
-
#type_name ⇒ String
The name of the extension type to which this configuration applies.
Instance Attribute Details
#type ⇒ String
The type of extension.
11569 11570 11571 11572 11573 11574 11575 11576 11577 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 11569 class TypeConfigurationIdentifier < Struct.new( :type_arn, :type_configuration_alias, :type_configuration_arn, :type, :type_name) SENSITIVE = [] include Aws::Structure end |
#type_arn ⇒ String
The ARN for the extension, in this account and Region.
For public extensions, this will be the ARN assigned when you call the ActivateType API operation in this account and Region. For private extensions, this will be the ARN assigned when you call the RegisterType API operation in this account and Region.
11569 11570 11571 11572 11573 11574 11575 11576 11577 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 11569 class TypeConfigurationIdentifier < Struct.new( :type_arn, :type_configuration_alias, :type_configuration_arn, :type, :type_name) SENSITIVE = [] include Aws::Structure end |
#type_configuration_alias ⇒ String
The alias specified for this configuration, if one was specified when the configuration was set.
11569 11570 11571 11572 11573 11574 11575 11576 11577 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 11569 class TypeConfigurationIdentifier < Struct.new( :type_arn, :type_configuration_alias, :type_configuration_arn, :type, :type_name) SENSITIVE = [] include Aws::Structure end |
#type_configuration_arn ⇒ String
The ARN for the configuration, in this account and Region.
11569 11570 11571 11572 11573 11574 11575 11576 11577 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 11569 class TypeConfigurationIdentifier < Struct.new( :type_arn, :type_configuration_alias, :type_configuration_arn, :type, :type_name) SENSITIVE = [] include Aws::Structure end |
#type_name ⇒ String
The name of the extension type to which this configuration applies.
11569 11570 11571 11572 11573 11574 11575 11576 11577 |
# File 'lib/aws-sdk-cloudformation/types.rb', line 11569 class TypeConfigurationIdentifier < Struct.new( :type_arn, :type_configuration_alias, :type_configuration_arn, :type, :type_name) SENSITIVE = [] include Aws::Structure end |