Class: Aws::CloudFormation::Waiters::ChangeSetCreateComplete
- Inherits:
-
Object
- Object
- Aws::CloudFormation::Waiters::ChangeSetCreateComplete
- Defined in:
- lib/aws-sdk-cloudformation/waiters.rb,
sig/waiters.rbs
Overview
Wait until change set status is CREATE_COMPLETE.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ChangeSetCreateComplete
constructor
A new instance of ChangeSetCreateComplete.
-
#wait(params = {}) ⇒ Types::DescribeChangeSetOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ChangeSetCreateComplete
Returns a new instance of ChangeSetCreateComplete.
94 95 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 94
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
131 132 133 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 131 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeChangeSetOutput
Returns a response object which responds to the following methods:
- #change_set_name => String
- #change_set_id => String
- #stack_id => String
- #stack_name => String
- #description => String
- #parameters => Array<Types::Parameter>
- #creation_time => Time
- #execution_status => String
- #status => String
- #status_reason => String
- #stack_drift_status => String
- #notification_arns => Array<String>
- #rollback_configuration => Types::RollbackConfiguration
- #capabilities => Array<String>
- #tags => Array<Types::Tag>
- #changes => Array<Types::Change>
- #next_token => String
- #include_nested_stacks => Boolean
- #parent_change_set_id => String
- #root_change_set_id => String
- #on_stack_failure => String
- #import_existing_resources => Boolean
- #deployment_mode => String
- #deployment_config => Types::DeploymentConfig
126 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 126
def wait: (
|