Class: Aws::CloudFormation::Waiters::StackExists
- Inherits:
-
Object
- Object
- Aws::CloudFormation::Waiters::StackExists
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-cloudformation/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ StackExists
constructor
A new instance of StackExists.
-
#wait(params = {}) ⇒ Types::DescribeStacksOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ StackExists
Returns a new instance of StackExists.
351 352 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 351
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
381 382 383 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 381 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeStacksOutput
Returns a response object which responds to the following methods:
- #stacks => Array<Types::Stack>
- #next_token => String
376 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 376
def wait: (
|