Class: Aws::CloudFormation::Waiters::StackImportComplete
- Inherits:
-
Object
- Object
- Aws::CloudFormation::Waiters::StackImportComplete
- Defined in:
- lib/aws-sdk-cloudformation/waiters.rb,
sig/waiters.rbs
Overview
Wait until stack status is IMPORT_COMPLETE.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ StackImportComplete
constructor
A new instance of StackImportComplete.
-
#wait(params = {}) ⇒ Types::DescribeStacksOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ StackImportComplete
Returns a new instance of StackImportComplete.
394 395 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 394
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
455 456 457 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 455 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeStacksOutput
Returns a response object which responds to the following methods:
- #stacks => Array<Types::Stack>
- #next_token => String
450 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 450
def wait: (
|