Class: Aws::CloudFormation::Waiters::StackRefactorExecuteComplete
- Inherits:
-
Object
- Object
- Aws::CloudFormation::Waiters::StackRefactorExecuteComplete
- Defined in:
- lib/aws-sdk-cloudformation/waiters.rb,
sig/waiters.rbs
Overview
Wait until the stack refactor status is EXECUTE_COMPLETE.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ StackRefactorExecuteComplete
constructor
A new instance of StackRefactorExecuteComplete.
-
#wait(params = {}) ⇒ Types::DescribeStackRefactorOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ StackRefactorExecuteComplete
Returns a new instance of StackRefactorExecuteComplete.
518 519 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 518
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
561 562 563 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 561 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeStackRefactorOutput
Returns a response object which responds to the following methods:
- #description => String
- #stack_refactor_id => String
- #stack_ids => Array<String>
- #execution_status => String
- #execution_status_reason => String
- #status => String
- #status_reason => String
556 |
# File 'lib/aws-sdk-cloudformation/waiters.rb', line 556
def wait: (
|